@@ -5,7 +5,7 @@
 ** analyst.cpp
 ** analyse the game and play
 **
-** Version : $Id: analyst.cpp,v 1.34 2004/10/09 13:18:51 audoux Exp $
+** Version : $Id: analyst.cpp,v 1.53 2004/12/27 22:52:45 audoux Exp $
 **
 ** Author(s) : Pascal Audoux - Sardi Carlo
 **
@@ -44,6 +44,7 @@
 #include "libCommon/genericMapCreature.h"
 #include "libCommon/genericPlayer.h"
 #include "libCommon/pathFinder.h"
+#include "libCommon/priceMarket.h"
 
 #include "libServer/fightAnalyst.h"
 
@@ -77,6 +78,8 @@ Analyst::Analyst()
 	for(int i = PR_ENEMY;i<=PR_LAST;i++){ 
 		_priorities[i]=i;
 	}	
+	srand( time( NULL ) );
+	_SuffisantPower = 1000;
 }
 
 Analyst::~Analyst()
@@ -150,8 +153,16 @@ void Analyst::socketConnect()
 		ialogN( "Receive: Connect Id = %d", _player->getNum() );
 		}
 		break;
-	case C_CONN_NAME:
-		ialogN( "Receive: Connect Name" );
+	case C_CONN_NAME:	
+		{
+			QString res;
+			uint len = _socket->readChar();
+			for( uint i = 0; i < len; i++) {
+				res.append( _socket->readChar() );
+			}
+			_player->setName(res);
+			ialogN( "Receive: Connect Name %s", res.latin1());
+		}
 		break;
 	case C_CONN_PLAYER:
 		ialogN( "Receive: Connect Player" );
@@ -189,7 +200,6 @@ void Analyst::socketMvt()
 		}
 	} else if( _map->at( row, col )->getBase() != 0 ) {
 		if( theLord->getOwner() == _player ) {
-			/// TODO: enter( _player->getSelectedLord(), _map->at( row, col )->getBase() );
 			enterBase(theLord, _map->at( row, col )->getBase());
 		}
 	}
@@ -216,6 +226,7 @@ void Analyst::socketFight()
 		break;
 	case C_FIGHT_END:
 		ialogN( "FIGHT END" );
+		//logDD( "ai: FIGHT END" );
 		bool isCrea;
 		isCrea	= _fight->IsCreature(); 
 		_fight->updateUnits();
@@ -259,6 +270,18 @@ void Analyst::socketQR()
 		_socket->sendAnswerEnum( 0 );
 		_socket->sendLordTurn( PL_SAME_LORD );
 		} break;
+	case C_QR_CREATURE_FLEE: 
+		_socket->sendAnswerYesNo( true );
+		_socket->sendLordTurn( PL_SAME_LORD );
+		break;
+	case C_QR_CREATURE_MERCENARY:
+		_socket->sendAnswerYesNo( false );
+		_socket->sendLordTurn( PL_SAME_LORD );
+		break;
+	case C_QR_CREATURE_JOIN: 
+		_socket->sendAnswerYesNo( true );
+		_socket->sendLordTurn( PL_SAME_LORD );
+		break;
 	case C_QR_ANSWER:
 		logEE( "Should not happen" );
 		break;
@@ -277,6 +300,9 @@ void Analyst::socketExch()
 	case C_EXCH_UNIT:
 	  	exchangeUnits();
 		break;
+	case C_EXCH_ARTEFACT:
+		exchangeArtefact();
+		break;
 	case C_EXCH_BASEUNITCL:
 	  	exchangeBaseUnits();
 		break;
@@ -332,6 +358,11 @@ void Analyst::exchangeUnits()
 	}
 }
 
+void Analyst::exchangeArtefact()
+{
+	ialogC( "Exchange artefact not implemented" );
+}
+
 void Analyst::exchangeBaseUnits()
 {
 	int row = _socket->readInt();
@@ -362,9 +393,9 @@ void Analyst::exchangeBaseUnits()
 					lord->setUnit( idUnit2, uni1 );
 					base->setUnit( idUnit1, uni2 );
 				} else {
-					uni1->addNumber( uni2->getNumber() );
-					lord->setUnit( idUnit2, 0 );
-					delete uni2;
+					uni2->addNumber( uni1->getNumber() );
+					base->setUnit( idUnit1, 0 );
+					delete uni1;
 				}
 			} else if (!uni1) {
 				lord->setUnit( idUnit2, 0 );
@@ -444,13 +475,15 @@ void Analyst::socketModifMap()
 
 void Analyst::socketModifCell()
 {
-	int a1 = _socket->readInt();
-	int a2 = _socket->readInt();
-	int a3 = _socket->readInt();
+	int row = _socket->readInt();
+	int col = _socket->readInt();
+	int type = _socket->readInt();
+	/* XXX: unused... uchar diversification = */ _socket->readChar();
 	int a4 = _socket->readInt();
 	int a5 = _socket->readInt();
 	int a6 = _socket->readInt();
-	_map->changeCell( a1, a2, a3, a4, a5, a6 );
+	int a7 = _socket->readInt();
+	_map->changeCell( row, col, type, a4, a5, a6, a7 );
 }
 
 void Analyst::socketModifLord()
@@ -594,22 +627,29 @@ void Analyst::socketModifLordUnit()
 	uchar race = _socket->readChar();
 	uchar level = _socket->readChar();
 	int nb = _socket->readInt();
+	uchar move = _socket->readChar();
+	int health = _socket->readInt();
+
 	GenericFightUnit * unit = 0;
 	unit =_lords.at( id )->getUnit( num );
 	if(!unit){
 		unit = new GenericFightUnit();
 		unit->setCreature( race, level );
-		unit->setMove( _socket->readChar() );
-		unit->setHealth( _socket->readInt() );
+		unit->setMove( move );
+		unit->setHealth( health );
 	}
 	
-	unit->setNumber( nb );
-	if( nb == 0){
-		delete unit;
-		unit = 0;
+	if( nb == 0  ){
+		if(_lords.at( id )->countUnits()>1){
+			unit->setNumber( nb );
+			delete unit;
+			unit = 0;
+		}
+	} else {
+		unit->setNumber( nb );
 	}
+	
 	_lords.at( id )->setUnit( num, unit );
-	/// XXX: remove/delete old unit ??
 }
 
 void Analyst::socketModifLordRemove()
@@ -640,6 +680,12 @@ void Analyst::socketModifPlayer()
 		_player->setResource( ress, _socket->readInt() );
 		}
 		break;
+	case C_PLAY_PRICE: {
+		uchar ress = _socket->readChar();
+		uint price = _socket->readInt();
+		_player->getPriceMarket()->setResourcePrice( ress, price);
+		}
+		break;
 	}
 }
 
@@ -652,6 +698,9 @@ void Analyst::socketModifBase()
 	case C_BASE_OWNER:
 		socketModifBaseOwner();
 		break;
+	case C_BASE_NAME:
+		socketModifBaseName();
+		break;
 	case C_BASE_BUILDING:
 		socketModifBaseBuilding();
 		break;
@@ -703,11 +752,26 @@ void Analyst::socketModifBaseOwner()
 	}
 }
 
+void Analyst::socketModifBaseName()
+{
+	int row = _socket->readInt();
+	int col = _socket->readInt();
+	uint length = _socket->readInt();
+	QString name;
+	
+	for( uint i = 0; i < length; i++ ) {
+		name.ref(i) = _socket->readChar();
+	}
+	
+	GenericBase * base = _map->at( row, col )->getBase();
+	base->setName( name );
+}
+
 void Analyst::socketModifBasePopulation()
 {
 	int row = _socket->readInt();
 	int col = _socket->readInt();
-	uint popul = _socket->readChar();
+	uint popul = _socket->readInt();
 	GenericBase * base = (GenericBase*) _map->at( row, col )->getBase();
 
 	if(base)
@@ -720,6 +784,7 @@ void Analyst::socketModifBaseBuilding()
 	int col = _socket->readInt();
 	uchar level = _socket->readChar();
 	bool create = (bool)_socket->readChar();
+	//ialogN("base building row %d, col %d, level %d, create %d",row,col,level,create);
 
 	if( _map->at( row, col )->getBase() ) {
 		if( create ) {
@@ -760,6 +825,7 @@ void Analyst::socketModifBuilding()
 			building->setPosition( _map->at( row, col ) );
 			uchar type = _socket->readChar();
 			building->setType( type );
+			_map->computeStoppable( building );
 		}
 		break;
 		case C_BUILD_OWNER: {
@@ -884,6 +950,16 @@ void Analyst::socketModifCreature()
 		_map->at( row, col )->setCreature( creature );
 		}
 		break;
+	case C_CRE_UPDATE: {
+		int row = _socket->readInt();
+		int col = _socket->readInt();
+		int nb = _socket->readInt();
+		GenericMapCreature * creature = _map->at( row, col )->getCreature();
+		if( creature ) {
+			creature->setCategoryNumber( nb );
+		}
+		}
+		break;
 	case C_CRE_DEL: {
 		int row = _socket->readInt();
 		int col = _socket->readInt();
@@ -976,9 +1052,27 @@ void Analyst::analyzeLord( GenericLord * lord )
 	data->startApprRow = 0;
 	data->startApprCol = 0;
 	data->destinationCell = cell;
-	data->curPrior = PR_LAST;
+	data->curPrior = (PR_LAST*10);
 	data->mincost = movePoints + 10;
 	data->fightCpt = _fightCpt;
+	
+	/* if a lord is already in a base */
+	if( cell->getBase() != 0 ) {
+		if( lord->getOwner() == _player ) {
+				enterBase(lord, cell->getBase());
+			}
+	}
+
+	/* if lord is powerful, prefer to fight and explore instead cumulate units */
+	if(getPower(lord) > _SuffisantPower){
+		lord->setPrio(PR_BASEOWNER,(PR_EXPLORE*10)+5);
+		lord->setPrio(PR_CREAT,(PR_BASE*10)-1);
+		//ialogV("prio %d",getPower(lord));
+		//ialogV("creat %d",lord->getPrio(PR_CREAT));
+	} else {
+		lord->setPrio(PR_BASEOWNER,(PR_BASEOWNER*10));
+		lord->setPrio(PR_CREAT,(PR_CREAT*10));
+	}
 
 	_map->getPath()->reinit( _map );
 	_map->getPath()->computePath( cell );
@@ -987,7 +1081,7 @@ void Analyst::analyzeLord( GenericLord * lord )
 		ialogV("no path");
 		movePoints=0;
 	}
-		
+	
 
 	if( movePoints > 0 ) {
 		analyzeLordMap( lord, data );
@@ -1051,7 +1145,7 @@ void Analyst::analyzeLordMap( GenericLord * lord ,struct aiData * data)
 	unsigned int i, j;
 	GenericCell * cell;
 
-	int opPower;
+	int opPower = 0;
 	//int cost;
 
 	data->fightCpt = PL_SAME_LORD_NOFIGHT;
@@ -1060,40 +1154,82 @@ void Analyst::analyzeLordMap( GenericLord * lord ,struct aiData * data)
 	for( i = 0; i < _map->getHeight(); i++ ) {
 		for( j = 0; j < _map->getWidth(); j++ ) {
 			cell = _map->at( i, j );
-			if( cell->getLord() && ( lord->getPrio(PR_ENEMY) <= data->curPrior ) && cell->getCoeff() != -1 ) {
-				if( cell->getLord()->getOwner() != _player ) {
-					opPower = getRandPower( cell->getLord() );
-					ialogN( "Try Enemy");
-					data->fightCpt=manageMeetings(lord,cell ,lord->getPrio(PR_ENEMY),opPower,true,data);
+			if(cell->getCoeff() != -1){
+				if( cell->getLord() && ( lord->getPrio(PR_ENEMY) <= data->curPrior )  ) {
+					if( cell->getLord()->getOwner() != _player ) {
+						opPower = getRandPower( cell->getLord() );
+						ialogN( "Try Enemy");
+						ialogV( "row %d, col %d",cell->getRow(),cell->getCol());
+						data->fightCpt=manageMeetings(lord,cell ,lord->getPrio(PR_ENEMY),opPower,true,data);
+					}
+				} 
+				if( cell->getBase() && (lord->getPrio(PR_BASE)	<= data->curPrior )  )	{
+					if( cell->getBase()->getOwner() != _player) {
+						ialogN( "Try Base");
+						ialogV( "row %d, col %d",cell->getRow(),cell->getCol());
+						data->fightCpt=manageMeetings(lord,cell ,lord->getPrio(PR_BASE),0,false,data);
+					}
+				} 
+				if( cell->getBase() && (lord->getPrio(PR_BASEOWNER)	<= data->curPrior )  )	{
+					if( cell->getBase()->getOwner() == _player && cell->getBase()->isUnitBought() ) {
+						ialogN( "Try Base Owner");
+						ialogV( "row %d, col %d",cell->getRow(),cell->getCol());
+						data->fightCpt=manageMeetings(lord,cell ,lord->getPrio(PR_BASEOWNER),0,false,data);
+					}
+				} 
+				if( cell->getBuilding() && (lord->getPrio(PR_BUILD) <= data->curPrior) ) {
+					if( cell->getBuilding()->getOwner() != _player ) {
+						ialogN( "Try Build");
+						ialogV( "row %d, col %d",cell->getRow(),cell->getCol());
+						data->fightCpt=manageMeetings(lord,cell ,lord->getPrio(PR_BUILD),0,false,data);
+					}
+				} 
+				if( cell->getEvent()){
+					if(cell->getEvent()->getType()==GenericEvent::EventArtefact && ( lord->getPrio(PR_ART) < data->curPrior )  )	{
+						ialogN( "Try Event-Artefact");
+						ialogV( "row %d, col %d",cell->getRow(),cell->getCol());
+						data->fightCpt=manageMeetings(lord,cell ,lord->getPrio(PR_ART),0,false,data);
+					} 
+					if( cell->getEvent()->getType()==GenericEvent::EventBonus && ( lord->getPrio(PR_BONUS) < data->curPrior ) )	{
+						ialogN( "Try Event-Bonus");
+						ialogV( "row %d, col %d",cell->getRow(),cell->getCol());
+						data->fightCpt=manageMeetings(lord,cell ,lord->getPrio(PR_BONUS),0,false,data);
+					} 
+					if( cell->getEvent()->getType()==GenericEvent::EventChest && ( lord->getPrio(PR_CHEST)< data->curPrior ) )	{
+						ialogN( "Try Event-chest");
+						ialogV( "row %d, col %d",cell->getRow(),cell->getCol());
+						data->fightCpt=manageMeetings(lord,cell ,lord->getPrio(PR_CHEST),0,false,data);
+					}
 				}
-			} else if( cell->getBase() && (lord->getPrio(PR_BASE)	<= data->curPrior ) && cell->getCoeff() != -1 )	{
-				if( cell->getBase()->getOwner() != _player || cell->getBase()->isUnitBought() ) {
-					ialogN( "Try Base");
-					data->fightCpt=manageMeetings(lord,cell ,lord->getPrio(PR_BASE),0,false,data);
+				if( cell->getCreature() ){
+					if	(lord->getPrio(PR_CREAT) < data->curPrior) {
+						ialogN( "Try Creat");
+						ialogV( "row %d, col %d",cell->getRow(),cell->getCol());
+						opPower = getCreaturePower( cell->getCreature() );
+						data->fightCpt=manageMeetings(lord,cell ,lord->getPrio(PR_CREAT),opPower,false,data);
+					} 
 				}
-			} else if( cell->getBuilding() && (lord->getPrio(PR_BUILD) <= data->curPrior) && cell->getCoeff() != -1 ) {
-				if( cell->getBuilding()->getOwner() != _player ) {
-					ialogN( "Try Build");
-					data->fightCpt=manageMeetings(lord,cell ,lord->getPrio(PR_BUILD),0,false,data);
+			} //coeff
+			if ( lord->getPrio(PR_EXPLORE) <= data->curPrior) {
+				/* ai explore map */
+				if(cell->getType() == 0){
+					GenericCell * dest;
+					dest = findNearCellReach(cell);
+					if(dest){
+						data->fightCpt=manageMeetings(lord,dest ,lord->getPrio(PR_EXPLORE),0,false,data);
+					}
 				}
-			} else if( cell->getEvent()){
-				if(cell->getEvent()->getType()==GenericEvent::EventArtefact && ( lord->getPrio(PR_ART) < data->curPrior ) && ( cell->getCoeff() != -1 ) )	{
-					ialogN( "Try Event-Artefact");
-					data->fightCpt=manageMeetings(lord,cell ,lord->getPrio(PR_ART),0,false,data);
-				} else if( cell->getEvent()->getType()==GenericEvent::EventBonus && ( lord->getPrio(PR_BONUS) < data->curPrior ) && ( cell->getCoeff() != -1 ) )	{
-					ialogN( "Try Event-Bonus");
-					data->fightCpt=manageMeetings(lord,cell ,lord->getPrio(PR_BONUS),0,false,data);
-				} else if( cell->getEvent()->getType()==GenericEvent::EventChest && ( lord->getPrio(PR_CHEST)< data->curPrior ) && ( cell->getCoeff() != -1 ) )	{
-					ialogN( "Try Event-chest");
-					data->fightCpt=manageMeetings(lord,cell ,lord->getPrio(PR_CHEST),0,false,data);
-				}
-			} else if( cell->getCreature() && (lord->getPrio(PR_CREAT) < data->curPrior) && ( cell->getCoeff() != -1 ) ){
-				ialogN( "Try Creat");
-				opPower = getCreaturePower( cell->getCreature() );
-				data->fightCpt=manageMeetings(lord,cell ,lord->getPrio(PR_CREAT),opPower,false,data);
 			}
 		}//for i
 	}//for j
+
+	/* tune ai based on enemy stength */
+	if(opPower > _SuffisantPower  ) {
+		_SuffisantPower = opPower ;
+		ialogV("opPower %d",opPower);
+	} else {
+		_SuffisantPower = 1000;
+	}
 }
 
 
@@ -1108,13 +1244,21 @@ void Analyst::socketGame()
 			break;
 		case C_GAME_LOST : {
 		  int nb = _socket->readChar();
-		  ialogN("player %d has lost",nb);
+			if(nb != _player->getNum()) {
+				ialogN("player %d has lost",nb);
+			} else {
+				ialogN("I'm the loser, i'm num %d",nb);
+			}
 		  ialogN( "SO_GAME_LOST" );
 			}
 			break;
 		case C_GAME_WIN : {
 		  int nb = _socket->readChar();
-		  ialogN("player %d has win",nb);
+			if(nb == _player->getNum()) {
+				ialogN("I'm the winner, i'm num %d",nb);
+			} else {
+				ialogN("player %d has win",nb);
+			}
 		  ialogN( "SO_GAME_WIN" );
 			}
 			break;
@@ -1223,18 +1367,26 @@ void Analyst::manageBase(GenericBase * base)
 		}
 	}
 
+	int bought = 0;
 	GenericBaseModel * baseModel = DataTheme.bases.at( base->getRace() );
 	int modelCount = baseModel->getBuildingCount();
+	InsideBuildingModel * model;
 
 	for( i = 0; i < (uint) modelCount; i++ ) {
-		GenericInsideBuilding * building= base->getBuilding( i );
-		if( _player && _socket &&  !building) {
-			if( _player->canBuy( DataTheme.bases.at( base->getRace() )->getBuildingModel( i ) ) ) {
-				_socket->requestBuilding( base, i, true );
-				ialogN("Buy Building");
-				break;
-			} else {
-				//logDD("Can't buy, Not enough ressources to buy this building" );
+		GenericInsideBuilding * building= base->getBuildingByType( i );
+		if( _player && _socket &&  !building && bought == 0) {
+			model = DataTheme.bases.at( base->getRace() )->getBuildingModel( i ) ;
+			/* ai don't buy buildings that not implement actions */
+			if (model->getAction()) {
+				if(model->getAction()->getType() != INSIDE_NONE) {
+					if( _player->canBuy( model ) ) {
+						_socket->requestBuilding( base, i, true );
+						ialogN("Request Building model %d",i);
+						bought = 1;
+					} else {
+						//logDD("Can't buy, Not enough ressources to buy this building" );
+					}
+				}
 			}
 		}
 	}
@@ -1245,14 +1397,13 @@ void Analyst::enterBase(GenericLord * lord,GenericBase * base )
 {
 	int i;
 	int j;
+	ialogN("Enter base");
 
 	base->enter( lord );
 		for(i=0;i<MAX_UNIT;i++){
 			for(j=0;j<MAX_UNIT;j++){
 				if(lord->getUnit(i) && lord->getUnit(j) && i!=j){
 					if(lord->getUnit(i)->getCreature()==lord->getUnit(j)->getCreature()){
-						lord->getUnit(j)->addNumber(lord->getUnit(i)->getNumber());
-						base->setVisitorUnit(i,0);
 						_socket->sendExchangeUnit( lord, i, lord, j );
 					}
 				}
@@ -1261,23 +1412,23 @@ void Analyst::enterBase(GenericLord * lord,GenericBase * base )
 	if(lord->countUnits()<MAX_UNIT){
 		for(i=0;i<MAX_UNIT;i++){
 			for(j=0;j<MAX_UNIT;j++){
-				if(!lord->getUnit(j) && base->getGarrisonUnit(i)){
-					lord->setUnit(j,base->getGarrisonUnit(i));
-					base->setGarrisonUnit(i,0);
-					_socket->sendExchangeBaseUnit( base, i, lord, j );
-					//ialogN("Exch ,pos i %d ,pos j %d",i,j);
-				} 
 				if(lord->getUnit(j) && base->getGarrisonUnit(i)){
 					if(lord->getUnit(j)->getCreature()==base->getGarrisonUnit(i)->getCreature()){
-						lord->getUnit(j)->addNumber(base->getGarrisonUnit(i)->getNumber());
-						base->setGarrisonUnit(i,0);
 						_socket->sendExchangeBaseUnit( base, i, lord, j );
 					}
 				}
 			}
-		base->isUnitBought(false);
+		}
+		for(i=0;i<MAX_UNIT;i++){
+			for(j=0;j<MAX_UNIT;j++){
+				if(!lord->getUnit(j) && base->getGarrisonUnit(i)){
+					_socket->sendExchangeBaseUnit( base, i, lord, j );
+					//ialogN("Exch ,pos i %d ,pos j %d",i,j);
+				} 
+			}
 		}
 	}
+	base->isUnitBought(false);
 	base->out( lord );
 }
 
@@ -1297,7 +1448,12 @@ int Analyst::manageMeetings(GenericLord * lord,GenericCell * cell ,int prior,int
 		ialogN("opPower %d, myPower %d",opPower,myPower);	
 
 	tcell=_map->getPath()->getNearCell(	cell );
-	cost = _map->getPath()->getDist( tcell );
+	/* workaround for getNearCell bug? */
+	if(tcell->getRow() > 0 && tcell->getCol() > 0) {
+		cost = _map->getPath()->getDist( tcell );
+	} else {
+		cost = 10000;
+	}
 	/* if they are more targets with same priority, use that with minimal cost*/
 	if( data->curPrior > prior ) {
 		data->mincost = movePoints+10;
@@ -1309,39 +1465,19 @@ int Analyst::manageMeetings(GenericLord * lord,GenericCell * cell ,int prior,int
 		data->destinationCell = cell;
 		data->mincost = cost;
 		data->curPrior = prior;
-		ialogN("Meeting");
+		//ialogN("Meeting");
 		return PL_SAME_LORD;
 		
 	/* else go near target (or flee if enemy is more powerful) */
 	} else if( cost < ( movePoints + 5 ) && cost != -1 ) {
-		if(  startRow > dRow ) {
-			data->startApprRow = dRow;
-			if( myPower < opPower && isFlee) {
-				data->startApprRow = startRow;
-				data->rowFlee = 1;
-			}
-		} else {
-			data->startApprRow = startRow;
-			if( myPower < opPower && isFlee) {
-				data->startApprRow = dRow;
-				data->rowFlee = -1;
-			}
-		}
-		if( startCol > dCol ){
-			data->startApprCol = dCol;
-			if( myPower < opPower && isFlee) {
-				data->startApprCol = startCol;
-				data->colFlee = 1;
-			}
-		} else {
-			data->startApprCol = startCol;
-			if( myPower < opPower && isFlee) {
-				data->startApprCol = dCol;
-				data->colFlee = -1;
-			}
-		}
-		
+		data->startApprRow = std::min(startRow,dRow);
+		data->startApprCol = std::min(startCol,dCol);
+	
 		if( myPower < opPower && isFlee) {
+			data->startApprRow = std::max(startRow,dRow);
+			data->startApprCol = std::max(startCol,dCol);
+			data->rowFlee = flee(startRow,dRow);
+			data->colFlee = flee(startCol,dCol);
 			data->curPrior = prior;
 		}
 	}
@@ -1357,13 +1493,13 @@ GenericCell * Analyst::randomPath(GenericLord * lord, struct aiData * data)
 		int sameTry=0;
 		int moreTry=0;
 		int i,j;
-		long he = (long)_map->getHeight();
-		long wi = (long)_map->getWidth();
+		float he = (float)_map->getHeight();
+		float wi = (float)_map->getWidth();
 		 
 		do {
 			do {
 				if( data->startApprRow ) {
-					i = data->startApprRow + ( data->rowFlee)*(int)( movePoints*(rand()/(RAND_MAX+1.0)));
+					i = data->startApprRow + ( data->rowFlee)*(int)( (rand()/(RAND_MAX+1.0)) * (float) movePoints);
 					moreTry++;
 					if(moreTry>19 ) {
 						i=data->startApprRow;
@@ -1375,7 +1511,7 @@ GenericCell * Analyst::randomPath(GenericLord * lord, struct aiData * data)
 			moreTry=0;
 			do{
 				if(data->startApprCol){
-					j=data->startApprCol+(data->colFlee)*(int)( movePoints*(rand()/(RAND_MAX+1.0)));
+					j=data->startApprCol+(data->colFlee)*(int)( (rand()/(RAND_MAX+1.0))* (float) movePoints);
 					moreTry++;
 					if(moreTry>19 ){
 						j=data->startApprCol;
@@ -1409,11 +1545,11 @@ int Analyst::noPath(GenericCell * cell)
 
 		initRow= row > 0 ? row-1 : 0;
 		initCol= col > 0 ? col-1 : 0;
-		finRow= row < _map->getWidth() ? row+1 : _map->getWidth();
-		finCol= row < _map->getHeight() ? col+1 : _map->getHeight();
+		finRow= row < _map->getHeight()-1 ? row+1 : _map->getHeight()-1;
+		finCol= col < _map->getWidth()-1 ? col+1 : _map->getWidth()-1;
 
-		for(i=initRow;i<=finRow;i++){
-			for(j=initCol;j<=finCol;j++){
+		for(i=initRow; i<=finRow; i++){
+			for(j=initCol; j<=finCol; j++){
 				if(_map->getPath()->isPath(_map->at(i,j)))
 						return false;
 			}
@@ -1421,3 +1557,45 @@ int Analyst::noPath(GenericCell * cell)
 		return true;
 }
 
+inline int Analyst::flee(int src, int dst)
+{
+	int tmp;
+	
+	tmp = ((src)>(dst) ? 1:  -1);
+
+	return tmp;
+}
+
+GenericCell * Analyst::findNearCellReach(GenericCell * cell)
+{
+
+		uint row= cell->getRow();
+		uint col= cell->getCol();
+		uint i,j;
+		uint initRow;
+		uint initCol;
+		uint finRow;
+		uint finCol;
+		uint height =_map->getHeight();
+		uint width = _map->getWidth();
+		GenericCell * tcell;
+
+		initRow= row > 0 ? row-1 : 0;
+		initCol= col > 0 ? col-1 : 0;
+		finRow= row < height-1 ? row+1 : height-1;
+		finCol= col < width-1 ? col+1 : width-1;
+
+		for(i=initRow; i<=finRow; i++){
+			for(j=initCol; j<=finCol; j++){
+				tcell = _map->at(i,j);
+				if(tcell){
+					if(tcell->getType() != 0){	
+						if(_map->getPath()->isPath(tcell))
+							return tcell;
+					}
+				}
+			}
+		}
+		return NULL;
+}
+
