@@ -5,7 +5,7 @@
 ** analyst.h
 ** analyse the game and play
 **
-** Version : $Id: analyst.h,v 1.15 2004/09/25 19:50:49 lusum Exp $
+** Version : $Id: analyst.h,v 1.23 2004/12/18 23:25:17 lusum Exp $
 **
 ** Author(s) : Pascal Audoux - Carlo
 **
@@ -29,7 +29,7 @@
 #define ANALYST_H
 #define DIM 100
  
- 
+
 // generic include files
 // include files for QT
 // application specific include files
@@ -108,6 +108,7 @@ public:
 	void socketModifBase();
 	void socketModifBaseNew();
 	void socketModifBaseOwner();
+	void socketModifBaseName();
 	void socketModifBaseBuilding();
 	void socketModifBaseUnit();
 	void socketModifBasePopulation();
@@ -137,9 +138,12 @@ public:
 
 	void exchangeStart();
 
-	/*manage exchange units*/
+	/** manage exchange units */
 	void exchangeUnits();
 	
+	/** manage exchange artefact */
+	void exchangeArtefact();
+	
 	void exchangeBaseUnits();
 	
 	void manageBase(GenericBase * base);
@@ -172,7 +176,12 @@ private:
 
 	GenericCell * randomPath(GenericLord * lord,struct aiData *data);
 
+	/* find if this is a cell reachable (and visible) near an unknown cell */
+	GenericCell * findNearCellReach(GenericCell * cell);
+
 	int noPath(GenericCell * cell);
+	
+	inline int flee(int src, int dst);
 
 	/* manageMeetings
 	 * with 
@@ -199,6 +208,7 @@ private:
 	int _numlords;
 
 	int _numTurn;
+	int _SuffisantPower;
 
 	//GenericMap * _map;
 	//GenericLord ** _lords;
