@@ -5,9 +5,9 @@
 ** clientInterface.cpp
 ** Manages the whole game
 **
-** Version : $Id: clientInterface.cpp,v 1.23 2004/10/03 19:02:25 audoux Exp $
+** Version : $Id: clientInterface.cpp,v 1.26 2004/12/11 13:39:04 lusum Exp $
 **
-** Author(s) : Pascal Audoux
+** Author(s) : Pascal Audoux - Sardi Carlo
 **
 ** Date : 17/08/2000
 **
@@ -83,6 +83,7 @@ ClientInterface::ClientInterface()
 	_mini = true;
 	_tab = true;
 	_full = true;
+	_help = 0;
 
 	qApp->setStyle( new AttalStyle( DATA_PATH + "style.dat" ) );
 
@@ -98,6 +99,8 @@ ClientInterface::ClientInterface()
 		connect( _game, SIGNAL( sig_statusMsg( const QString & ) ), SLOT( slot_status( const QString & ) ) );
 		connect( _game, SIGNAL( sig_base( GenericBase * ) ), SLOT( slot_base( GenericBase * ) ) );
 		connect( _game, SIGNAL( sig_fight( GenericLord *, CLASS_FIGHTER ) ), SLOT( slot_fight( GenericLord *, CLASS_FIGHTER ) ) );
+		connect( _game, SIGNAL( sig_endGame() ), SLOT( slot_endGame() ) );
+		connect( _game, SIGNAL( sig_exchange() ), SLOT( slot_exchange() ) );
 	} else {
 		/// XXX: we could manage this better (later :) )
 		QMessageBox::critical( this, tr( "Can't load theme" ), tr( "Theme " ) + THEME + tr( " has not been loaded successfully" ) );
@@ -110,16 +113,21 @@ ClientInterface::~ClientInterface()
 		actionDisconnect(QUIT_GAME);
 		delete _socket;
 	}
-	if(_config)
+	if( _config ) {
 		delete _config;
+	}
+	
 	delete _game;
-	if(_fight)
+	
+	if( _fight ) {
 		delete _fight;
-	if(_base)
+	}
+	if( _base ) {
 		delete _base;
+	}
 }
 
-void ClientInterface::closeEvent( QCloseEvent* event )
+void ClientInterface::closeEvent( QCloseEvent * event )
 {
 	actionQuit();
 	event->accept();
@@ -165,6 +173,11 @@ void ClientInterface::initActions()
 	_actions.insert( ACTION_FULL, action );
 	sigmap->setMapping( action, ACTION_FULL );
 	connect( action, SIGNAL( activated() ), sigmap, SLOT( map() ) );
+	
+	action = new QAction( tr( "Help" ), tr( "&Help" ), QKeySequence( tr( "Key_F1" ) ), this );
+	_actions.insert( ACTION_HELP, action );
+	sigmap->setMapping( action, ACTION_HELP );
+	connect( action, SIGNAL( activated() ), sigmap, SLOT( map() ) );
 
 	action = new QAction( tr( "Quit" ), tr( "&Quit" ), QKeySequence( tr( "CTRL+Q" ) ), this );
 	_actions.insert( ACTION_QUIT, action );
@@ -186,9 +199,13 @@ void ClientInterface::initMenuBar()
 	_actions[ ACTION_MINIMAP ]->addTo( menuGame );
 	_actions[ ACTION_TAB ]->addTo( menuGame );
 	_actions[ ACTION_FULL ]->addTo( menuGame );
+	
+	QPopupMenu * menuHelp = new QPopupMenu();
+	_actions[ ACTION_HELP ]->addTo( menuHelp );
 
 	menuBar()->insertItem( tr( "&File" ), menuFile );
 	menuBar()->insertItem( tr( "&Game" ), menuGame );
+	menuBar()->insertItem( tr( "&Help" ), menuHelp );
 }
 
 void ClientInterface::slot_action( int num )
@@ -212,12 +229,39 @@ void ClientInterface::slot_action( int num )
 	case ACTION_FULL:
 		actionFullScreen();
 		break;
+	case ACTION_HELP:
+		actionHelp();
+		break;
 	case ACTION_QUIT:
 		actionQuit();
 		break;
 	}
 }
 
+void ClientInterface::slot_exchange()
+{
+	if(_base)
+		_base->reinit();
+}
+
+void ClientInterface::slot_endGame()
+{
+	static int count = 0;
+	_state = SG_MAP;
+	_game->show();
+	
+	if(_fight){
+		_fight->hide();
+		delete _fight;
+		_fight = 0;
+	}
+	if(_base){
+		_base->hide();
+		delete _base;
+		_base = 0;
+	}
+}
+
 void ClientInterface::actionFastConnect()
 {
 	int pid; 
@@ -361,6 +405,15 @@ void ClientInterface::actionFullScreen()
 	}
 }
 
+void ClientInterface::actionHelp()
+{
+	if( ! _help ) {
+		_help = new DisplayHelp( this );
+	}
+	_help->show();
+}
+
+
 void ClientInterface::actionQuit()
 {
 	_game->endGame();
