@@ -5,9 +5,9 @@
 ** clientInterface.h
 ** Manages the whole game
 **
-** Version : $Id: clientInterface.h,v 1.14 2004/09/12 15:06:28 lusum Exp $
+** Version : $Id: clientInterface.h,v 1.17 2004/12/11 13:39:04 lusum Exp $
 **
-** Author(s) : Pascal Audoux
+** Author(s) : Pascal Audoux - Sardi Carlo
 **
 ** Date : 17/08/2000
 **
@@ -36,6 +36,7 @@
 #include <qptrvector.h>
 #include <qstring.h>
 // application specific includes
+#include "libCommon/displayHelp.h"
 #include "libCommon/genericBuilding.h"
 #include "libClient/player.h"
 #include "libClient/game.h"
@@ -81,6 +82,10 @@ public slots:
 	/** when connection is closed by server **/
 	void slot_connectionClosed();
 	
+	void slot_endGame();
+	
+	void slot_exchange();
+	
 	void slot_hostfound();
 	
 	/** manage connection's errors **/
@@ -106,6 +111,7 @@ private:
 		ACTION_MINIMAP,
 		ACTION_TAB,
 		ACTION_FULL,
+		ACTION_HELP,
 		ACTION_QUIT,
 
 		NB_ACTIONS
@@ -152,6 +158,8 @@ private:
 	
 	void actionFullScreen();
 
+	void actionHelp();
+	
 	void actionQuit();
 
 	Game * _game;
@@ -163,6 +171,7 @@ private:
 	bool _mini;
 	bool _tab,_full;
 	QPtrVector<QAction> _actions;
+	DisplayHelp * _help;
 
 	StateGame _state;
 };
