@@ -5,7 +5,7 @@
 ** conf.h
 ** this file contains all generic datas
 **
-** Version : $Id: conf.h,v 1.2 2004/04/04 17:15:07 audoux Exp $
+** Version : $Id: conf.h,v 1.4 2004/08/22 13:51:58 audoux Exp $
 **
 ** Author(s) : Pascal Audoux - Cyrille Verrier
 **
@@ -34,10 +34,16 @@
 
 const QString IMAGE_DEFAULT_PATH( "images/" );
 
-const QString SOUND_DEFAULT_PATH( "musics/" );
+const QString MUSIC_DEFAULT_PATH( "musics/" );
+
+const QString SOUND_DEFAULT_PATH( "sounds/" );
 
 const QString DATA_DEFAULT_PATH( "data/" );
 
+const QString CAMPAIGN_DEFAULT_PATH( "campaigns/" );
+
+const QString SCENARIO_DEFAULT_PATH( "scenarii/" );
+
 const QString THEME_DEFAULT( "medieval" );
 
 enum CanvasHeight {
