@@ -6,6 +6,13 @@
         <translation type="unfinished"></translation>
     </message>
 </context>
+<context>
+    <name>DecorationSelection</name>
+    <message>
+        <source>Auto-path</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>DisplayQuests</name>
     <message>
@@ -71,6 +78,25 @@
         <translation type="unfinished"></translation>
     </message>
 </context>
+<context>
+    <name>GeneralPropertiesBase</name>
+    <message>
+        <source>Owner:</source>
+        <translation type="unfinished">Besitzer: </translation>
+    </message>
+    <message>
+        <source>Buildings</source>
+        <translation type="unfinished">Gebäude</translation>
+    </message>
+    <message>
+        <source>Name: </source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>None</source>
+        <translation type="unfinished">Niemand</translation>
+    </message>
+</context>
 <context>
     <name>NewQuestConditionDialog</name>
     <message>
@@ -102,19 +128,27 @@
     </message>
     <message>
         <source>Owner:</source>
-        <translation>Besitzer: </translation>
+        <translation type="obsolete">Besitzer: </translation>
     </message>
     <message>
         <source>Buildings</source>
-        <translation>Gebäude</translation>
+        <translation type="obsolete">Gebäude</translation>
     </message>
     <message>
         <source>Ok</source>
-        <translation>Ok</translation>
+        <translation type="obsolete">Ok</translation>
     </message>
     <message>
         <source>None</source>
-        <translation>Niemand</translation>
+        <translation type="obsolete">Niemand</translation>
+    </message>
+    <message>
+        <source>General</source>
+        <translation type="unfinished">Allgemein</translation>
+    </message>
+    <message>
+        <source>Units</source>
+        <translation type="unfinished">Einheiten</translation>
     </message>
 </context>
 <context>
@@ -199,7 +233,7 @@
     </message>
     <message>
         <source>Behaviour of Creatures: </source>
-        <translation>Verhalten der Kreaturen: </translation>
+        <translation type="obsolete">Verhalten der Kreaturen: </translation>
     </message>
     <message>
         <source>Never flee: </source>
@@ -217,6 +251,22 @@
         <source>Cancel</source>
         <translation type="unfinished">Abbrechen</translation>
     </message>
+    <message>
+        <source>Behaviour of creatures: </source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Growth of creatures: </source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Growth param 0: </source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Growth param 1: </source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>PropertiesEvent</name>
@@ -459,6 +509,29 @@
         <translation type="unfinished">Abbrechen</translation>
     </message>
 </context>
+<context>
+    <name>QuestConditionPlayerProperties</name>
+    <message>
+        <source>Nb lords </source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Nb bases </source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Basename = </source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Ok</source>
+        <translation type="unfinished">Ok</translation>
+    </message>
+    <message>
+        <source>Cancel</source>
+        <translation type="unfinished">Abbrechen</translation>
+    </message>
+</context>
 <context>
     <name>QuestEditor</name>
     <message>
