@@ -304,6 +304,14 @@
         <source>Picture: </source>
         <translation type="unfinished">Bild: </translation>
     </message>
+    <message>
+        <source>X Offset: </source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Y Offset: </source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>EditTroop</name>
@@ -509,7 +517,7 @@
     <name>SectionDecoration</name>
     <message>
         <source>Decoration</source>
-        <translation>Verzierung</translation>
+        <translation type="obsolete">Verzierung</translation>
     </message>
     <message>
         <source>Name: </source>
@@ -523,6 +531,14 @@
         <source>Image: </source>
         <translation>Bild:</translation>
     </message>
+    <message>
+        <source>Decoration group</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Decoration item</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>SectionExperience</name>
@@ -604,12 +620,28 @@
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>Action: </source>
+        <source>Params: </source>
+        <translation type="unfinished">Parameter:</translation>
+    </message>
+    <message>
+        <source>Not yet used</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>Params: </source>
-        <translation type="unfinished">Parameter:</translation>
+        <source>Main Building</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Castle</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Prod Creature</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Market</source>
+        <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
