@@ -129,6 +129,18 @@
         <source>CTRL+S</source>
         <translation>CTRL+S</translation>
     </message>
+    <message>
+        <source>Help</source>
+        <translation>Aide</translation>
+    </message>
+    <message>
+        <source>&amp;Help</source>
+        <translation>&amp;Aide</translation>
+    </message>
+    <message>
+        <source>Key_F1</source>
+        <translation>Key_F1</translation>
+    </message>
 </context>
 <context>
     <name>ConfigConnection</name>
