@@ -100,6 +100,14 @@
         <source>Wrong number of connected players</source>
         <translation>Nombre de joueurs connectés incorrect</translation>
     </message>
+    <message>
+        <source>You have no place for recruiting new creatures</source>
+        <translation>Vous n&apos;avez plus de place pour de nouvelles créatures</translation>
+    </message>
+    <message>
+        <source>You have not enough resources for recruiting this creatures</source>
+        <translation>Vous n&apos;avez pas assez de ressources pour recruter ces créatures</translation>
+    </message>
 </context>
 <context>
     <name>QObject</name>
