@@ -6,6 +6,13 @@
         <translation>Caractéristique</translation>
     </message>
 </context>
+<context>
+    <name>DecorationSelection</name>
+    <message>
+        <source>Auto-path</source>
+        <translation>Automatique</translation>
+    </message>
+</context>
 <context>
     <name>DisplayQuests</name>
     <message>
@@ -71,6 +78,25 @@
         <translation>%d (pondération=%d)</translation>
     </message>
 </context>
+<context>
+    <name>GeneralPropertiesBase</name>
+    <message>
+        <source>Owner:</source>
+        <translation>Possesseur :</translation>
+    </message>
+    <message>
+        <source>Buildings</source>
+        <translation>Bâtiments</translation>
+    </message>
+    <message>
+        <source>Name: </source>
+        <translation>Nom :</translation>
+    </message>
+    <message>
+        <source>None</source>
+        <translation>Aucun</translation>
+    </message>
+</context>
 <context>
     <name>NewQuestConditionDialog</name>
     <message>
@@ -102,19 +128,31 @@
     </message>
     <message>
         <source>Owner:</source>
-        <translation>Possesseur :</translation>
+        <translation type="obsolete">Possesseur :</translation>
     </message>
     <message>
         <source>Buildings</source>
-        <translation>Bâtiments</translation>
+        <translation type="obsolete">Bâtiments</translation>
     </message>
     <message>
         <source>Ok</source>
-        <translation>OkOk</translation>
+        <translation type="obsolete">OkOk</translation>
     </message>
     <message>
         <source>None</source>
-        <translation>Aucun</translation>
+        <translation type="obsolete">Aucun</translation>
+    </message>
+    <message>
+        <source>Name: </source>
+        <translation type="obsolete">Nom :</translation>
+    </message>
+    <message>
+        <source>General</source>
+        <translation>Général</translation>
+    </message>
+    <message>
+        <source>Units</source>
+        <translation>Unités</translation>
     </message>
 </context>
 <context>
@@ -199,7 +237,7 @@
     </message>
     <message>
         <source>Behaviour of Creatures: </source>
-        <translation>Comportement des créatures :</translation>
+        <translation type="obsolete">Comportement des créatures :</translation>
     </message>
     <message>
         <source>Never flee: </source>
@@ -217,6 +255,22 @@
         <source>Cancel</source>
         <translation>Annuler</translation>
     </message>
+    <message>
+        <source>Behaviour of creatures: </source>
+        <translation>Comportement:</translation>
+    </message>
+    <message>
+        <source>Growth of creatures: </source>
+        <translation>Croissance :</translation>
+    </message>
+    <message>
+        <source>Growth param 0: </source>
+        <translation>Param. de croissance 0 :</translation>
+    </message>
+    <message>
+        <source>Growth param 1: </source>
+        <translation>Param. de croissance 1 :</translation>
+    </message>
 </context>
 <context>
     <name>PropertiesEvent</name>
@@ -459,6 +513,29 @@
         <translation>Annuler</translation>
     </message>
 </context>
+<context>
+    <name>QuestConditionPlayerProperties</name>
+    <message>
+        <source>Nb lords </source>
+        <translation>Nb seigneurs</translation>
+    </message>
+    <message>
+        <source>Nb bases </source>
+        <translation>Nb bases</translation>
+    </message>
+    <message>
+        <source>Basename = </source>
+        <translation>Nom = </translation>
+    </message>
+    <message>
+        <source>Ok</source>
+        <translation>Ok</translation>
+    </message>
+    <message>
+        <source>Cancel</source>
+        <translation>Annuler</translation>
+    </message>
+</context>
 <context>
     <name>QuestEditor</name>
     <message>
