@@ -304,6 +304,14 @@
         <source>Picture: </source>
         <translation>Image :</translation>
     </message>
+    <message>
+        <source>X Offset: </source>
+        <translation>Offset X :</translation>
+    </message>
+    <message>
+        <source>Y Offset: </source>
+        <translation>Offset Y :</translation>
+    </message>
 </context>
 <context>
     <name>EditTroop</name>
@@ -509,7 +517,7 @@
     <name>SectionDecoration</name>
     <message>
         <source>Decoration</source>
-        <translation>Décoration</translation>
+        <translation type="obsolete">Décoration</translation>
     </message>
     <message>
         <source>Name: </source>
@@ -523,6 +531,14 @@
         <source>Image: </source>
         <translation>Image :</translation>
     </message>
+    <message>
+        <source>Decoration group</source>
+        <translation>Groupe déco</translation>
+    </message>
+    <message>
+        <source>Decoration item</source>
+        <translation>Objet déco</translation>
+    </message>
 </context>
 <context>
     <name>SectionExperience</name>
@@ -605,12 +621,32 @@
     </message>
     <message>
         <source>Action: </source>
-        <translation>Action:</translation>
+        <translation type="obsolete">Action:</translation>
     </message>
     <message>
         <source>Params: </source>
         <translation>Paramètres :</translation>
     </message>
+    <message>
+        <source>Not yet used</source>
+        <translation>Pas encore utilisé</translation>
+    </message>
+    <message>
+        <source>Main Building</source>
+        <translation>Bâtiment principal</translation>
+    </message>
+    <message>
+        <source>Castle</source>
+        <translation>Château</translation>
+    </message>
+    <message>
+        <source>Prod Creature</source>
+        <translation>Générateur créatures</translation>
+    </message>
+    <message>
+        <source>Market</source>
+        <translation>Marché</translation>
+    </message>
 </context>
 <context>
     <name>SectionLord</name>
