@@ -100,6 +100,14 @@
         <source>Wrong number of connected players</source>
         <translation>Numero di giocatori connessi errato</translation>
     </message>
+    <message>
+        <source>You have no place for recruiting new creatures</source>
+        <translation>Non hai abbatanza spazio per reclutare nuove creature</translation>
+    </message>
+    <message>
+        <source>You have not enough resources for recruiting this creatures</source>
+        <translation>Non hai abbastanza risorse per reclutare questa creature</translation>
+    </message>
 </context>
 <context>
     <name>QObject</name>
@@ -172,39 +180,39 @@
     </message>
     <message>
         <source>Load scenario</source>
-        <translation type="unfinished"></translation>
+        <translation>Carica lo scenario</translation>
     </message>
     <message>
         <source>Load campaign</source>
-        <translation type="unfinished"></translation>
+        <translation>Carica la campagna</translation>
     </message>
     <message>
         <source>Load game</source>
-        <translation type="unfinished"></translation>
+        <translation>Carica il gioco</translation>
     </message>
     <message>
         <source>Save game</source>
-        <translation type="unfinished"></translation>
+        <translation>Salva il gioco</translation>
     </message>
     <message>
         <source>End game</source>
-        <translation type="unfinished"></translation>
+        <translation>Fine gioco</translation>
     </message>
     <message>
         <source>&amp;Quit</source>
-        <translation type="unfinished"></translation>
+        <translation>&amp;Esci</translation>
     </message>
     <message>
         <source>Fill with AI</source>
-        <translation type="unfinished"></translation>
+        <translation>Completa con l&apos;IA</translation>
     </message>
     <message>
         <source>Add AI player</source>
-        <translation type="unfinished"></translation>
+        <translation>Aggiungi un giocatore dell&apos;IA</translation>
     </message>
     <message>
         <source>&amp;Game</source>
-        <translation type="unfinished"></translation>
+        <translation>&amp;Gioco</translation>
     </message>
 </context>
 <context>
