@@ -6,6 +6,13 @@
         <translation>Caratteristica</translation>
     </message>
 </context>
+<context>
+    <name>DecorationSelection</name>
+    <message>
+        <source>Auto-path</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>DisplayQuests</name>
     <message>
@@ -71,6 +78,25 @@
         <translation>%d (peso=%d)</translation>
     </message>
 </context>
+<context>
+    <name>GeneralPropertiesBase</name>
+    <message>
+        <source>Owner:</source>
+        <translation>Proprietario:</translation>
+    </message>
+    <message>
+        <source>Buildings</source>
+        <translation>Edificio</translation>
+    </message>
+    <message>
+        <source>Name: </source>
+        <translation>Nome:</translation>
+    </message>
+    <message>
+        <source>None</source>
+        <translation>Niente</translation>
+    </message>
+</context>
 <context>
     <name>NewQuestConditionDialog</name>
     <message>
@@ -102,19 +128,31 @@
     </message>
     <message>
         <source>Owner:</source>
-        <translation>Proprietario:</translation>
+        <translation type="obsolete">Proprietario:</translation>
     </message>
     <message>
         <source>Buildings</source>
-        <translation>Edificio</translation>
+        <translation type="obsolete">Edificio</translation>
     </message>
     <message>
         <source>Ok</source>
-        <translation>Ok</translation>
+        <translation type="obsolete">Ok</translation>
     </message>
     <message>
         <source>None</source>
-        <translation>Niente</translation>
+        <translation type="obsolete">Niente</translation>
+    </message>
+    <message>
+        <source>Name: </source>
+        <translation type="obsolete">Nome:</translation>
+    </message>
+    <message>
+        <source>General</source>
+        <translation>Generale</translation>
+    </message>
+    <message>
+        <source>Units</source>
+        <translation>Unità</translation>
     </message>
 </context>
 <context>
@@ -199,7 +237,7 @@
     </message>
     <message>
         <source>Behaviour of Creatures: </source>
-        <translation>Comportamento delle creature:</translation>
+        <translation type="obsolete">Comportamento delle creature:</translation>
     </message>
     <message>
         <source>Never flee: </source>
@@ -217,6 +255,22 @@
         <source>Cancel</source>
         <translation>Annulla</translation>
     </message>
+    <message>
+        <source>Behaviour of creatures: </source>
+        <translation>Comportamento delle creature:</translation>
+    </message>
+    <message>
+        <source>Growth of creatures: </source>
+        <translation>Crescita delle creature:</translation>
+    </message>
+    <message>
+        <source>Growth param 0: </source>
+        <translation>Crescita param 0:</translation>
+    </message>
+    <message>
+        <source>Growth param 1: </source>
+        <translation>Crescita param 1:</translation>
+    </message>
 </context>
 <context>
     <name>PropertiesEvent</name>
@@ -459,6 +513,29 @@
         <translation>Annulla</translation>
     </message>
 </context>
+<context>
+    <name>QuestConditionPlayerProperties</name>
+    <message>
+        <source>Nb lords </source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Nb bases </source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Basename = </source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Ok</source>
+        <translation type="unfinished">Ok</translation>
+    </message>
+    <message>
+        <source>Cancel</source>
+        <translation type="unfinished">Annulla</translation>
+    </message>
+</context>
 <context>
     <name>QuestEditor</name>
     <message>
@@ -495,11 +572,11 @@
     </message>
     <message>
         <source>Fail condition: </source>
-        <translation>Condizione di successo:</translation>
+        <translation>Condizione di fallimento:</translation>
     </message>
     <message>
         <source>Success condition: </source>
-        <translation>Condizione di fallimento:</translation>
+        <translation>Condizione di successo:</translation>
     </message>
 </context>
 <context>
