@@ -304,6 +304,14 @@
         <source>Picture: </source>
         <translation>Immagine:</translation>
     </message>
+    <message>
+        <source>X Offset: </source>
+        <translation>Scostamento X:</translation>
+    </message>
+    <message>
+        <source>Y Offset: </source>
+        <translation>Scostamento Y:</translation>
+    </message>
 </context>
 <context>
     <name>EditTroop</name>
@@ -509,7 +517,7 @@
     <name>SectionDecoration</name>
     <message>
         <source>Decoration</source>
-        <translation>Decorazione</translation>
+        <translation type="obsolete">Decorazione</translation>
     </message>
     <message>
         <source>Name: </source>
@@ -523,6 +531,14 @@
         <source>Image: </source>
         <translation>Immagine:</translation>
     </message>
+    <message>
+        <source>Decoration group</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Decoration item</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>SectionExperience</name>
@@ -601,12 +617,32 @@
     </message>
     <message>
         <source>Action: </source>
-        <translation>Azione:</translation>
+        <translation type="obsolete">Azione:</translation>
     </message>
     <message>
         <source>Params: </source>
         <translation>Parametri:</translation>
     </message>
+    <message>
+        <source>Not yet used</source>
+        <translation>Non ancora usato</translation>
+    </message>
+    <message>
+        <source>Main Building</source>
+        <translation>Edificio principale</translation>
+    </message>
+    <message>
+        <source>Castle</source>
+        <translation>Castello</translation>
+    </message>
+    <message>
+        <source>Prod Creature</source>
+        <translation>Produce Creature</translation>
+    </message>
+    <message>
+        <source>Market</source>
+        <translation>Mercato</translation>
+    </message>
 </context>
 <context>
     <name>SectionLord</name>
