@@ -100,6 +100,14 @@
         <source>Wrong number of connected players</source>
         <translation>Неверное количество подключившихся игроков</translation>
     </message>
+    <message>
+        <source>You have no place for recruiting new creatures</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>You have not enough resources for recruiting this creatures</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>QObject</name>
