@@ -6,6 +6,13 @@
         <translation>Персонаж</translation>
     </message>
 </context>
+<context>
+    <name>DecorationSelection</name>
+    <message>
+        <source>Auto-path</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>DisplayQuests</name>
     <message>
@@ -71,6 +78,25 @@
         <translation>%d (ширина=%d)</translation>
     </message>
 </context>
+<context>
+    <name>GeneralPropertiesBase</name>
+    <message>
+        <source>Owner:</source>
+        <translation type="unfinished">Владелец:</translation>
+    </message>
+    <message>
+        <source>Buildings</source>
+        <translation type="unfinished">Строения</translation>
+    </message>
+    <message>
+        <source>Name: </source>
+        <translation type="unfinished">Название:</translation>
+    </message>
+    <message>
+        <source>None</source>
+        <translation type="unfinished">Нет</translation>
+    </message>
+</context>
 <context>
     <name>NewQuestConditionDialog</name>
     <message>
@@ -102,19 +128,31 @@
     </message>
     <message>
         <source>Owner:</source>
-        <translation>Владелец:</translation>
+        <translation type="obsolete">Владелец:</translation>
     </message>
     <message>
         <source>Buildings</source>
-        <translation>Строения</translation>
+        <translation type="obsolete">Строения</translation>
     </message>
     <message>
         <source>Ok</source>
-        <translation>Ок</translation>
+        <translation type="obsolete">Ок</translation>
     </message>
     <message>
         <source>None</source>
-        <translation>Нет</translation>
+        <translation type="obsolete">Нет</translation>
+    </message>
+    <message>
+        <source>Name: </source>
+        <translation type="obsolete">Название:</translation>
+    </message>
+    <message>
+        <source>General</source>
+        <translation type="unfinished">Общие</translation>
+    </message>
+    <message>
+        <source>Units</source>
+        <translation type="unfinished">Юниты</translation>
     </message>
 </context>
 <context>
@@ -199,7 +237,7 @@
     </message>
     <message>
         <source>Behaviour of Creatures: </source>
-        <translation>Поведение созданий:</translation>
+        <translation type="obsolete">Поведение созданий:</translation>
     </message>
     <message>
         <source>Never flee: </source>
@@ -217,6 +255,22 @@
         <source>Cancel</source>
         <translation>Отмена</translation>
     </message>
+    <message>
+        <source>Behaviour of creatures: </source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Growth of creatures: </source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Growth param 0: </source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Growth param 1: </source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>PropertiesEvent</name>
@@ -459,6 +513,29 @@
         <translation>Отмена</translation>
     </message>
 </context>
+<context>
+    <name>QuestConditionPlayerProperties</name>
+    <message>
+        <source>Nb lords </source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Nb bases </source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Basename = </source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Ok</source>
+        <translation type="unfinished">Ок</translation>
+    </message>
+    <message>
+        <source>Cancel</source>
+        <translation type="unfinished">Отмена</translation>
+    </message>
+</context>
 <context>
     <name>QuestEditor</name>
     <message>
