@@ -304,6 +304,14 @@
         <source>Picture: </source>
         <translation>Изображение:</translation>
     </message>
+    <message>
+        <source>X Offset: </source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Y Offset: </source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>EditTroop</name>
@@ -509,7 +517,7 @@
     <name>SectionDecoration</name>
     <message>
         <source>Decoration</source>
-        <translation>Декорация</translation>
+        <translation type="obsolete">Декорация</translation>
     </message>
     <message>
         <source>Name: </source>
@@ -523,6 +531,14 @@
         <source>Image: </source>
         <translation>Изображение:</translation>
     </message>
+    <message>
+        <source>Decoration group</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Decoration item</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>SectionExperience</name>
@@ -601,12 +617,32 @@
     </message>
     <message>
         <source>Action: </source>
-        <translation>Действие:</translation>
+        <translation type="obsolete">Действие:</translation>
     </message>
     <message>
         <source>Params: </source>
         <translation>Параметры:</translation>
     </message>
+    <message>
+        <source>Not yet used</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Main Building</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Castle</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Prod Creature</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Market</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>SectionLord</name>
