@@ -5,7 +5,7 @@
 ** building.cpp
 ** manages building
 **
-** Version : $Id: building.cpp,v 1.2 2004/09/12 18:21:43 audoux Exp $
+** Version : $Id: building.cpp,v 1.3 2004/11/29 19:40:47 lusum Exp $
 **
 ** Author(s) : Pascal Audoux
 **
@@ -97,7 +97,7 @@ Building::Building( QCanvas * canvas )
 void Building::setPosition( GenericCell * cell )
 {
 	GenericBuilding::setPosition( cell );
-	GraphicalBuilding::setPosition( (Cell *)cell );
+	GraphicalBuilding::setPosition( (Cell *)cell , ( 4 - getDoorRow() ), ( 0 - getDoorCol() ));
 	//cell->setBuilding( this );
 }
 
