@@ -5,9 +5,9 @@
 ** displayBase.cpp
 ** inside the base
 **
-** Version : $Id: displayBase.cpp,v 1.13 2004/10/06 21:00:12 audoux Exp $
+** Version : $Id: displayBase.cpp,v 1.22 2004/12/13 15:14:59 lusum Exp $
 **
-** Author(s) : Pascal Audoux
+** Author(s) : Pascal Audoux - Sardi Carlo
 **
 ** Date : 03/09/2000
 **
@@ -64,8 +64,8 @@ DisplayBase::DisplayBase( QWidget * parent, const char * name )
 	_base = 0;
 	_socket = 0;
 	_game = 0;
+	_dialog = 0;
 	
-	_mprices = new PriceMarket();
 	_inside = new InsideBase( this );	
 	
 	_panel = new BaseRightPanel( this );
@@ -97,6 +97,10 @@ DisplayBase::DisplayBase( QWidget * parent, const char * name )
 	//connect( _baseLords, SIGNAL( sig_exchange( bool ) ), _baseButtons, SLOT( slot_exchange( bool ) ) );
 }
 
+DisplayBase::~DisplayBase()
+{
+}
+
 void DisplayBase::handleSocket()
 {
 	_game->handleSocket();
@@ -125,6 +129,8 @@ void DisplayBase::handleSocket()
 					_inside->delBuilding( level );
 				}
 			}
+			if(_dialog)
+				_dialog->updateView();
 		} else if( ( _socket->getCla2() == C_MOD_BASE ) && ( _socket->getCla3() == C_BASE_UNIT ) ) {
 			reinit();
 		}
@@ -155,18 +161,18 @@ void DisplayBase::slot_building( GenericInsideBuilding * building )
 		InsideBuildingModel * model = DataTheme.bases.at( _base->getRace() )->getBuildingModel( building->getLevel() );
 		if( model->getAction() ) {
 			switch( model->getAction()->getType() ) {
-			case 0:
+			case INSIDE_NONE:
 				break;
-			case 1:
+			case INSIDE_VILLAGE:
 				actionAllBuildings();
 				break;
-			case 2:
+			case INSIDE_CASTLE:
 				actionAllCreatures();
 				break;
-			case 3:
+			case INSIDE_CREA:
 				actionSomeCreatures( building );
 				break;
-			case 4:
+			case INSIDE_MARKET:
 				actionMarket();
 				break;
 			default:
@@ -179,16 +185,21 @@ void DisplayBase::slot_building( GenericInsideBuilding * building )
 
 void DisplayBase::actionAllBuildings()
 {
-	InsideActionAllBuildings dialog( _base );
-	dialog.setSocket( _socket );
-	dialog.setPlayer( _player );
-	dialog.exec();
+	_dialog = new InsideActionAllBuildings( _base );
+	if(_dialog){
+		_dialog->setSocket( _socket );
+		_dialog->setPlayer( _player );
+		_dialog->exec();
+		delete _dialog;
+		_dialog = 0;
+	}
 }
 
 void DisplayBase::actionAllCreatures()
 {
-	DisplayCreatureBase creatures( this );
-	//dialog.setSocket( _socket );
+	DisplayCreatureBase creatures( _base, this );
+	creatures.initSocket( _socket );
+	creatures.init( _player );
 	creatures.exec();
 }
 
@@ -203,7 +214,6 @@ void DisplayBase::actionSomeCreatures( GenericInsideBuilding * building )
 			int race = action->getParam( 0 );
 			int level = action->getParam( 1 );
 			dialog.init( _player, _base, DataTheme.creatures.at( race, level ) );
-			//dialog.setSocket( _socket );
 			if( dialog.exec() ) {
 				// try to buy some creature
 			}
@@ -214,29 +224,8 @@ void DisplayBase::actionSomeCreatures( GenericInsideBuilding * building )
 void DisplayBase::actionMarket()
 {
 	Market mark( this );
-	int cupr,tmpr;
-	uint nbRes = DataTheme.resources.count();
 
-	cupr = 10000;	
-
-	for( uint i = 0; i < nbRes; i++ ) {
-		uint nbases = _player->numBase();
-		for( uint j = 0 ; j < nbases ; j++){
-			PriceMarket * price = DataTheme.bases.at( _player->getBase( j )->getRace())->getPriceMarket();
-			tmpr= price->getResourcePrice( i ) ;
-			if( tmpr < cupr ) {
-				cupr = tmpr;
-			}
-		}
-		if(cupr==10000){
-			cupr=1;
-		}
-		_mprices->setResourcePrice(i,cupr);
-		cupr = 10000;
-	}
-
-
-	mark.setPrices( _mprices );
+	mark.setPrices( _player->getPriceMarket());
 	mark.initSocket( _socket );
 	mark.exec();
 	reinit();
@@ -251,7 +240,7 @@ void DisplayBase::setPlayer( Player * player )
 void DisplayBase::setBase( GenericBase * base )
 {
 	_base = base;
-	/// XXX: _baseSummary->setBase( base );
+	//_baseSummary->setBase( base );
 	//_baseLords->setBase( base );
 	_panel->setBase( base );
 	_inside->setBase( base );
@@ -290,6 +279,7 @@ BaseRightPanel::BaseRightPanel( QWidget * parent, const char * name )
 	_player = 0;
 	_socket = 0;
 	_base = 0;
+	_displayLords = 0;
 	_pbLord = new QPushButton( this );
 	_pbLord->setFixedSize( 60, 60 );
 	
@@ -328,11 +318,13 @@ BaseRightPanel::BaseRightPanel( QWidget * parent, const char * name )
 
 void BaseRightPanel::slot_lords()
 {
-	DisplayBaseLord displayLords( this );
+	_displayLords = new DisplayBaseLord( this );
 	/// XXX: could be gathered
-	displayLords.init( _player, _base, _socket );
-	displayLords.exec();
+	_displayLords->init( _player, _base, _socket );
+	_displayLords->exec();
 	reinit();
+	delete _displayLords;
+	_displayLords = 0;
 }
 	
 void BaseRightPanel::slot_info()
@@ -380,6 +372,8 @@ void BaseRightPanel::reinit()
 	}
 	
 	_lordLabel->setText( text );
+	if(_displayLords)
+		_displayLords->reinit();
 }
 
 //
@@ -391,6 +385,7 @@ BaseSummary::BaseSummary( QWidget * parent, const char * name )
 {
 	_base = 0;
 	int i;
+	_popul = new QLabel( this );
 
 	QVBoxLayout * layout = new QVBoxLayout( this );
 	
@@ -399,6 +394,8 @@ BaseSummary::BaseSummary( QWidget * parent, const char * name )
 	lay1->addWidget( _ress );
 	
 	layout->addLayout( lay1 );
+	layout->addStretch( 2 );
+	layout->addWidget( _popul );
 	
 	QHBoxLayout * lay2 = new QHBoxLayout();
 	lay2->addStretch( 1 );
@@ -439,12 +436,13 @@ void BaseSummary::setPlayer( Player * player )
 void BaseSummary::reinit()
 {
 	_ress->reinit();
+	_popul->setText(QString("  Population %1 ").arg(_base->getPopulation(),10,10));
 }
 
-void BaseSummary::setBase( GenericBase * /*base*/ )
+void BaseSummary::setBase( GenericBase * base )
 {
-	/// XXX: TODO
-	logEE( "not yet implemented" );
+	_base = base;
+	reinit();
 }
 
 //
@@ -605,25 +603,10 @@ void BaseLords::exchangeLords()
 
 void BaseLords::exchangeUnitsGV()
 {
-	GenericFightUnit * uni1 = _base->getGarrisonUnit( _unitGarrison );
-	GenericFightUnit * uni2 = _base->getVisitorUnit( _unitVisitor );
 	GenericLord * garrison = _base->getGarrisonLord();
 	GenericLord * visitor = _base->getVisitorLord();
 
 	if(visitor){
-		if( uni1 && uni2 ) {
-			if( uni1->getCreature() != uni2->getCreature() ) {
-				_base->setVisitorUnit( _unitVisitor, uni1 );
-				_base->setGarrisonUnit( _unitGarrison, uni2 );
-			} else {
-				uni2->addNumber( uni1->getNumber() );
-				_base->setGarrisonUnit( _unitGarrison, 0 );
-				delete uni1;
-			}
-		} else {
-			_base->setVisitorUnit( _unitVisitor, uni1 );
-			_base->setGarrisonUnit( _unitGarrison, uni2 );
-		}
 		if(garrison){
 			_socket->sendExchangeUnit( garrison, _unitGarrison, visitor, _unitVisitor );
 		} else {
@@ -636,22 +619,6 @@ void BaseLords::exchangeUnitsGV()
 	
 void BaseLords::exchangeUnitsVG()
 {
-	GenericFightUnit * uni1 = _base->getGarrisonUnit( _unitGarrison );
-	GenericFightUnit * uni2 = _base->getVisitorUnit( _unitVisitor );
-	
-	if( uni1 && uni2 ) {
-		if( uni1->getCreature() != uni2->getCreature() ) {
-			_base->setVisitorUnit( _unitVisitor, uni1 );
-			_base->setGarrisonUnit( _unitGarrison, uni2 );
-		} else {
-			uni1->addNumber( uni2->getNumber() );
-			_base->setVisitorUnit( _unitVisitor, 0 );
-			delete uni2;
-		}
-	} else {
-		_base->setVisitorUnit( _unitVisitor, uni1 );
-		_base->setGarrisonUnit( _unitGarrison, uni2 );
-	}
 	GenericLord * garrison = _base->getGarrisonLord();
 	GenericLord * visitor = _base->getVisitorLord();
 	if(garrison){
@@ -671,27 +638,12 @@ void BaseLords::exchangeUnitsGG( int u1, int u2 )
 		return;
 	}
 	
-	GenericFightUnit * uni1 = _base->getGarrisonUnit( u1 );
-	GenericFightUnit * uni2 = _base->getGarrisonUnit( u2 );
-
-	if( uni1 && uni2 ) {
-		if( uni1->getCreature() != uni2->getCreature() ) {
-			_base->setGarrisonUnit( u2, uni1 );
-			_base->setGarrisonUnit( u1, uni2 );
-		} else {
-			uni2->addNumber( uni1->getNumber() );
-			_base->setGarrisonUnit( u1, 0 );
-			delete uni1;
-		}
-	} else {
-		_base->setGarrisonUnit( u2, uni1 );
-		_base->setGarrisonUnit( u1, uni2 );
-	}
 	GenericLord * garrison = _base->getGarrisonLord();
 	if(garrison){
 		_socket->sendExchangeUnit( garrison, u1, garrison, u2 );
+	} else {
+		_socket->sendExchangeBaseUnit( _base, u1, 0, u2 );
 	}
-		_socket->sendExchangeBaseUnit( _base, _unitGarrison, 0, _unitVisitor );
 	_garrison->reinit();
 }
 
@@ -701,22 +653,6 @@ void BaseLords::exchangeUnitsVV( int u1, int u2 )
 		return;
 	}
 
-	GenericFightUnit * uni1 = _base->getVisitorUnit( u1 );
-	GenericFightUnit * uni2 = _base->getVisitorUnit( u2 );
-	
-	if( uni1 && uni2 ) {
-		if( uni1->getCreature() != uni2->getCreature() ) {
-			_base->setVisitorUnit( u2, uni1 );
-			_base->setVisitorUnit( u1, uni2 );
-		} else {
-			uni2->addNumber( uni1->getNumber() );
-			_base->setVisitorUnit( u1, 0 );
-			delete uni1;
-		}
-	} else {
-		_base->setVisitorUnit( u2, uni1 );
-		_base->setVisitorUnit( u1, uni2 );	
-	}
 	GenericLord * visitor = _base->getVisitorLord();
 	_socket->sendExchangeUnit( visitor, u1, visitor, u2 );
 	
@@ -825,6 +761,11 @@ void DisplayBaseLord::init( Player * player, GenericBase * base, AttalSocket * s
 	_widget->setBase( base );
 }
 
+void DisplayBaseLord::reinit()
+{
+ _widget->reinit();
+}
+
 //
 // ----- BaseButtons -----
 //
