@@ -5,9 +5,9 @@
 ** displayBase.h
 ** inside the base
 **
-** Version : $Id: displayBase.h,v 1.5 2004/10/03 19:03:25 audoux Exp $
+** Version : $Id: displayBase.h,v 1.9 2004/12/11 13:39:04 lusum Exp $
 **
-** Author(s) : Pascal Audoux
+** Author(s) : Pascal Audoux - Sardi Carlo
 **
 ** Date : 03/09/2000
 **
@@ -53,7 +53,8 @@ class GenericLord;
 class GenericInsideBuilding;
 class InsideBase;
 class UnitSummary;
-
+class InsideActionAllBuildings;
+class DisplayBaseLord;
 
 /*              ------------------------------
  *                         DisplayBase
@@ -69,6 +70,8 @@ public:
 	/** Construtor */
 	DisplayBase( QWidget * parent = 0, const char * name = 0 );
 
+	~DisplayBase();
+
 	/** Initialize the player */
 	void setPlayer( Player * player );
 
@@ -108,10 +111,11 @@ private:
 	GenericBase * _base;
 	AttalSocket * _socket;
 	
-	PriceMarket * _mprices;
 	InsideBase * _inside;
 	BaseRightPanel * _panel;
+	BaseSummary * _baseSummary;
 	Game * _game;
+	InsideActionAllBuildings * _dialog;
 };
 
 class BaseRightPanel : public QWidget
@@ -144,6 +148,7 @@ protected:
 	GenericBase * _base;
 	Player * _player;
 	AttalSocket * _socket;
+	DisplayBaseLord * _displayLords;
 };
 
 /** Widget for displaying a summary of the base info */
@@ -166,6 +171,7 @@ private:
 	GenericBase * _base;
 	Player * _player;
 	RessourceWin * _ress;
+	QLabel * _popul;
 };
 
 class DisplayBaseInfo : public QDialog
@@ -254,6 +260,8 @@ public:
 	
 	void init( Player * player, GenericBase * base, AttalSocket * socket );
 
+	void reinit();
+
 protected:
 	BaseLords * _widget;
 };
