@@ -5,7 +5,7 @@
 ** displayCreature.cpp
 ** widget for displaying, buying cretaures
 **
-** Version : $Id: displayCreature.cpp,v 1.8 2004/07/28 21:07:04 lusum Exp $
+** Version : $Id: displayCreature.cpp,v 1.10 2004/11/16 19:29:41 lusum Exp $
 **
 ** Author(s) : Pascal Audoux
 **
@@ -73,6 +73,7 @@ DisplayCreature::DisplayCreature( QWidget * parent, const char * name )
 
 void DisplayCreature::setCreature( int race, int level )
 {
+	_creature = DataTheme.creatures.at( race , level );
 	_creaturePres->setCreature( race, level );
 	_creatureInfo->setCreature( race, level );
 }
@@ -117,7 +118,7 @@ CreaturePresentation::CreaturePresentation( QWidget * parent, const char * name
 void CreaturePresentation::setCreature( int race, int level )
 {
 	Creature * crea = DataTheme.creatures.at( race, level );
-
+	
 	_name->setText( crea->getName() );
 	QString pic = IMAGE_PATH + "units/face_";
 	pic += QString::number( race ) + "_" + QString::number( level ) + ".png";
@@ -323,9 +324,28 @@ void BuyCreature::init( GenericPlayer * player, GenericBase * base, Creature * c
 	//_cost->init( creature, prodPlayer );
 }
 
-void BuyCreature::slot_all()
+void BuyCreature::reinit()
 {
+	int prodBase = _base->getCreatureProduction( _creature );
+	int prodPlayer = _player->computeBuyCreatureMax( _creature );
+	//logDD(" creature %p, prodBase%d, prodPlayer %d", creature, prodBase, prodPlayer );
+	_cost->setValue( std::min( prodBase, prodPlayer ));
+}
 
+void BuyCreature::slot_all()
+{ 
+	int prodBase = _base->getCreatureProduction( _creature );
+	int prodPlayer = _player->computeBuyCreatureMax( _creature );
+	int cost = std::min( prodBase, prodPlayer );
+	if( _base->canAddGarrison( _creature ) ) {
+		if( _player->canBuy( _creature, cost ) ) {
+			_socket->sendBaseUnit( _base, _creature, cost );
+			_base->buyCreature( _creature, cost );
+			reinit();
+		}
+	} else {
+		QMessageBox::warning( this, "No room left", "No room left for a new unit" );
+	}
 }
 
 void BuyCreature::slot_buy()
@@ -335,6 +355,7 @@ void BuyCreature::slot_buy()
 			if( _player->canBuy( _creature, _cost->getNumber() ) ) {
 				_socket->sendBaseUnit( _base, _creature, _cost->getNumber() );
 				_base->buyCreature( _creature, _cost->getNumber() );
+				reinit();
 			}
 		}
 	} else {
@@ -376,6 +397,12 @@ int ComputeCost::getNumber()
 	return _bar->value();
 }
 
+void ComputeCost::setValue( int value )
+{
+	_totalCost->setNumber( value );
+	_bar->setMaxValue( value );
+}
+
 void ComputeCost::init( Creature * creature, int max )
 {
 	_max = max;
@@ -390,6 +417,9 @@ void ComputeCost::slot_newValue( int value )
 	_totalCost->setNumber( value );
 }
 
+
+
+
 //
 // ----- CreatureCost -----
 //
