@@ -5,7 +5,7 @@
 ** displayLord.h
 ** show infos about Lord
 **
-** Version : $Id: displayLord.h,v 1.3 2004/07/31 19:29:46 audoux Exp $
+** Version : $Id: displayLord.h,v 1.5 2004/11/01 14:39:37 lusum Exp $
 **
 ** Author(s) : Pascal Audoux
 **
@@ -49,6 +49,7 @@ class DisplayGeneral;
 class DisplayListPanel;
 class DisplayListLord;
 class UnitExchange;
+class AttalSocket;
 
 /*              ------------------------------
  *                         DisplayLord
@@ -76,6 +77,8 @@ public:
 	/** Update info displayed */
 	void reupdate();
 
+	void initSocket( AttalSocket * socket );
+
 public slots:
 	/** Slot if lord clicked */
 	void slot_lord( int num );
@@ -87,6 +90,7 @@ private:
 	DisplayGeneral * _dispGeneral;
 	DisplayArtefacts * _dispArtefact;
 	DisplayListPanel * _dispList;
+	AttalSocket * _socket;
 };
 
 /** General information about lord */
@@ -120,6 +124,8 @@ public:
 
 	/** Reinit info displayed */
 	void reinit();
+	
+	QString showDescription(GenericFightUnit * unit);
 
 	/** Update info displayed */
 	void reupdate() { reinit(); }
@@ -132,6 +138,10 @@ public:
 
 	/** Deselect unit */
 	void deselectUnit();
+	
+	void initSocket( AttalSocket * socket ) {
+		_socket = socket;
+	}
 
 public slots:
 	/** Slot for 'Exchange' button */
@@ -150,6 +160,7 @@ private:
 	QLabel * _numUnit[ MAX_UNIT ];
 	QPushButton * _dispo[ 4 ], * _butExchange;
 	UnitExchange * _unitExchange;
+	AttalSocket * _socket;
 	int _unit;
 	bool _exch;
 };
