@@ -5,9 +5,9 @@
 ** game.cpp
 ** Manages the whole game
 **
-** Version : $Id: game.cpp,v 1.46 2004/10/08 23:06:34 audoux Exp $
+** Version : $Id: game.cpp,v 1.63 2004/12/24 18:28:18 lusum Exp $
 **
-** Author(s) : Pascal Audoux - Carlo
+** Author(s) : Pascal Audoux - Sardi Carlo
 **
 ** Date : 17/08/2000
 **
@@ -46,15 +46,18 @@
 #include "libCommon/pathFinder.h"
 #include "libCommon/technic.h"
 #include "libCommon/unit.h"
+#include "libCommon/priceMarket.h"
 
 #include "libFight/fightUnit.h"
 
 #include "libClient/askChest.h"
+#include "libClient/askDialog.h"
 #include "libClient/bonus.h"
 #include "libClient/building.h"
 #include "libClient/chatWidget.h"
 #include "libClient/chest.h"
 #include "libClient/displayLord.h"
+#include "libClient/displayBase.h"
 #include "libClient/event.h"
 #include "libClient/gainLevel.h"
 #include "libClient/gameInfo.h"
@@ -179,7 +182,7 @@ void Game::slot_mouseMoved( Cell *cell )
 			emit sig_statusMsg( msg );
 			setCursor( waitCursor );
 		} else if( cell->getBase() ) { 
-			msg = tr( "Base " ) + cell->getBase()->getName() + QString(tr("  population: %1 ")).arg(cell->getBase()->getPopulation());
+			msg = tr( "Base " ) + cell->getBase()->getName() + QString(tr(" - population: %1 ")).arg(cell->getBase()->getPopulation());
 			emit sig_statusMsg( msg );
 			setCursor( waitCursor );
 		} else if( cell->getBuilding() ) {
@@ -233,10 +236,10 @@ void Game::handleClickNothing( Cell * cell )
 	
 	if( lord ) {
 		if( _player->hasLord( lord ) ) {
-			_control->reinit();
 			_scrLord->reinit();
 			_scrBase->reinit();
 			_player->setSelectedLord( lord );
+			_view->goToPosition((Cell *) cell);
 		}
 		return;
 	}
@@ -246,9 +249,9 @@ void Game::handleClickNothing( Cell * cell )
 	if( base ) {
 		if( _player->hasBase( base ) ) {
 			_player->setSelectedBase( base );
-			_control->reinit();
 			_scrLord->reinit();
 			_scrBase->reinit();
+			_view->goToPosition((Cell *) cell);
 		}
 		return;
 	}
@@ -259,6 +262,9 @@ void Game::handleClickLord( Cell * cell )
 	GenericLord * selectedLord = _player->getSelectedLord();
 		
 	if( selectedLord && ( cell->getCoeff() >= 0 ) ) {
+		if(cell->getLord()){
+			_view->goToPosition((Cell *) cell);
+		}
 		if( ((Lord*)selectedLord)->getDestination() != (GenericCell*)cell ) {
 			((Lord*)selectedLord)->computePath( (GenericCell*)cell );
 		} else {
@@ -281,7 +287,6 @@ void Game::handleClickBase( Cell * cell )
 				return;
 			} else {
 				_player->setSelectedBase( base );
-				_control->reinit();
 				_scrLord->reinit();
 				_scrBase->reinit();
 				return;
@@ -381,9 +386,12 @@ void Game::beginGame( int nb )
 void Game::endGame()
 {
 	uint i, j;
+	emit sig_endGame();
 	_control->disableGame();
 	_scrLord->setEnabled( false );
 	_scrBase->setEnabled( false );
+	_scrLord->deselect();
+	_scrBase->deselect();
 
 	for( i = 0; i < (uint) _map->getHeight(); i++ ) {
 		for( j = 0; j < (uint) _map->getWidth(); j++ ) {
@@ -419,6 +427,10 @@ void Game::endGame()
 	_resourceBar->reinit();
 	reInitLords();
 	_state = MS_NOTHING;
+	if( _dispLord ) {
+		delete _dispLord;
+		_dispLord = 0;
+	}
 }
 
 void Game::handleSocket()
@@ -591,6 +603,10 @@ void Game::socketMvt()
 			}
 
 			theLord->moveTo( _map->at( row, col ) );
+			if(_map->at( row, col )->getType() != 0){
+				_view->goToPosition((Cell *) _map->at( row, col ));
+						
+			}
 			if( _map->computeMinimalNextCost( theLord ) > theLord->getBaseCharac( MOVE ) ) {
 				theLord->setBaseCharac( MOVE, 0 );
 			}
@@ -627,12 +643,16 @@ void Game::socketExchange()
 		_lordExchange->initSocket( _socket );
 		_lordExchange->initLords( lord1, lord2 );
 		_lordExchange->exec();
+		/// XXX: why deleting and not only clearing ??
 		delete _lordExchange;
 		_lordExchange = 0;
 		} break;
 	case C_EXCH_UNIT:
 		exchangeUnits();
 		break;
+	case C_EXCH_ARTEFACT:
+		exchangeArtefact();
+		break;
 	case C_EXCH_BASEUNITCL:
 		exchangeBaseUnits();
 		break;
@@ -664,7 +684,7 @@ void Game::exchangeUnits()
 		if( unit1 ) {
 			if( unit2 ) {
 				if( ( unit1->getRace() == unit2->getRace() ) &&
-					unit1->getLevel() == unit2->getLevel() ) {
+						unit1->getLevel() == unit2->getLevel() ) {
 					unit2->addNumber( unit1->getNumber() );
 					lord1->setUnit( idUnit1, 0 );
 					delete unit1;
@@ -677,10 +697,52 @@ void Game::exchangeUnits()
 				lord1->setUnit( idUnit1, 0 );
 			}
 		}
+		if(lord1->getOwner() == _player)
+		{
+			_player->setSelectedLord(lord1);
+		}
+		if( _dispLord ) {
+			_dispLord->reinit();
+		}
 		if( _lordExchange ) {
 			_lordExchange->reinit();
 		}
 	}
+	emit sig_exchange();
+}
+
+void Game::exchangeArtefact()
+{
+	uchar idLord1 = _socket->readChar();
+	int item = _socket->readInt();
+	uchar idLord2 = _socket->readChar();
+	
+	GenericLord * lord1 = 0;
+	GenericLord * lord2 = 0;
+	
+	if( idLord1 ) {
+		lord1 = (GenericLord * )_realLords[ idLord1 ];
+	}
+	if( idLord2 ) {
+		lord2 = (GenericLord * )_realLords[ idLord2 ];
+	}
+	
+	if( lord1 && lord2 ) {
+		ArtefactManager * manag1 = lord1->getArtefactManager();
+		ArtefactManager * manag2 = lord2->getArtefactManager();
+		
+		GenericLordArtefact * artefact = manag1->getArtefact( item );
+		
+		manag1->removeArtefact( item );
+		manag2->addArtefact( artefact );
+		
+		if( _lordExchange ) {
+			_lordExchange->reinit();
+		}
+		if( _dispLord ) {
+			_dispLord->reinit();
+		}
+	}
 }
 
 void Game::exchangeBaseUnits()
@@ -715,13 +777,13 @@ void Game::exchangeBaseUnits()
 					lord->setUnit( idUnit2, uni1 );
 					base->setUnit( idUnit1, uni2 );
 				} else {
-					uni1->addNumber( uni2->getNumber() );
-					lord->setUnit( idUnit2, 0 );
-					delete uni2;
+					uni2->addNumber( uni1->getNumber() );
+					base->setUnit( idUnit1, 0 );
+					delete uni1;
 				}
 			} else if (!uni1) {
-				lord->setUnit( idUnit2, 0 );
-				base->setUnit( idUnit1, uni2 );
+					lord->setUnit( idUnit2, 0 );
+					base->setUnit( idUnit1, uni2 );
 			} else if (!uni2) {
 				lord->setUnit( idUnit2, uni1 );
 				base->setUnit( idUnit1, 0 );
@@ -745,6 +807,7 @@ void Game::exchangeBaseUnits()
 			}
 		}	
 	}
+	emit sig_exchange();
 }
 
 
@@ -796,9 +859,10 @@ void Game::socketModifCell()
 	int a4 = _socket->readInt();
 	int a5 = _socket->readInt();
 	int a6 = _socket->readInt();
-
+	int a7 = _socket->readInt();
+//logDD("modif deco %d %d", a6, a7 );
 	GenericCell * cell = _map->at( row, col );
-	_map->changeCell( row, col, type, a4, a5, a6 );
+	_map->changeCell( row, col, type, a4, a5, a6, a7 );
 	cell->setDiversification( diversification );
 	_miniMap->redrawCell( cell );
 }
@@ -960,7 +1024,6 @@ void Game::socketModifLordNew()
 	lord->moveTo( _map->at( row, col ) );
 	lord->setOwner( _player );
 	_player->addLord( lord );
-	_control->reinit();
 	_scrLord->reinit();
 	_scrBase->reinit();
 }
@@ -972,20 +1035,31 @@ void Game::socketModifLordUnit()
 	uchar race = _socket->readChar();
 	uchar level = _socket->readChar();
 	int nb = _socket->readInt();
+	uchar move = _socket->readChar();
+	int health = _socket->readInt();
+
 	GenericFightUnit * uni = 0;
 	uni =_realLords[ id ]->getUnit( num );
 	if(!uni){
 		uni = new GenericFightUnit();
 		uni->setCreature( race, level );
-		uni->setMove( _socket->readChar() );
-		uni->setHealth( _socket->readInt() );
+		uni->setMove( move );
+		uni->setHealth( health );
 	}
-	uni->setNumber( nb );
-	if( nb == 0){
-		delete uni;
-		uni = 0;
-	}	
+	if( nb == 0 ){
+		if( _realLords[ id ]->countUnits() > 1){
+			uni->setNumber( nb );
+			delete uni;
+			uni = 0;
+		}		
+	}	else {
+		uni->setNumber( nb );
+	}
+
 	_realLords[ id ]->setUnit( num, uni );
+	if(_dispLord){
+		_dispLord->reupdate();
+	}
 }
 
 void Game::socketModifLordRemove()
@@ -999,7 +1073,6 @@ void Game::socketModifLordRemove()
 	if( player ) {
 		player->removeLord( (GenericLord *)lord );
 	}
-	_control->reinit();
 	_scrLord->reinit();
 	_scrBase->reinit();
 	//XXX: Remove lord from map
@@ -1013,7 +1086,6 @@ void Game::socketModifLordGarrison()
 	uchar lord = _socket->readChar();
 	uchar state = _socket->readChar();
 	_realLords[ lord ]->setVisible( state != 1 );
-	_control->reinit();
 	_scrLord->reinit();
 	_scrBase->reinit();
 }
@@ -1033,6 +1105,13 @@ void Game::socketModifPlayer()
 		_player->setResource( ress, _socket->readInt() );
 		_resourceBar->reinit();}
 		break;
+	case C_PLAY_PRICE: {
+		uchar ress = _socket->readChar();
+		uint price = _socket->readInt();
+		_player->getPriceMarket()->setResourcePrice( ress, price);
+		}
+		break;
+
 	}
 }
 
@@ -1045,6 +1124,9 @@ void Game::socketModifBase()
 	case C_BASE_OWNER:
 		socketModifBaseOwner();
 		break;
+	case C_BASE_NAME:
+		socketModifBaseName();
+		break;
 	case C_BASE_BUILDING:
 		socketModifBaseBuilding();
 		break;
@@ -1069,8 +1151,8 @@ void Game::socketModifBaseNew()
 	Base * base = (Base*)_map->at( row, col )->getBase();
 	if( ! base ) {
 		base = new Base( _map );
-		base->setPosition( row, col );
 		base->setRace( race );
+		base->setPosition( (GenericCell *)_map->at( row, col ));
 		base->setPopulation( population );
 		_map->computeStoppable( (GenericBase *)base );
 		base->setId( id );/// XXX: to inv ??
@@ -1088,6 +1170,7 @@ void Game::socketModifBaseOwner()
 	int col = _socket->readInt();
 	uchar playerNum = _socket->readChar();
 	Base * base = (Base*)_map->at( row, col )->getBase();
+	//logDD("own base row %d, col  %d, num %d", row,col,playerNum);
 
 	if( playerNum == _player->getNum() ) {
 		_player->addBase( base );
@@ -1095,15 +1178,29 @@ void Game::socketModifBaseOwner()
 	} else {
 		/// XXX: improve management of base of other player
 		if( base->getOwner() == _player ) {
-			base->setOwner( 0 );
 			_player->removeBase( (GenericBase*)base );
 		}
+		base->setOwner( getPlayer( playerNum ) );
 	}
-	_control->reinit();
 	_scrLord->reinit();
 	_scrBase->reinit();
 }
 
+void Game::socketModifBaseName()
+{
+	int row = _socket->readInt();
+	int col = _socket->readInt();
+	uint length = _socket->readInt();
+	QString name;
+	
+	for( uint i = 0; i < length; i++ ) {
+		name.ref(i) = _socket->readChar();
+	}
+	
+	Base * base = (Base*)_map->at( row, col )->getBase();
+	base->setName( name );
+}
+
 void Game::socketModifBaseBuilding()
 {
 	int row = _socket->readInt();
@@ -1145,11 +1242,12 @@ void Game::socketModifBasePopulation()
 {
 	int row = _socket->readInt();
 	int col = _socket->readInt();
-	uint popul = _socket->readChar();
+	uint popul = _socket->readInt();
 	Base * base = (Base*)_map->at( row, col )->getBase();
 
-	if(base)
+	if(base){
 		base->setPopulation(popul);	
+	}
 
 }
 
@@ -1163,8 +1261,8 @@ void Game::socketModifBuilding()
 
 		if( _map->at( row, col )->getBuilding() == 0 ) {
 			Building * building = new Building( _map );
-			building->setPosition( _map->at( row, col ) );
 			building->setType( type );
+			building->setPosition( _map->at( row, col ) );
 			_map->computeStoppable( (GenericBuilding *)building );
 			building->show();
 		} // XXX: update building if already created ?
@@ -1173,12 +1271,22 @@ void Game::socketModifBuilding()
 	case C_BUILD_OWNER: {
 		int row = _socket->readInt();
 		int col = _socket->readInt();
-		GenericBuilding * build = _map->at( row, col )->getBuilding();
-		if( _socket->readChar() == _player->getNum() ) {
+		char playNum = _socket->readChar();
+		//logDD("own build row %d, col  %d, num %d", row,col,playNum);
+
+		Building * build = (Building*)_map->at( row, col )->getBuilding();
+		if(  playNum == _player->getNum() ) {
 			if( build ) {
-				_player->addBuilding( build );
+				_player->addBuilding( (GenericBuilding *) build );
 				build->setOwner( _player );
 			}
+		} else {
+			if( build ) {
+				if(build->getOwner() == _player){
+					_player->removeBuilding( (GenericBuilding *) build );
+				}
+				build->setOwner( getPlayer(playNum) );
+			}
 		}
 	}
 	}
@@ -1223,6 +1331,16 @@ void Game::socketModifCreature()
 		_map->at( row, col )->setCreature( creature );
 		}
 		break;
+	case C_CRE_UPDATE: {
+		int row = _socket->readInt();
+		int col = _socket->readInt();
+		int nb = _socket->readInt();
+		MapCreature * creature = (MapCreature * ) _map->at( row, col )->getCreature();
+		if( creature ) {
+			creature->setCategoryNumber( nb );
+		}
+		}
+		break;
 	case C_CRE_DEL: {
 		int row = _socket->readInt();
 		int col = _socket->readInt();
@@ -1317,7 +1435,15 @@ void Game::socketConnect()
 		}
 		break;
 	case C_CONN_NAME:
-		_player->setName( "Player" );
+		{
+			QString res;
+			uint len = _socket->readChar();
+			for( uint i = 0; i < len; i++) {
+				res.append( _socket->readChar() );
+			}
+			_player->setName(res);
+			_chat->newMessage( QString( "Name of player: %1" ).arg( res ) );
+		}
 		break;
 	case C_CONN_PLAYER:
 		break;
@@ -1347,6 +1473,7 @@ void Game::slot_displayLord()
 	if( _player->numLord() > 0 ) {
 		if( _dispLord == 0 ) {
 			_dispLord = new DisplayLord( _player, this );
+			_dispLord->initSocket(_socket);
 		}
 		_dispLord->show();
 	}
@@ -1391,6 +1518,39 @@ void Game::socketQR()
 		_socket->sendAnswerEnum( chest->getResult() );
 		delete chest;
 		} break;
+	case C_QR_CREATURE_FLEE: {
+			AskDialog dialog;
+			/// XXX: to improve with name/category of creature
+			dialog.setText( "The creatures are fleeing. Do you want to fight them ?" );
+			dialog.setYesNo();
+			if( dialog.exec() ) {
+				_socket->sendAnswerYesNo( false );
+			} else {
+				_socket->sendAnswerYesNo( true );
+			}
+		} break;
+	case C_QR_CREATURE_MERCENARY: {
+			AskDialog dialog;
+			/// XXX: to improve with name/category of creature
+			dialog.setText( "You can buy these creatures. Do you want to buy them ?" );
+			dialog.setYesNo();
+			if( dialog.exec() ) {
+				_socket->sendAnswerYesNo( true );
+			} else {
+				_socket->sendAnswerYesNo( false );
+			}
+		} break;
+	case C_QR_CREATURE_JOIN: {
+			AskDialog dialog;
+			/// XXX: to improve with name/category of creature
+			dialog.setText( "The creatures want to join. Do you accept them ?" );
+			dialog.setYesNo();
+			if( dialog.exec() ) {
+				_socket->sendAnswerYesNo( true );
+			} else {
+				_socket->sendAnswerYesNo( false );
+			}
+		} break;
 	case C_QR_ANSWER:
 		logEE( "Should not happen" );
 		break;
