@@ -5,7 +5,7 @@
 ** game.h
 ** Manages the whole game
 **
-** Version : $Id: game.h,v 1.13 2004/10/08 23:06:34 audoux Exp $
+** Version : $Id: game.h,v 1.17 2004/12/11 13:39:04 lusum Exp $
 **
 ** Author(s) : Pascal Audoux
 **
@@ -135,6 +135,8 @@ signals:
 	void sig_base( GenericBase * );
 	void sig_fight( GenericLord * lord, CLASS_FIGHTER cla );
 	void sig_statusMsg( const QString & );
+	void sig_endGame();
+	void sig_exchange();
 
 public slots:
 	/** Slot for displaying lord */
@@ -208,6 +210,7 @@ private:
 
 	void socketModifBaseNew();
 	void socketModifBaseOwner();
+	void socketModifBaseName();
 	void socketModifBaseBuilding();
 	void socketModifBaseUnit();
 	void socketModifBasePopulation();
@@ -216,7 +219,7 @@ private:
 	void socketFight();
 
 	void exchangeUnits();
-	
+	void exchangeArtefact();	
 	void exchangeBaseUnits();
 
 	Player * _player;
