@@ -5,9 +5,9 @@
 ** gameConrol.cpp
 ** Widget on the right, controlling the game
 **
-** Version : $Id: gameControl.cpp,v 1.6 2004/08/24 19:31:46 tribunal2 Exp $
+** Version : $Id: gameControl.cpp,v 1.7 2004/12/11 13:33:43 lusum Exp $
 **
-** Author(s) : Pascal Audoux - Carlo
+** Author(s) : Pascal Audoux - Sardi Carlo
 **
 ** Date : 02/09/2000
 **
@@ -34,6 +34,7 @@
 #include <qpushbutton.h>
 #include <qlayout.h>
 #include <qlabel.h>
+#include <qmessagebox.h>
 // application specific includes
 #include "conf.h"
 #include "libCommon/attalSettings.h"
@@ -150,7 +151,7 @@ CentralControl::CentralControl( QWidget * parent, const char * name )
 
 	layout->activate();
 
-	connect( _pbQuit, SIGNAL( clicked() ), qApp, SLOT( quit() ) );
+	connect( _pbQuit, SIGNAL( clicked() ), SLOT( slot_quit() ) );
 	connect( _pbNext, SIGNAL( clicked() ), SLOT( slot_nextLord() ) );
 	connect( _pbTurn, SIGNAL( clicked() ), SIGNAL( sig_endTurn() ) );
 	connect( _pbOptions, SIGNAL( clicked() ), this, SLOT( slot_options() ) );
@@ -158,6 +159,14 @@ CentralControl::CentralControl( QWidget * parent, const char * name )
 	disableGame();
 }
 
+void CentralControl::slot_quit ()
+{
+	QMessageBox msb( tr("Are you sure ?"), tr("Do you really want to quit?"), QMessageBox::Warning, QMessageBox::Yes | QMessageBox::Default, QMessageBox::No | QMessageBox::Escape, 0, this );
+	if ( msb.exec() == QMessageBox::Yes ) {
+		qApp->quit();
+	}
+}
+
 void CentralControl::slot_options ()
 {
 	StrategyModeSettings settings = AttalSettings::getStrategyModeSettings ();
