@@ -5,7 +5,7 @@
 ** graphicalCell.cpp
 ** this class draws an animated cell
 **
-** Version : $Id: graphicalCell.cpp,v 1.5 2004/07/31 19:29:46 audoux Exp $
+** Version : $Id: graphicalCell.cpp,v 1.6 2004/12/18 11:52:52 audoux Exp $
 **
 ** Author(s) : Pascal Audoux - Cyrille Verrier
 **
@@ -122,15 +122,17 @@ Decoration::Decoration( Cell * parent, QCanvas *canvas)
 {
 	_parent = parent;
 	setZ( CAN_DECO );
-	setSequence( ImageTheme.decoration );
 	setFrame( 0 );
 }
 
-void Decoration::setDecoration( int decoration )
+void Decoration::setDecoration( uint group, uint item )
 {
-	setFrame( decoration - 1 );
+	setSequence( ImageTheme.decoration[ group-1 ] );
+	setFrame( item );
 
-	GenericDecoration * decor = DataTheme.decorations.at( decoration - 1 );
+	DecorationGroup * decoGroup = DataTheme.decorations.at( group );
+	
+	GenericDecoration * decor = decoGroup->at( item );
 	if( ( decor->getWidth() > 1 ) || ( decor->getHeight() > 1 ) ) {
 		int offsetRow = decor->getHeight() - ( 1 + decor->getDoorRow() );
 		int offsetCol = 0 - decor->getDoorCol();
