@@ -5,7 +5,7 @@
 ** imageTheme.cpp
 ** manage images in theme
 **
-** Version : $Id: imageTheme.cpp,v 1.20 2004/08/08 12:08:41 audoux Exp $
+** Version : $Id: imageTheme.cpp,v 1.26 2004/12/18 21:02:20 lusum Exp $
 **
 ** Author(s) : Pascal Audoux
 **
@@ -28,10 +28,11 @@
 
 // generic include files
 // include files for QT
-#include <qcanvas.h>
+#include <qimage.h>
 #include <qptrlist.h>
 #include <qpixmap.h>
-#include <qimage.h>
+#include <qpointarray.h>
+#include <qcanvas.h>
 // application specific include files
 #include "libCommon/dataTheme.h"
 #include "libCommon/genericMapCreature.h"
@@ -69,6 +70,25 @@ CreaturePixmap::CreaturePixmap( QPtrList<QPixmap> pix, QPtrList<QPoint> hotspots
 	_pixmaps[1] = new QCanvasPixmapArray( newList, hotspots );
 }
 
+CreaturePixmap::CreaturePixmap( const QValueList<QPixmap> & pix, const QPointArray & hotspots )
+{
+	_pixmaps[0] = new QCanvasPixmapArray( pix, hotspots );
+
+	QValueList<QPixmap> newList;
+	for( uint i=0; i<pix.count(); i++ ) {
+		QCanvasPixmap oldPix( pix[ i ], hotspots.at(i) );
+		QImage newImg;
+		if( !oldPix.isNull() ) {
+			newImg = (QImage) oldPix.convertToImage().mirror( true, false );
+			QCanvasPixmap newPix(newImg);
+			newList.append( newPix ) ;
+		} else {
+			newList.append( QPixmap() );
+		}
+	}
+	_pixmaps[1] = new QCanvasPixmapArray( newList, hotspots );
+}
+
 CreaturePixmap::~CreaturePixmap()
 {
 	if( _pixmaps[0] ) {
@@ -95,7 +115,7 @@ MapCreaturePixmap::MapCreaturePixmap( QPtrList<QPixmap> pix, QPtrList<QPoint> ho
 
 	QPtrList<QPixmap> newList;
 	for( uint i=0; i<pix.count(); i++ ) {
-		QCanvasPixmap oldPix( *pix.at(i), *hotspots.at(i) );
+		QCanvasPixmap oldPix( * pix.at( i ), * hotspots.at(i) );
 		QCanvasPixmap * newPix;
 		QImage newImg;
 		if( !oldPix.isNull() ) {
@@ -109,6 +129,26 @@ MapCreaturePixmap::MapCreaturePixmap( QPtrList<QPixmap> pix, QPtrList<QPoint> ho
 	_pixmaps[1] = new QCanvasPixmapArray( newList, hotspots );
 }
 
+MapCreaturePixmap::MapCreaturePixmap( const QValueList<QPixmap> & pix, const QPointArray & hotspots )
+{
+	_pixmaps[0] = new QCanvasPixmapArray( pix, hotspots );
+
+	QValueList<QPixmap> newList;
+	for( uint i=0; i<pix.count(); i++ ) {
+		QCanvasPixmap oldPix( pix[ i ], hotspots.at(i) );
+		QImage newImg;
+		if( !oldPix.isNull() ) {
+			newImg = oldPix.convertToImage().mirror( true, false );
+			QCanvasPixmap newPix(newImg);
+			newList.append( newPix ) ;
+		} else {
+			newList.append( QPixmap() );
+		}
+	}
+	_pixmaps[1] = new QCanvasPixmapArray( newList, hotspots );
+
+}
+
 MapCreaturePixmap::~MapCreaturePixmap()
 {
 	if( _pixmaps[0] ) {
@@ -184,7 +224,7 @@ QPixmap * ImageTheme::getArtefactIcon( uint num )
 		ret = _artefactIcon[num];
 	} else {
 		logEE( "artefact %d pixmap not found", num );
-		ret = new QPixmap();
+		ret = new QPixmap(); /// XXX: memory leak...
 	}
 
 	return ret;
@@ -226,16 +266,6 @@ QPixmap * ImageTheme::getResourceSmallIcom( uint num )
 	return ret;
 }
 
-#define CRE_ARRAY( list1, list2 ) \
-QPtrList<QPixmap> list1; \
-list1.setAutoDelete( true ); \
-QPtrList<QPoint> list2; \
-list2.setAutoDelete( true )
-
-#define ADD_PIX( list1, list2, name ) \
-list1.append( new QPixmap( IMAGE_PATH + name ) ); \
-list2.append( new QPoint( 0, 0 ) )
-
 bool ImageTheme::init()
 {
 	_isLoaded = initSkills();
@@ -301,7 +331,10 @@ void ImageTheme::clear()
 	transition = 0;
 
 	if( decoration ) {
-		delete decoration;
+		for( uint i = 1; i < DataTheme.decorations.count(); i++ ) {
+			delete decoration[ i - 1 ];
+		}
+		delete [] decoration;
 	}
 	decoration = 0;
 
@@ -466,10 +499,12 @@ bool ImageTheme::initTeams()
 	for( i = 0; i < NB_FLAGTYPE; i++ ) {
 		_mapFlags[ i ] = new QCanvasPixmapArray * [ nbTeams ];
 		for( j = 0; j < nbTeams; j++ ) {
-			CRE_ARRAY( listPixmapFlag, listPointFlag );
+			QPointArray listPointFlag( 1 );
+			QValueList<QPixmap> listPixmapFlag;
 			/// XXX: for the moment, only one pixmap, but maybe one day it will be animated...
 			fileName.sprintf( "players/mapFlag_%d_%d_0.png", i, j );
-			ADD_PIX( listPixmapFlag, listPointFlag, fileName.latin1() );
+			listPixmapFlag.append( QPixmap( IMAGE_PATH + fileName.latin1() ) );
+			listPointFlag.setPoint( 0, 0, 0 );
 			_mapFlags[ i ][ j ] = new QCanvasPixmapArray( listPixmapFlag, listPointFlag );
 		}
 	}
@@ -479,9 +514,12 @@ bool ImageTheme::initTeams()
 
 bool ImageTheme::initSkills()
 {
-	CRE_ARRAY( listPixmapSkill, listPointSkill );
-	ADD_PIX( listPixmapSkill, listPointSkill, "technics/technic_1_1.png" );
-	ADD_PIX( listPixmapSkill, listPointSkill, "technics/technic_1_2.png" );
+	QPointArray listPointSkill( 2 );
+	QValueList<QPixmap> listPixmapSkill;
+	listPixmapSkill.append( QPixmap( IMAGE_PATH + "technics/technic_1_1.png" ) );
+	listPointSkill.setPoint( 0, 0, 0 );
+	listPixmapSkill.append( QPixmap( IMAGE_PATH + "technics/technic_1_2.png" ) );
+	listPointSkill.setPoint( 1, 0, 0 );
 	skills = new QCanvasPixmapArray( listPixmapSkill, listPointSkill );
 
 	return true;
@@ -494,30 +532,39 @@ bool ImageTheme::initCells()
 
 	cells = new QCanvasPixmapArray * [DataTheme.tiles.count()];
 
-	CRE_ARRAY( listPixmapUnknown, listPointUnknown );
-	ADD_PIX( listPixmapUnknown, listPointUnknown, "tiles/unknown.png" );
-	cells[0] = new QCanvasPixmapArray( listPixmapUnknown, listPointUnknown );
+	QPointArray listPointUnknown( 1 ); 
+	QValueList<QPixmap> listPixmapUnknown;
+	listPixmapUnknown.append( QPixmap( IMAGE_PATH + "tiles/unknown.png" ) );
+	listPointUnknown.setPoint( 0, 0, 0 );
+	cells[ 0 ] = new QCanvasPixmapArray( listPixmapUnknown, listPointUnknown );
 
 	for( i = 1; i < DataTheme.tiles.count(); i++ ) {
 		uint nbTiles = DataTheme.tiles.at( i )->getDiversificationNumber();
-		CRE_ARRAY( listPixmapCell, listPointCell );
+		
+		QPointArray listPointCell( nbTiles );
+		QValueList<QPixmap> listPixmapCell;
 
 		for( j = 0; j < nbTiles; j++ ) {
 			name.sprintf( "tiles/tile_%d_%d.png", i, j );
-			ADD_PIX( listPixmapCell, listPointCell, name.latin1() );
+			listPixmapCell.append( QPixmap( IMAGE_PATH + name.latin1() ) );
+			listPointCell.setPoint( j, 0, 0 );
 		}
 		cells[i] = new QCanvasPixmapArray( listPixmapCell, listPointCell );
 	}
 
 
-	CRE_ARRAY( listPixmapPathCell, listPointPathCell );
+	QPointArray listPointPathCell( 66 );
+	QValueList<QPixmap> listPixmapPathCell;
+	
 	for( i = 0; i < 33; i++ ) {
 		QString name = "misc/arrow-" + QString::number( i ) + ".png";
-		ADD_PIX( listPixmapPathCell, listPointPathCell, name.latin1() );
+		listPixmapPathCell.append( QPixmap( IMAGE_PATH + name.latin1() ) );
+		listPointPathCell.setPoint( i, 0, 0 );
 	}
 	for( i = 0; i < 33; i++ ) {
 		QString name = "misc/arrowFar-" + QString::number( i ) + ".png";
-		ADD_PIX( listPixmapPathCell, listPointPathCell, name.latin1() );
+		listPixmapPathCell.append( QPixmap( IMAGE_PATH + name.latin1() ) );
+		listPointPathCell.setPoint( 33 + i, 0, 0 );
 	}
 	pathCells = new QCanvasPixmapArray( listPixmapPathCell, listPointPathCell );
 
@@ -535,7 +582,7 @@ bool ImageTheme::initCreatures()
 			listPixmapFightUnit.setAutoDelete( true );
 			QPtrList<QPoint> listPointFightUnit;
 			listPointFightUnit.setAutoDelete( true );
-
+			
 			if ( DataTheme.creatures.at (i , j)->isAnimated () )
 			{
 				for ( int fr = 0; fr < DataTheme.creatures.at ( i , j )->getNumFrames (); fr++ )
@@ -543,21 +590,24 @@ bool ImageTheme::initCreatures()
 					QString numFrame = "00";
 					numFrame.sprintf ("%02d",fr + 1);
 					QString fileName = "units/cre_" + QString::number( i ) + "_" + QString::number( j ) + "_" + numFrame + ".png";
-					ADD_PIX( listPixmapFightUnit, listPointFightUnit, fileName );
+					listPixmapFightUnit.append( new QPixmap( IMAGE_PATH + fileName ) );
+					listPointFightUnit.append( new QPoint( 0, 0 ) );
 				}
 			}
 			else
 			{
-			ADD_PIX( listPixmapFightUnit, listPointFightUnit, "units/cre_" + QString::number( i ) + "_" + QString::number( j ) + ".png" );
+				listPixmapFightUnit.append( new QPixmap( IMAGE_PATH + "units/cre_" + QString::number( i ) + "_" + QString::number( j ) + ".png" ) );
+				listPointFightUnit.append( new QPoint( 0, 0 ) );
 			}
 			creatures[cpt] = new CreaturePixmap( listPixmapFightUnit , listPointFightUnit );
 			cpt++;
 		}
 	}
 
-	CRE_ARRAY( listPixmapDead, listPointDead );
-	listPixmapDead.append( new QPixmap( IMAGE_PATH + "units/dead.png" ) ); \
-	listPointDead.append( new QPoint( 0, -70 ) );
+	QPointArray listPointDead( 1 );
+	QValueList<QPixmap> listPixmapDead;
+	listPixmapDead.append( QPixmap( IMAGE_PATH + "units/dead.png" ) );
+	listPointDead.setPoint( 0, 0, -70 );
 	deadCreature = new QCanvasPixmapArray( listPixmapDead, listPointDead );
 
 	return true;
@@ -568,8 +618,10 @@ bool ImageTheme::initLords()
 	uint nbLord = DataTheme.lords.count();
 	uint i;
 
-	CRE_ARRAY( listPixmapLord, listPointLord );
-	ADD_PIX( listPixmapLord, listPointLord, "units/lord.png" );
+	QPointArray listPointLord( 1 );
+	QValueList<QPixmap> listPixmapLord;
+	listPixmapLord.append( QPixmap( IMAGE_PATH + "units/lord.png" ) );
+	listPointLord.setPoint( 0, 0, 0 );
 	lords = new QCanvasPixmapArray( listPixmapLord , listPointLord );
 
 	_lordPixmap = new QPixmap * [ nbLord ];
@@ -588,15 +640,18 @@ bool ImageTheme::initLords()
 bool ImageTheme::initBases()
 {
 	uint i;
+	uint nbBases = DataTheme.bases.count();
 	
 	_insideBase = new QPixmap * [DataTheme.bases.count()];
-	for( i = 0; i < DataTheme.bases.count(); i++ ) {
+	for( i = 0; i < nbBases; i++ ) {
 		_insideBase[i] = 0;
 	}
 
-	CRE_ARRAY( listPixmapBase, listPointBase );
-	for( i = 0; i < DataTheme.bases.count(); i++ ) {
-		ADD_PIX( listPixmapBase, listPointBase, "base/base_" + QString::number( i ) + ".png" );
+	QPointArray listPointBase( nbBases );
+	QValueList<QPixmap> listPixmapBase;
+	for( i = 0; i < nbBases; i++ ) {
+		listPixmapBase.append( QPixmap( IMAGE_PATH + "base/base_" + QString::number( i ) + ".png" ) );
+		listPointBase.setPoint( i, 0, 0 );
 	}
 	bases = new QCanvasPixmapArray( listPixmapBase, listPointBase );
 
@@ -609,14 +664,18 @@ bool ImageTheme::initBases()
 bool ImageTheme::initArtefacts()
 {
 	uint i;
-	CRE_ARRAY( listPixmapArtefact, listPointArtefact );
-	for( i = 0; i < DataTheme.artefacts.count(); i++ ) {
-		ADD_PIX( listPixmapArtefact, listPointArtefact, "artefacts/artefactItem_" + QString::number( i ) + ".png" );
+	uint nbArtefacts = DataTheme.artefacts.count();
+	 
+	QPointArray listPointArtefact( nbArtefacts );
+	QValueList<QPixmap> listPixmapArtefact;
+	for( i = 0; i < nbArtefacts; i++ ) {
+		listPixmapArtefact.append( QPixmap( IMAGE_PATH + "artefacts/artefactItem_" + QString::number( i ) + ".png" ) );
+		listPointArtefact.setPoint( i, 0, 0 );
 	}
 	artefacts = new QCanvasPixmapArray( listPixmapArtefact, listPointArtefact );
 
-	_artefactIcon = new QPixmap * [DataTheme.artefacts.count()];
-	for( i = 0; i < DataTheme.artefacts.count(); i++ ) {
+	_artefactIcon = new QPixmap * [ nbArtefacts ];
+	for( i = 0; i < nbArtefacts; i++ ) {
 		_artefactIcon[i] = 0;
 	}
 
@@ -640,29 +699,38 @@ bool ImageTheme::initResources()
 bool ImageTheme::initBonus()
 {
 	uint j;
+	uint nbResources = DataTheme.resources.count();
 	QString name;
 	bonus = new QCanvasPixmapArray * [ 4 ];
 
-	CRE_ARRAY( listPixmapBonus0, listPointBonus0 );
-	for( j = 0; j < DataTheme.resources.count(); j++ ) {
+	QPointArray listPointBonus0( nbResources );
+	QValueList<QPixmap> listPixmapBonus0;
+	for( j = 0; j < nbResources; j++ ) {
 		name.sprintf( "ressources/smallResource_%02d.png", j+1 );
-		ADD_PIX( listPixmapBonus0, listPointBonus0, name );
+		listPixmapBonus0.append( QPixmap( IMAGE_PATH + name ) );
+		listPointBonus0.setPoint( j, 0, 0 );
 	}
 	bonus[0] = new QCanvasPixmapArray( listPixmapBonus0, listPointBonus0 );
 
-	CRE_ARRAY( listPixmapBonus1, listPointBonus1 );
+	QPointArray listPointBonus1( 1 );
+	QValueList<QPixmap> listPixmapBonus1;
 	name = "events/event1.png";
-	ADD_PIX( listPixmapBonus1, listPointBonus1, name );
+	listPixmapBonus1.append( QPixmap( IMAGE_PATH + name ) );
+	listPointBonus1.setPoint( 0, 0, 0 );
 	bonus[1] = new QCanvasPixmapArray( listPixmapBonus1, listPointBonus1 );
 
-	CRE_ARRAY( listPixmapBonus2, listPointBonus2 );
+	QPointArray listPointBonus2( 1 );
+	QValueList<QPixmap> listPixmapBonus2;
 	name = "events/event1.png";
-	ADD_PIX( listPixmapBonus2, listPointBonus2, name );
+	listPixmapBonus2.append( QPixmap( IMAGE_PATH + name ) );
+	listPointBonus2.setPoint( 0, 0, 0 );
 	bonus[2] = new QCanvasPixmapArray( listPixmapBonus2, listPointBonus2 );
 
-	CRE_ARRAY( listPixmapBonus3, listPointBonus3 );
+	QPointArray listPointBonus3( 1 );
+	QValueList<QPixmap> listPixmapBonus3;
 	name = "events/scroll.png";
-	ADD_PIX( listPixmapBonus3, listPointBonus3, name );
+	listPixmapBonus3.append( QPixmap( IMAGE_PATH + name ) );
+	listPointBonus3.setPoint( 0, 0, 0 );
 	bonus[3] = new QCanvasPixmapArray( listPixmapBonus3, listPointBonus3 );
 
 	return true;
@@ -670,8 +738,10 @@ bool ImageTheme::initBonus()
 
 bool ImageTheme::initChest()
 {
-	CRE_ARRAY( listPixmapChest, listPointChest );
-	ADD_PIX( listPixmapChest, listPointChest, "events/chest.png" );
+	QPointArray listPointChest( 1 );
+	QValueList<QPixmap> listPixmapChest;
+	listPixmapChest.append( QPixmap( IMAGE_PATH + "events/chest.png" ) );
+	listPointChest.setPoint( 0, 0, 0 );
 	chest = new QCanvasPixmapArray( listPixmapChest, listPointChest );
 
 	return true;
@@ -679,23 +749,31 @@ bool ImageTheme::initChest()
 
 bool ImageTheme::initBuildings()
 {
-	uint i, j;
+	uint i, j, nbBuildings, nbBases;
 	buildings = new QCanvasPixmapArray * [ DataTheme.buildings.count() ];
 	for( i = 0; i < DataTheme.buildings.count(); i++ ) {
-		CRE_ARRAY( listPixmapBuilding, listPointBuilding );
-		for( j = 0; j < DataTheme.buildings.at( i )->getNbFrame(); j++ ) {
+		nbBuildings = DataTheme.buildings.at( i )->getNbFrame();
+		QPointArray listPointBuilding( nbBuildings );
+		QValueList<QPixmap> listPixmapBuilding;
+		for( j = 0; j < nbBuildings; j++ ) {
 			QString name = "building/building_" + QString::number( i ) + "_" + QString::number( j ) + ".png";
-			ADD_PIX( listPixmapBuilding, listPointBuilding, name );
+			listPixmapBuilding.append( QPixmap( IMAGE_PATH + name ) );
+			listPointBuilding.setPoint( j, 0, 0 );
 		}
 		buildings[i] = new QCanvasPixmapArray( listPixmapBuilding, listPointBuilding );
 	}
 
-	insideBuildings = new QCanvasPixmapArray * [ DataTheme.bases.count() ];
-	for( i = 0; i < DataTheme.bases.count(); i++ ) {
-		CRE_ARRAY( listPixmapInside, listPointInside );
-		for( j = 0; j < DataTheme.bases.at( i )->getBuildingCount(); j++ ) {
-			ADD_PIX( listPixmapInside, listPointInside, "base/inside_" + QString::number( i ) + "_" + QString::number( j ) + ".png" );
-			ADD_PIX( listPixmapInside, listPointInside, "base/insideSel_" + QString::number( i ) + "_" + QString::number( j ) + ".png" );
+	nbBases = DataTheme.bases.count();
+	insideBuildings = new QCanvasPixmapArray * [ nbBases ];
+	for( i = 0; i < nbBases; i++ ) {
+		nbBuildings = DataTheme.bases.at( i )->getBuildingCount();
+		QPointArray listPointInside( 2 * nbBuildings );
+		QValueList<QPixmap> listPixmapInside;
+		for( j = 0; j < nbBuildings; j++ ) {
+			listPixmapInside.append( QPixmap( IMAGE_PATH + "base/inside_" + QString::number( i ) + "_" + QString::number( j ) + ".png" ) );
+			listPointInside.setPoint( 2 * j, 0, 0 );
+			listPixmapInside.append( QPixmap( IMAGE_PATH + "base/insideSel_" + QString::number( i ) + "_" + QString::number( j ) + ".png" ) );
+			listPointInside.setPoint( (2 * j) + 1, 0, 0 );
 		}
 		insideBuildings[i] = new QCanvasPixmapArray( listPixmapInside, listPointInside );
 	}
@@ -706,14 +784,18 @@ bool ImageTheme::initBuildings()
 bool ImageTheme::initTransitions()
 {
 	uint i, j;
-	transition = new QCanvasPixmapArray * [ DataTheme.tiles.count() ];
-	for( i = 1; i <= DataTheme.tiles.count(); i++ ) {
-		CRE_ARRAY( listPixmapTrans, listPointTrans );
+	uint nbTransitions = DataTheme.tiles.count();
+	
+	transition = new QCanvasPixmapArray * [ nbTransitions ];
+	for( i = 1; i <= nbTransitions; i++ ) {
+		QPointArray listPointTransition( NB_TRANSITION );
+		QValueList<QPixmap> listPixmapTransition;
 		for( j = 1; j <= NB_TRANSITION; j++ ) {
 			QString name = "tiles/transi_" + QString::number( i ) + "_" + QString::number( j ) + ".png";
-			ADD_PIX( listPixmapTrans, listPointTrans, name.latin1() );
+			listPixmapTransition.append( QPixmap( IMAGE_PATH + name.latin1() ) );
+			listPointTransition.setPoint( j - 1, 0, 0 );
 		}
-		transition[i-1] = new QCanvasPixmapArray( listPixmapTrans, listPointTrans );
+		transition[i-1] = new QCanvasPixmapArray( listPixmapTransition, listPointTransition );
 	}
 
 	return true;
@@ -721,12 +803,25 @@ bool ImageTheme::initTransitions()
 
 bool ImageTheme::initDecorations()
 {
-	uint i;
-	CRE_ARRAY( listPixmapDeco, listPointDeco );
-	for( i = 1; i <= DataTheme.decorations.count(); i++ ) {
-		ADD_PIX( listPixmapDeco, listPointDeco, "decor/decoration_" + QString::number( i ) + ".png" );
+	uint i, j;
+	uint nbDecoGroups = DataTheme.decorations.count();
+	uint nbDeco;
+	
+	decoration = new QCanvasPixmapArray * [ nbDecoGroups ];
+	for( i = 1; i < nbDecoGroups; i++ ) {
+		DecorationGroup * group = DataTheme.decorations.at( i );
+		nbDeco = group->count();
+		QPointArray listPointDeco( nbDeco );
+		QValueList<QPixmap> listPixmapDeco;
+		
+		for( j = 0; j < nbDeco; j++ ) {
+			listPixmapDeco.append( QPixmap( IMAGE_PATH + "decor/decoration_" + QString::number( i ) + "_" + QString::number( j ) + ".png" ) );
+			listPointDeco.setPoint( j, 0, 0 );
+		}
+		
+		decoration[ i-1 ] = new QCanvasPixmapArray( listPixmapDeco, listPointDeco );
 	}
-	decoration = new QCanvasPixmapArray( listPixmapDeco, listPointDeco );
+	
 
 	return true;
 }
@@ -737,23 +832,29 @@ bool ImageTheme::initEvents()
 	events = new QCanvasPixmapArray * [ 3 ];
 	QString fileName;
 
-	CRE_ARRAY( listPixmapEvent, listPointEvent );
+	QPointArray listPointEvent( 1 );
+	QValueList<QPixmap> listPixmapEvent;
 	fileName = "events/event1.png";
-	ADD_PIX( listPixmapEvent, listPointEvent, fileName );
-	events[0] = new QCanvasPixmapArray( listPixmapEvent, listPointEvent );
+	listPixmapEvent.append( QPixmap( IMAGE_PATH + fileName ) );
+	listPointEvent.setPoint( 0, 0, 0 );
+	events[ 0 ] = new QCanvasPixmapArray( listPixmapEvent, listPointEvent );
 
-	CRE_ARRAY( listPixmapEvent2, listPointEvent2 );
 	uint nbRes = DataTheme.resources.count();
+	QPointArray listPointEvent2( nbRes );
+	QValueList<QPixmap> listPixmapEvent2;
 	for( i = 0; i < nbRes; ++i ) {
 		fileName.sprintf( "ressources/smallResource_%02d.png", i+1 );
-		ADD_PIX( listPixmapEvent2, listPointEvent2, fileName );
+		listPixmapEvent2.append( QPixmap( IMAGE_PATH + fileName ) );
+		listPointEvent2.setPoint( i, 0, 0 );
 	}
-	events[1] = new QCanvasPixmapArray( listPixmapEvent2, listPointEvent2 );
+	events[ 1 ] = new QCanvasPixmapArray( listPixmapEvent2, listPointEvent2 );
 
-	CRE_ARRAY( listPixmapEvent3, listPointEvent3 );
+	QPointArray listPointEvent3( 1 );
+	QValueList<QPixmap> listPixmapEvent3;
 	fileName = "events/chest.png";
-	ADD_PIX( listPixmapEvent3, listPointEvent3, fileName );
-	events[2] = new QCanvasPixmapArray( listPixmapEvent3, listPointEvent3 );
+	listPixmapEvent3.append( QPixmap( IMAGE_PATH + fileName ) );
+	listPointEvent3.setPoint( 0, 0, 0 );
+	events[ 2 ] = new QCanvasPixmapArray( listPixmapEvent3, listPointEvent3 );
 
 	return true;
 }
@@ -766,9 +867,11 @@ bool ImageTheme::initMapCreatures()
 	for( i = 0; i < DataTheme.countRace(); i++ ) {
 		mapCreatures[i] = new MapCreaturePixmap * [ DataTheme.creatures.getRace( i )->count() ];
 		for( j = 0; j < DataTheme.creatures.getRace( i )->count(); j++ ) {
-			CRE_ARRAY( listPixmapMapCreature, listPointMapCreature );
+			QPointArray listPointMapCreature( 1 );
+			QValueList<QPixmap> listPixmapMapCreature;
 			QString name = "units/creMap_" + QString::number( i ) + "_" + QString::number( j ) + ".png";
-			ADD_PIX( listPixmapMapCreature, listPointMapCreature, name );
+			listPixmapMapCreature.append( QPixmap( IMAGE_PATH + name ) );
+			listPointMapCreature.setPoint( 0, 0, 0 );
 			mapCreatures[i][j] = new MapCreaturePixmap( listPixmapMapCreature, listPointMapCreature );
 		}
 	}
