@@ -5,7 +5,7 @@
 ** imageTheme.h
 ** manage images in theme
 **
-** Version : $Id: imageTheme.h,v 1.14 2004/08/08 12:08:41 audoux Exp $
+** Version : $Id: imageTheme.h,v 1.16 2004/12/18 11:51:01 audoux Exp $
 **
 ** Author(s) : Pascal Audoux
 **
@@ -32,6 +32,8 @@
 // generic include files
 // include files for QT
 #include <qcanvas.h>
+#include <qpointarray.h>
+#include <qvaluelist.h>
 // application specific include files
 #include "libClient/attalSound.h"
 
@@ -48,8 +50,15 @@ class GenericMapCreature;
 class CreaturePixmap
 {
 public:
+	/** Constrictor */
 	CreaturePixmap( QPtrList<QPixmap> pix, QPtrList<QPoint> hotspots );
-	~CreaturePixmap();
+	
+	/** Constructor */
+	CreaturePixmap( const QValueList<QPixmap> & pix, const QPointArray & hotspots );
+	
+	/** destructor */
+	virtual ~CreaturePixmap();
+	
 	QCanvasPixmapArray * operator[] ( uint i );
 
 private:
@@ -60,8 +69,15 @@ private:
 class MapCreaturePixmap
 {
 public:
+	/** Constructor */
 	MapCreaturePixmap( QPtrList<QPixmap> pix, QPtrList<QPoint> hotspots );
-	~MapCreaturePixmap();
+	
+	/** Constructor */
+	MapCreaturePixmap( const QValueList<QPixmap> & pix, const QPointArray & hotspots );
+	
+	/** Destructor */
+	virtual ~MapCreaturePixmap();
+	
 	QCanvasPixmapArray * operator[] ( uint i );
 
 private:
@@ -114,7 +130,7 @@ public:
 	CreaturePixmap ** creatures;
 	QCanvasPixmapArray * deadCreature;
 	QCanvasPixmapArray ** transition;
-	QCanvasPixmapArray * decoration;
+	QCanvasPixmapArray ** decoration;
 	QCanvasPixmapArray * artefacts;
 	QCanvasPixmapArray ** bonus;
 	QCanvasPixmapArray * chest;
