@@ -5,9 +5,9 @@
 ** insideAction.cpp
 ** Dialogs for actions of inside buildings
 **
-** Version : $Id: insideAction.cpp,v 1.6 2004/08/01 12:51:56 audoux Exp $
+** Version : $Id: insideAction.cpp,v 1.11 2004/12/07 19:05:29 lusum Exp $
 **
-** Author(s) : Pascal Audoux - Carlo 
+** Author(s) : Pascal Audoux - Sardi Carlo 
 **
 ** Date : 10/05/2002
 **
@@ -28,7 +28,6 @@
 
 // generic include files
 // include files for QT
-#include <qlayout.h>
 #include <qlabel.h>
 #include <qmessagebox.h>
 #include <qpushbutton.h>
@@ -58,13 +57,14 @@ InsideActionAllBuildings::InsideActionAllBuildings( GenericBase * base, QWidget
 	_base = base;
 	_socket = 0;
 	_player = 0;
+	_buildings = 0;
 
 	QVBoxLayout * layout = new QVBoxLayout( this );
 
 	QScrollView * scroll = new QScrollView( this );
 	scroll->setVScrollBarMode( QScrollView::AlwaysOn );
-	BuildingsView * buildings = new BuildingsView( base, scroll->viewport() );
-	scroll->addChild( buildings );
+	_buildings = new BuildingsView( base, scroll->viewport() );
+	scroll->addChild( _buildings );
 	layout->addWidget( scroll, 1 );
 	//layout->addStretch( 1 );
 
@@ -79,8 +79,8 @@ InsideActionAllBuildings::InsideActionAllBuildings( GenericBase * base, QWidget
 	layout->activate();
 
 	connect( pbOk, SIGNAL( clicked() ), SLOT( accept() ) );
-	connect( buildings, SIGNAL( sig_buy( int ) ), SLOT( slot_buy( int ) ) );
-	connect( buildings, SIGNAL( sig_sell( int ) ), SLOT( slot_sell( int ) ) );
+	connect( _buildings, SIGNAL( sig_buy( int ) ), SLOT( slot_buy( int ) ) );
+	connect( _buildings, SIGNAL( sig_sell( int ) ), SLOT( slot_sell( int ) ) );
 	setFixedSize( 800, 600 );
 }
 
@@ -108,6 +108,11 @@ void InsideActionAllBuildings::slot_sell( int building )
 	}
 }
 
+void InsideActionAllBuildings::updateView()
+{
+	_buildings->updateView();
+}
+
 
 //
 // ----- BuildingsView -----
@@ -116,6 +121,7 @@ void InsideActionAllBuildings::slot_sell( int building )
 BuildingsView::BuildingsView( GenericBase * base, QWidget * parent, const char * name )
 	:QWidget( parent, name )
 {
+	_base=base;
 	QSignalMapper * sigmap = new QSignalMapper( this );
 	QSignalMapper * sigmap2 = new QSignalMapper( this );
 	GenericBaseModel * baseModel = DataTheme.bases.at( base->getRace() );
@@ -155,6 +161,22 @@ void BuildingsView::buy( int building )
 	}
 }
 
+void BuildingsView::updateView()
+{
+	GenericBaseModel * baseModel = DataTheme.bases.at( _base->getRace() );
+	for( uint i = 0; i < baseModel->getBuildingCount(); i++ ) {
+		if( ! _base->isForbidden( i ) ) {
+			if( _base->hasBuildingType( i ) ) {
+				_panels[i]->setBuyable( false );
+				_panels[i]->setSellable( true );
+			} else {
+				_panels[i]->setBuyable( true );
+				_panels[i]->setSellable( false );
+			}
+		}
+	}
+}
+
 //
 // ----- BuildingPanel -----
 //
@@ -249,6 +271,38 @@ void BuildingPanel::slot_info()
 		text = "0";
 	}
 	text = tr( "Cost: " ) + text;
+	text += tr( "\n" );
+	if(_model->getAction()){
+		switch (_model->getAction()->getType()){
+			case INSIDE_NONE: 
+				text+=tr("Not implemented");
+				break;
+			case INSIDE_VILLAGE: 
+				text+=tr("Main Building");
+				break;
+			case INSIDE_CASTLE: 
+				text+=tr("Castle");
+				break;
+			case INSIDE_CREA:{ 
+							 /* specify what kind and number of units produced */
+							 text+=tr("Produce ");
+							 if(_model->getAction()->getParamNumber() == 3) {
+								 text+=QString("%1 ").arg(_model->getAction()->getParam(2));
+								 text+= DataTheme.creatures.at(_model->getAction()->getParam(0),_model->getAction()->getParam(1))->getName();
+							 }
+							 break;
+						 }
+			case INSIDE_MARKET: 
+						 text+=tr("Market");
+						 break;
+			default: 
+						 break;
+		}
+	} else {
+		text+=tr("Not implemented");
+	}
+			
+						
 	QMessageBox::information( this, tr( "Building informations" ), text, tr( "Ok" ) );
 }
 
@@ -303,58 +357,56 @@ InsideActionSomeCreature::InsideActionSomeCreature( int race, int level, QWidget
 // ----- DisplayCreatureBase -----
 //
 
-DisplayCreatureBase::DisplayCreatureBase( QWidget * parent, const char * name )
+DisplayCreatureBase::DisplayCreatureBase( GenericBase * base ,QWidget * parent, const char * name )
 	: QDialog( parent, name, true )
 {
+	_player = 0;
+	_base = base;
+	_socket = 0;
+
 	QVBoxLayout * lay = new QVBoxLayout( this );
 
-	QHBoxLayout * layH1 = new QHBoxLayout();
-	QHBoxLayout * layH2 = new QHBoxLayout();
-	QHBoxLayout * layH3 = new QHBoxLayout();
-	QHBoxLayout * layH4 = new QHBoxLayout();
+	uint i,nbLay ;
 
 	QSignalMapper * sigmap = new QSignalMapper( this );
-	for( int i = 0; i < 7; i++ ) {
+	for( i = 0; i < DataTheme.creatures.getRace(_base->getRace())->count();i++ ) {
 		_buy[i] = new DisplayCreature( this );
-		//_buy[i]->setCreature( i );
+		_buy[i]->setCreature( _base->getRace(), i );
+		
+		if((i % 2) == 0){
+			nbLay = (i/2) + 1;
+			_layH[nbLay] = new QHBoxLayout();
+		}
+		_layH[nbLay]->addWidget( _buy[i], 1 );
+		_layH[nbLay]->addSpacing( 5 );
 		sigmap->setMapping( _buy[i], i );
 		connect( _buy[i], SIGNAL( sig_clicked() ), sigmap, SLOT( map() ) );
 	}
 
-	layH1->addWidget( _buy[0], 1 );
-	layH1->addSpacing( 5 );
-	layH1->addWidget( _buy[1], 1 );
+	if((DataTheme.creatures.getRace(_base->getRace())->count() % 2) != 0){
+		_layH[nbLay]->addStretch( 1 );
+	}
 
-	layH2->addWidget( _buy[2], 1 );
-	layH2->addSpacing( 5 );
-	layH2->addWidget( _buy[3], 1 );
-
-	layH3->addWidget( _buy[4], 1 );
-	layH3->addSpacing( 5 );
-	layH3->addWidget( _buy[5], 1 );
-
-	layH4->addStretch( 1 );
-	layH4->addWidget( _buy[6], 2 );
-	layH4->addStretch( 1 );
-
-	lay->addLayout( layH1, 1 );
-	lay->addSpacing( 5 );
-	lay->addLayout( layH2, 1 );
-	lay->addSpacing( 5 );
-	lay->addLayout( layH3, 1 );
-	lay->addSpacing( 5 );
-	lay->addLayout( layH4, 1 );
+	for( i = 1; i <= nbLay; i++) {
+		lay->addLayout( _layH[i], 1 );
+		lay->addSpacing( 5 );
+	}
 
 	lay->activate();
 
 	connect( sigmap, SIGNAL( mapped( int ) ), SLOT( slot_buyUnit( int ) ) );
 }
+	
+void DisplayCreatureBase::init( GenericPlayer * player)
+{
+	_player = player;
+}
 
-void DisplayCreatureBase::slot_buyUnit( int /*num*/ )
+void DisplayCreatureBase::slot_buyUnit( int num )
 {
-	/// XXX: TODO
-	logEE( "not finished" );
 	BuyCreature es( this );
+	es.initSocket(_socket);
+	es.init( _player, _base, _buy[num]->getCreature() );
 	es.exec();
 }
 
