@@ -5,9 +5,9 @@
 ** insideAction.h
 ** Dialogs for actions of inside buildings
 **
-** Version : $Id: insideAction.h,v 1.3 2004/07/29 21:22:05 audoux Exp $
+** Version : $Id: insideAction.h,v 1.6 2004/12/07 19:05:29 lusum Exp $
 **
-** Author(s) : Pascal Audoux
+** Author(s) : Pascal Audoux - Sardi Carlo
 **
 ** Date : 10/05/2002
 **
@@ -33,7 +33,9 @@
 // include files for QT
 #include <qframe.h>
 #include <qdialog.h>
+#include <qlayout.h>
 // application specific include files
+#include "libCommon/creature.h"
 
 
 class QPushButton;
@@ -45,6 +47,7 @@ class GenericBase;
 class GenericBaseModel;
 class GenericPlayer;
 class InsideBuildingModel;
+class BuildingsView;
 
 /*              ------------------------------
  *                         InsideAction
@@ -64,6 +67,8 @@ public:
 
 	void setPlayer( GenericPlayer * player ) { _player = player; }
 
+	void updateView();
+
 public slots:
 	void slot_buy( int building );
 	void slot_sell( int building );
@@ -72,6 +77,7 @@ protected:
 	GenericBase * _base;
 	AttalSocket * _socket;
 	GenericPlayer * _player;
+	BuildingsView * _buildings;
 };
 
 /** View of all buildings */
@@ -82,6 +88,8 @@ public:
 	BuildingsView( GenericBase * model, QWidget * parent = 0, const char * name = 0 );
 
 	void buy( int building );
+	
+	void updateView();
 
 signals:
 	void sig_buy( int building );
@@ -89,6 +97,7 @@ signals:
 
 protected:
 	BuildingPanel ** _panels;
+	GenericBase * _base;
 };
 
 /** Panel for displaying the view of a building */
@@ -125,14 +134,25 @@ class DisplayCreatureBase : public QDialog
 	Q_OBJECT
 public:
 	/** Constructor */
-	DisplayCreatureBase( QWidget * parent = 0, const char * name = 0 );
+	DisplayCreatureBase( GenericBase * base ,QWidget * parent = 0, const char * name = 0 );
+	
+	void init( GenericPlayer * player);
+	
+	/** Initialize the socket of the dialog for requesting the server */
+	void initSocket( AttalSocket * socket ) {
+		_socket = socket;
+	}
 
 public slots:
 	/** Slot for buying unit 'num' */
 	void slot_buyUnit( int num );
 
 private:
+	AttalSocket * _socket;
+	GenericBase * _base;
+	GenericPlayer * _player;
 	DisplayCreature * _buy[7];
+	QHBoxLayout * _layH[7];
 };
 
 
