@@ -5,7 +5,7 @@
 ** lordExchange.h
 ** Dialog for exchnagiong units and artefacts between two lords.
 **
-** Version : $Id: lordExchange.h,v 1.2 2004/07/31 19:29:46 audoux Exp $
+** Version : $Id: lordExchange.h,v 1.3 2004/11/16 22:30:15 audoux Exp $
 **
 ** Author(s) : Pascal Audoux
 **
@@ -38,6 +38,8 @@
 
 class QLabel;
 class QListBox;
+class QTable;
+
 class AttalSocket;
 class GenericLord;
 class Icon;
@@ -167,11 +169,27 @@ protected:
 /** Displays artefacts of two lords */
 class DisplayBothArtefacts : public QWidget
 {
+	Q_OBJECT
 public:
 	/** Constructor */
 	DisplayBothArtefacts( QWidget * parent = 0, const char * name = 0 );
 
 	void initLords( GenericLord * lordLeft, GenericLord * lordRight );
+	
+	void initSocket( AttalSocket * socket );
+	
+public slots:
+	void slot_exchangeToRight();
+	
+	void slot_exchangeToLeft();	
+	
+	void slot_readSocket();
+
+protected:
+	QListBox * _artefactsRight, * _artefactsLeft;
+	GenericLord * _lordRight, * _lordLeft;
+	AttalSocket * _socket;
+	
 };
 
 /** */
