@@ -5,7 +5,7 @@
 ** map.cpp
 ** Manage the global view
 **
-** Version : $Id: map.cpp,v 1.6 2004/08/01 11:27:34 audoux Exp $
+** Version : $Id: map.cpp,v 1.8 2004/12/18 12:05:38 audoux Exp $
 **
 ** Author(s) : Pascal Audoux - Cyrille Verrier
 **
@@ -39,7 +39,7 @@
 #include "libCommon/pathFinder.h"
 
 #include "libClient/cell.h"
-#include "libClient/lord.h"
+//#include "libClient/lord.h"
 
 //
 // ----- Map -----
@@ -138,9 +138,10 @@ void Map::changeCell( int i,
 		      int typ,
 		      int transition,
 		      int typtra,
-		      int decoration )
+		      uint decorationGroup, 
+		      uint decorationItem )
 {
-	GenericMap::changeCell( i, j, typ, transition, typtra, decoration );
+	GenericMap::changeCell( i, j, typ, transition, typtra, decorationGroup, decorationItem );
 
 	if( _theCells[i][j]->getType() == 0 ) {
 		/*((Cell*)_theCells[i][j])->setType( typ );
@@ -166,6 +167,7 @@ bool Map::load( QTextStream * ts, int width, int heigth )
 		_theCells[i] = (GenericCell**) ( new Cell *[_width] );
 	}
 	int val;
+	uint item;
 	
 	// Loading base cell
 	for( i = 0; i < _height; i++ ) {
@@ -228,7 +230,10 @@ bool Map::load( QTextStream * ts, int width, int heigth )
 		for( j = 0; j < _width; j++ ) {
 			if( ! ts->atEnd() ) {
 				*ts >> val;
-				_theCells[i][j]->setDecoration( val );
+				if( val ) {
+					*ts >> item;	
+					_theCells[i][j]->setDecoration( val, item );
+				}
 			} else {
 				logEE("Stream too short");
 				return false;
