@@ -5,7 +5,7 @@
 ** attalSocket.cpp
 ** socket for Attal over network
 **
-** Version : $Id: attalSocket.cpp,v 1.19 2004/10/08 23:05:54 audoux Exp $
+** Version : $Id: attalSocket.cpp,v 1.26 2004/12/18 11:46:34 audoux Exp $
 **
 ** Author(s) : Pascal Audoux
 **
@@ -201,6 +201,17 @@ void AttalSocket::sendExchangeUnit( GenericLord * lord1, int unit1, GenericLord
 	send();
 }
 
+void AttalSocket::sendExchangeArtefact( GenericLord * lord1, int item, GenericLord * lord2 )
+{
+	if( lord1 && lord2) {
+		init( (uchar)SO_EXCH, (uchar)C_EXCH_ARTEFACT );
+		appendChar( (uchar)lord1->getId() );
+		appendInt( item );
+		appendChar( (uchar)lord2->getId() );
+		send();
+	}
+}
+
 void AttalSocket::sendExchangeBaseUnit( GenericBase * base, int unit1, GenericLord * lord2, int unit2 )
 {
 	init( (uchar)SO_EXCH, (uchar)C_EXCH_BASEUNIT );
@@ -249,6 +260,14 @@ void AttalSocket::sendPlayerResource( char res, int nb )
 	send();
 }
 
+void AttalSocket::sendPlayerPrice( char res, int price )
+{
+	init( (uchar)SO_MODIF, (uchar)C_MOD_PLAYER, (uchar)C_PLAY_PRICE );
+	appendChar( res );
+	appendInt( price );
+	send();
+}
+
 void AttalSocket::sendAskNone( const QString & msg )
 {
 	uint len = msg.length();
@@ -282,6 +301,33 @@ void AttalSocket::sendAskChest()
 	send();
 }
 
+void AttalSocket::sendAskCreatureJoin( GenericMapCreature * creature )
+{
+	init( (uchar) SO_QR, (uchar) C_QR_CREATURE_JOIN );
+	appendChar( creature->getRace() );
+	appendChar( creature->getLevel() );
+	appendInt( creature->getCategoryNumber() );
+	send();
+}
+	
+void AttalSocket::sendAskCreatureMercenary( GenericMapCreature * creature )
+{
+	init( (uchar) SO_QR, (uchar) C_QR_CREATURE_MERCENARY );
+	appendChar( creature->getRace() );
+	appendChar( creature->getLevel() );
+	appendInt( creature->getCreatureNumber() );
+	send();
+}
+		
+void AttalSocket::sendAskCreatureFlee( GenericMapCreature * creature )
+{
+	init( (uchar) SO_QR, (uchar) C_QR_CREATURE_FLEE );
+	appendChar( creature->getRace() );
+	appendChar( creature->getLevel() );
+	appendInt( creature->getCategoryNumber() );
+	send();
+}
+
 void AttalSocket::sendBegGame( char nb ) 
 {
 	init( (uchar)SO_GAME, (uchar)C_GAME_BEGIN );
@@ -380,7 +426,8 @@ void AttalSocket::sendCell( GenericCell * cell )
 	appendChar( (int) cell->getDiversification() );
 	appendInt( (int) cell->getTransition() );
 	appendInt( (int) cell->getTransitionCellType() );
-	appendInt( (int) cell->getDecoration() );
+	appendInt( (int) cell->getDecorationGroup() );
+	appendInt( (int) cell->getDecorationItem() );
 	send();
 }
 
@@ -692,6 +739,24 @@ void AttalSocket::sendLordUnit( GenericLord * lord, int num )
 	}
 }
 
+void AttalSocket::sendLordUnit( GenericLord * lord, int num , int value)
+{
+	GenericFightUnit * temp = lord->getUnit( num );
+	if( temp ) {
+		init( (uchar)SO_MODIF, (uchar)C_MOD_LORD, (uchar)C_LORD_UNIT );
+		appendChar( lord->getId() );
+		appendChar( num );
+		appendChar( temp->getRace() );
+		appendChar( temp->getLevel() );
+		appendInt( value );
+		appendChar( temp->getMove() );
+		appendInt( temp->getHealth() );
+		send();
+	}
+}
+
+
+
 void AttalSocket::sendLordRemove( GenericLord * lord )
 {
 	init( (uchar) SO_MODIF, (uchar) C_MOD_LORD, (uchar) C_LORD_REMOVE );
@@ -742,6 +807,25 @@ void AttalSocket::sendBaseNew( GenericBase * base )
 	send();
 }
 
+void AttalSocket::sendBaseName( GenericBase * base )
+{
+	QString name;
+	name = base->getName();
+	
+	init( (uchar)SO_MODIF, (uchar)C_MOD_BASE, (uchar)C_BASE_NAME );
+	
+	appendInt( base->getCell()->getRow() );
+	appendInt( base->getCell()->getCol() );
+	appendInt( name.length() );
+	
+	for( uint i = 0; i < name.length(); i++ ) {
+		appendChar( (uchar) (name.latin1())[i] );
+	}
+
+	send();
+}
+
+
 void AttalSocket::sendBaseOwner( GenericBase * base, GenericPlayer * player )
 {
 	init( (uchar)SO_MODIF, (uchar)C_MOD_BASE, (uchar)C_BASE_OWNER );
@@ -865,6 +949,15 @@ void AttalSocket::sendNewCreature( GenericMapCreature * creature )
 	send();
 }
 
+void AttalSocket::sendUpdateCreature( GenericMapCreature * creature )
+{
+	init( (uchar)SO_MODIF, (uchar)C_MOD_CREATURE, (uchar)C_CRE_UPDATE );
+	appendInt( creature->getCell()->getRow() );
+	appendInt( creature->getCell()->getCol() );
+	appendInt( creature->getCategoryNumber() );
+	send();
+}
+
 void AttalSocket::sendDelCreature( GenericCell * cell )
 {
 	init( (uchar)SO_MODIF, (uchar)C_MOD_CREATURE, (uchar)C_CRE_DEL );
