@@ -5,7 +5,7 @@
 ** attalSocket.h
 ** socket for Attal over network
 **
-** Version : $Id: attalSocket.h,v 1.14 2004/10/08 23:05:54 audoux Exp $
+** Version : $Id: attalSocket.h,v 1.20 2004/12/05 15:08:48 lusum Exp $
 **
 ** Author(s) : Pascal Audoux
 **
@@ -95,6 +95,7 @@ enum CLASS_CONNECT {
 enum CLASS_EXCH {
 	C_EXCH_START,
 	C_EXCH_UNIT,
+	C_EXCH_ARTEFACT,
 	C_EXCH_BASEUNIT,
 	C_EXCH_BASEUNITCL
 };
@@ -105,11 +106,15 @@ enum CLASS_QR {
 	C_QR_LEVEL,
 	C_QR_CHEST,
 	C_QR_QUEST,
+	C_QR_CREATURE_FLEE,
+	C_QR_CREATURE_MERCENARY,
+	C_QR_CREATURE_JOIN,
 	C_QR_ANSWER
 };
 
 enum CLASS_PLAYER {
-	C_PLAY_RESS
+	C_PLAY_RESS,
+	C_PLAY_PRICE
 };
 
 enum CLASS_LORD {
@@ -137,6 +142,7 @@ enum CLASS_LORD {
 enum CLASS_BASE {
 	C_BASE_NEW,
 	C_BASE_OWNER,
+	C_BASE_NAME,
 	C_BASE_BUILDING,
 	C_BASE_UNIT,
 	C_BASE_MARKET,
@@ -215,6 +221,7 @@ enum CLASS_ARTEFACT {
 
 enum CLASS_CREATURE {
 	C_CRE_NEW,
+	C_CRE_UPDATE,
 	C_CRE_DEL
 };
 
@@ -252,6 +259,9 @@ public:
 
 	/** Exchange 2 units between one or two lords */
 	void sendExchangeUnit( GenericLord * lord1, int unit1, GenericLord * lord2, int unit2 );
+	
+	/** Exchange 2 artefacts between one or two lords */
+	void sendExchangeArtefact( GenericLord * lord1, int item, GenericLord * lord2 );
 
 	/** Exchange 2 units between one base and a lord or inside a base */
 	void sendExchangeBaseUnit( GenericBase * base, int unit1, GenericLord * lord2, int unit2 );
@@ -260,7 +270,10 @@ public:
 	
 	/** Send ressources of a player */
 	void sendPlayerResource( char res, int nb );
-	
+
+	/** Send prices of a player */
+	void sendPlayerPrice( char res, int price );
+
 	/** Send 'Game begins' info */
 	void sendBegGame( char nb );
 
@@ -349,6 +362,12 @@ public:
 	void sendAskNone( const QString & msg );
 
 	void sendAskChest();
+	
+	void sendAskCreatureJoin( GenericMapCreature * creature );
+	
+	void sendAskCreatureMercenary( GenericMapCreature * creature );
+		
+	void sendAskCreatureFlee( GenericMapCreature * creature );
 
 	/** Ask skill when level upgrade */
 	void sendAskLevel( char lord, char level, char primSkill, char skill1, char skill2 );
@@ -378,6 +397,9 @@ public:
 
 	/** Send unit 'num' */
 	void sendLordUnit( GenericLord * lord, int num );
+	
+	/** Send unit 'num' */
+	void sendLordUnit( GenericLord * lord, int num , int value);
 
 	void sendLordRemove( GenericLord * lord );
 
@@ -387,6 +409,9 @@ public:
 
 	/** New base */
 	void sendBaseNew( GenericBase * base );
+	
+	/** Base name */
+	void sendBaseName( GenericBase * base );
 
 	/** New owner for the base */
 	void sendBaseOwner( GenericBase * base, GenericPlayer * player );
@@ -419,6 +444,9 @@ public:
 	/** new creature on map */
 	void sendNewCreature( GenericMapCreature * creature );
 
+	/** updates creature on map */
+	void sendUpdateCreature( GenericMapCreature * creature );
+	
 	/** delete creature of map */
 	void sendDelCreature( GenericCell * cell );
 
