@@ -5,7 +5,7 @@
 ** template.cpp
 ** this is a template for all .cpp files
 **
-** Version : $Id: creature.cpp,v 1.10 2004/07/31 19:29:46 audoux Exp $
+** Version : $Id: creature.cpp,v 1.12 2004/12/05 14:07:17 audoux Exp $
 **
 ** Author(s) : Pascal Audoux
 **
@@ -192,9 +192,9 @@ void Creature::save( QTextStream & ts, int indent )
 	indentation( &ts, indent );
 	ts << "\t</animations>" << endl;
 	indentation( &ts, indent );
-	ts << "\t<xoffset>" << getNumFrames () << "</xoffset>" << endl;
+	ts << "\t<xoffset>" << getXOffset() << "</xoffset>" << endl;
 	indentation( &ts, indent );
-	ts << "\t<yoffset>" << getNumFrames () << "</yoffset>" << endl;
+	ts << "\t<yoffset>" << getYOffset() << "</yoffset>" << endl;
 	for( k = 0; k < DataTheme.resources.count(); k++ ) {
 		if( getCost( k ) > 0 ) {
 			indentation( &ts, indent );
@@ -277,30 +277,34 @@ void CreatureCounter::addCreature( Creature * creature, int nb )
 {
 	bool added = false;
 
-	for( uint i = 0; i < _list.count(); i++ ) {
-		Creature * temp = _list.at( i )->getCreature();
-		if( ( temp->getRace() == creature->getRace() )
-			&& ( temp->getLevel() == creature->getLevel() ) ) {
-			_list.at( i )->increase( nb );
-			added = true;
-			i = _list.count();
+	if( creature ) {
+		for( uint i = 0; i < _list.count(); i++ ) {
+			Creature * temp = _list.at( i )->getCreature();
+			if( ( temp->getRace() == creature->getRace() )
+				&& ( temp->getLevel() == creature->getLevel() ) ) {
+				_list.at( i )->increase( nb );
+				added = true;
+				i = _list.count();
+			}
+		}
+	
+		if( ! added ) {
+			CreatureStack * stack = new CreatureStack( creature, nb );
+			_list.append( stack );
 		}
-	}
-
-	if( ! added ) {
-		CreatureStack * stack = new CreatureStack( creature, nb );
-		_list.append( stack );
 	}
 }
 
 void CreatureCounter::decreaseCreature( Creature * creature, int number )
 {
-	for( uint i = 0; i < _list.count(); i++ ) {
-		Creature * temp = _list.at( i )->getCreature();
-		if( ( temp->getRace() == creature->getRace() )
-			&& ( temp->getLevel() == creature->getLevel() ) ) {
-			_list.at( i )->decrease( number );
-			i = _list.count();
+	if( creature ) {
+		for( uint i = 0; i < _list.count(); i++ ) {
+			Creature * temp = _list.at( i )->getCreature();
+			if( ( temp->getRace() == creature->getRace() )
+				&& ( temp->getLevel() == creature->getLevel() ) ) {
+				_list.at( i )->decrease( number );
+				i = _list.count();
+			}
 		}
 	}
 }
