@@ -5,7 +5,7 @@
 ** genericBase.cpp
 ** in order to manage buildings...
 **
-** Version : $Id: genericBase.cpp,v 1.18 2004/08/06 10:33:03 lusum Exp $
+** Version : $Id: genericBase.cpp,v 1.21 2004/12/05 14:05:43 audoux Exp $
 **
 ** Author(s) : Pascal Audoux - Sardi Carlo
 **
@@ -87,6 +87,9 @@ void GenericBase::save( QTextStream * ts, int indent )
 
 	indentation( ts, indent );
 	*ts << "\t<type>" << _race << "</type>" << endl;
+	
+	indentation( ts, indent );
+	*ts << "\t<name>" << _name << "</name>" << endl;
 
 	indentation( ts, indent );
 	*ts << "\t<col>" << _currentCell->getCol() << "</col>" << endl;
@@ -104,6 +107,22 @@ void GenericBase::save( QTextStream * ts, int indent )
 		*ts << "\t<forbidden>" << * ( _forbidden.at( j ) ) << "</forbidden>" << endl;
 	}
 
+	for( uint i = 0; i < MAX_UNIT; i++ ) {
+		if( _units[i] ) {
+			indentation( ts, indent );
+			*ts << "\t<unit pos=\"" << i << "\">" << endl;
+			indentation( ts, indent );
+			*ts << "\t\t<race>" << _units[i]->getRace() << "</race>" << endl;
+			indentation( ts, indent );
+			*ts << "\t\t<level>" << _units[i]->getLevel() << "</level>" << endl;
+			indentation( ts, indent );
+			*ts << "\t\t<number>" << _units[i]->getNumber() << "</number>" << endl;
+			indentation( ts, indent );
+			*ts << "\t</unit>" << endl;
+		}
+	}
+
+
 	indentation( ts, indent );
 	*ts << "</base>" << endl;
 	*ts << flush;
@@ -335,10 +354,11 @@ int GenericBase::getCreatureProduction( Creature * creature )
 
 void GenericBase::initCreatureProduction()
 {
+	uint nbBuildings = _buildings.count();
 	_counter.clear();
 
 	GenericBaseModel * baseModel = DataTheme.bases.at( _race );
-	for( int i = 0; i < (int)_buildings.count(); i++ ) {
+	for( uint i = 0; i < nbBuildings; i++ ) {
 		GenericInsideBuilding * building = _buildings.at( i );
 		InsideBuildingModel * model = baseModel->getBuildingModel( building->getLevel() );
 		InsideAction * action = model->getAction();
@@ -346,7 +366,8 @@ void GenericBase::initCreatureProduction()
 			if( action->getType() == INSIDE_CREA ) {
 				int race = action->getParam( 0 );
 				int level = action->getParam( 1 );
-				Creature * creature = DataTheme.creatures.at( race, level );
+				
+				Creature * creature = DataTheme.creatures.at( race, level );			
 				_counter.addCreature( creature, action->getParam( 2 ) );
 			}
 		}
@@ -823,21 +844,22 @@ bool BaseHandler::endElement( const QString &, const QString &, const QString &
     return true;	
 }
 
-bool BaseHandler::characters( const QString& ch )
+bool BaseHandler::characters( const QString & ch )
 {
 	QString ch_simplified = ch.simplifyWhiteSpace();
-	if ( ch_simplified.isEmpty() )
+	if( ch_simplified.isEmpty() ) {
 		return true;
+	}
 
 	switch( _state ) {
 	case StateName:
 		_base->setModelName( ch_simplified );
 		break;
-	case StateDisposition:{
+	case StateDisposition: {
 		QStringList li = QStringList::split( " ", ch_simplified );
 		GenericMapDisposition::DispositionType type;
-		for( int i = 0; i < _height; i++ ) {
-			for( int j = 0; j < _width; j++ ) {
+		for( uint i = 0; i < _height; i++ ) {
+			for( uint j = 0; j < _width; j++ ) {
 				type = GenericMapDisposition::DispositionType( li[ i * _width + j ].toInt() );
 				_base->setDisposition( i, j, type );
 			}
