@@ -5,7 +5,7 @@
 ** genericBase.h
 ** in order to manage bases...
 **
-** Version : $Id: genericBase.h,v 1.11 2004/09/12 18:17:22 audoux Exp $
+** Version : $Id: genericBase.h,v 1.13 2004/12/04 14:25:51 lusum Exp $
 **
 ** Author(s) : Pascal Audoux
 **
@@ -101,7 +101,7 @@ public:
 	int getRace() { return _race; }
 
 	/** Set name */
-	void setName( QString name ) { _name = name; }
+	void setName( const QString & name ) { _name = name; }
 	
 	/** Get name */
 	QString getName() { return _name; } 
@@ -299,7 +299,7 @@ public:
 	void setPriceMarket(PriceMarket * price) { _price = price;}
 	
 	void save( QTextStream * ts, int indent = 0 );
-
+	
 protected:	
 	QString _modelName;
 	int _race;
@@ -371,6 +371,7 @@ private:
 	BaseList * _list;
 	GenericBaseModel * _base;
 	int _race, _level;
+	int _unRace, _unLevel;
 	InsideBuildingModel * _building;
 	InsideAction * _action;
 	QTextStream * _stream;
