@@ -5,7 +5,7 @@
 ** genericBuilding.cpp
 ** in order to manage buildings...
 **
-** Version : $Id: genericBuilding.cpp,v 1.10 2004/07/31 19:29:46 audoux Exp $
+** Version : $Id: genericBuilding.cpp,v 1.11 2004/12/27 22:58:07 audoux Exp $
 **
 ** Author(s) : Pascal Audoux - Sardi Carlo
 **
@@ -409,13 +409,13 @@ bool BuildingHandler::characters( const QString& ch )
 		case StateDisposition:{
 			QStringList li = QStringList::split( " ", ch_simplified );
 			GenericMapDisposition::DispositionType type;
-			for( int i = 0; i < _height; i++ ) {
-				for( int j = 0; j < _width; j++ ) {
+			for( uint i = 0; i < _height; i++ ) {
+				for( uint j = 0; j < _width; j++ ) {
 					type = GenericMapDisposition::DispositionType( li[ i * _width + j ].toInt() );
 					_building->setDisposition( i, j, type );
 				}
-			}}
-			break;
+			}
+			} break;
 		case StateFrame:
 			_building->setNbFrame( ch_simplified.toInt() );
 			break;
