@@ -5,9 +5,9 @@
 ** genericCell.cpp
 ** gereric class for managing (not graphical) cells
 **
-** Version : $Id: genericCell.cpp,v 1.12 2004/07/31 19:29:46 audoux Exp $
+** Version : $Id: genericCell.cpp,v 1.14 2004/12/18 11:39:24 audoux Exp $
 **
-** Author(s) : Pascal Audoux - Cyrille Verrier
+** Author(s) : Pascal Audoux - Cyrille Verrier - Nick Semenov
 **
 ** Date : 02/08/2000
 **
@@ -52,7 +52,8 @@ GenericCell::GenericCell( int row, int col )
 	  _col( col ),
 	  _transition( 0 ),
 	  _transitionCellType( 0 ),
-	  _decoration( 0 )
+	  _decorationGroup( 0 ),
+	  _decorationItem( 0 )
 {
 	_stop = true;
 	_lord = 0;
@@ -115,36 +116,38 @@ bool GenericCell::isFree()
 	return ret;
 }
 
-void GenericCell::setDecoration( int decoration )
+void GenericCell::setDecoration( uint group, uint item )
 {
-	_decoration = decoration;
+	_decorationGroup = group;
+	_decorationItem = item;
 
-	GenericDecoration * deco = DataTheme.decorations.at( decoration-1 );
-	if( deco ) {
-		for( uint i = 0; i < deco->getEffectNumber(); i++ ) {
-			switch( deco->getEffectType( i ) ) {
-			case GenericDecoration::NONE:
+	DecorationGroup * decoGroup = DataTheme.decorations.at( _decorationGroup );
+	
+	if( decoGroup ) {
+		for( uint i = 0; i < decoGroup->getEffectNumber(); i++ ) {
+			switch( decoGroup->getEffectType( i ) ) {
+			case DecorationGroup::NONE:
 				break;
-			case GenericDecoration::NO_MOVE:
+			case DecorationGroup::NO_MOVE:
 				_coeff = -1;
 				break;
-			case GenericDecoration::DECREASE_MOVECOST:
+			case DecorationGroup::DECREASE_MOVECOST:
 				if( _coeff != -1 ) {
-					uint rate = deco->getEffectParam( i );
+					uint rate = decoGroup->getEffectParam( i );
 					rate += 100;
 					_coeff = ( _coeff * 100 ) / rate;
 				}
 				break;
-			case GenericDecoration::INCREASE_MOVECOST:
+			case DecorationGroup::INCREASE_MOVECOST:
 				if( _coeff != -1 ) {
-					uint rate = deco->getEffectParam( i );
+					uint rate = decoGroup->getEffectParam( i );
 					rate += 100;
 					_coeff = ( _coeff * rate ) / 100;
 				}
 				break;
-			case GenericDecoration::NO_TECHNICAL:
+			case DecorationGroup::NO_TECHNICAL:
 				break;
-			case GenericDecoration::MAX_TECHNICAL:
+			case DecorationGroup::MAX_TECHNICAL:
 				break;
 			default:
 				logEE( "Should not happen" );
@@ -628,6 +631,179 @@ int computeTransitionCellType( GenericMap * theMap, GenericCell * cell )
 	return ret;
 }
 
+/**
+		Cells:
+		123
+		456
+		789
+
+		Types:
+		5 - lonely cell, 0	14	00100
+		25 		1		12	00101
+		45 		2		15	00110
+		56 		3		13    01100
+		58 		4		14	10100
+		245  	5		9	00111
+		256  	6		8	01101
+		258  	7		1	10101
+		456		8		2	01110
+		458		9		10	10110
+		568    	10		11	11100
+		2456	11		5	01111
+		2458	12		6	10111
+		2568	13		4	11101
+		4568	14		7	11110
+		24568	15		3	11111
+*/
+
+const char roadTypeTable[ 16 ] = {
+	13, 11, 14, 12, 13,  8,  7,  0, 
+	1,   9, 10,  4,  5,  3,  6,  2
+};
+
+const char binaryTable[ 16 ] = {
+	 4,  5,  6, 12, 20,  7, 13, 21,
+	14, 22, 28, 15, 23, 29, 30, 31
+};
+
+int getRoadTypeByBinary( char binary )
+{
+	int index = -1;
+	
+	for( int i = 0; i < 16; i++ ) {
+		if ( binary == binaryTable[ i ] )
+		{
+			index = i;
+			break;
+		} 
+	}
+	
+	if( index == -1 ) {
+		return -1;
+	}
+	
+	return roadTypeTable[ index ];
+}
+
+char smallCompute( GenericMap* theMap, GenericCell* cell, uint decorationGroup )
+{
+	int row = cell->getRow();
+	int col = cell->getCol();
+	
+	int height = theMap->getHeight();
+	int width = theMap->getWidth();
+	
+	GenericCell * neighbourUp = 0;
+	GenericCell * neighbourLeft = 0;
+	GenericCell * neighbourRight = 0;
+	GenericCell * neighbourDown = 0;
+	
+	char result = 0;
+	
+	if( cell->getDecorationGroup() == decorationGroup ) {
+		result |= 4;
+	}
+	
+	if ( row > 0 ) {
+		neighbourUp = theMap->at ( row - 1, col );
+		if( neighbourUp->getDecorationGroup() == decorationGroup ) {
+			result |= 1;
+		}
+	}
+	
+	if ( col > 0 ) {
+		neighbourLeft = theMap->at ( row, col - 1 );
+		if( neighbourLeft->getDecorationGroup() == decorationGroup ) {
+			result |= 2;
+		}
+	}
+	
+	if ( row < height - 1 ) {
+		neighbourDown = theMap->at ( row + 1, col );
+		if( neighbourDown->getDecorationGroup() == decorationGroup ) {
+			result |= 16;
+		}
+	}
+	
+	if ( col < width - 1 ) {
+		neighbourRight = theMap->at ( row, col + 1  );
+		if( neighbourRight->getDecorationGroup() == decorationGroup ) {
+			result |= 8;
+		}
+	}
+	
+	return result;
+}
+
+void computeAndChangeRoadType( GenericMap* theMap, GenericCell* cell, uint decorationGroup )
+{
+	cell->setDecoration( decorationGroup, 0 );
+
+	int row = cell->getRow();
+	int col = cell->getCol();
+	
+	int height = theMap->getHeight();
+	int width = theMap->getWidth();
+	
+	char binary = smallCompute( theMap, cell, decorationGroup );
+	
+	int roadType = getRoadTypeByBinary( binary );
+	
+	if( roadType != -1 ) {
+		cell->setDecoration( decorationGroup, roadType );
+	}
+	
+	GenericCell* neighbourUp = 0;
+	GenericCell* neighbourLeft = 0;
+	GenericCell* neighbourRight = 0;
+	GenericCell* neighbourDown = 0;
+	
+	if ( row > 0 ) {
+		neighbourUp = theMap->at( row - 1, col );
+		
+		char newBinary = smallCompute( theMap, neighbourUp, decorationGroup );
+		int newRoadType = getRoadTypeByBinary ( newBinary );
+		
+		if( newRoadType != -1 ) {
+			neighbourUp->setDecoration( decorationGroup, newRoadType );
+		}
+	}
+	
+	if( col > 0 ) {
+		neighbourLeft = theMap->at( row, col - 1 );
+		
+		char newBinary = smallCompute ( theMap, neighbourLeft, decorationGroup );
+		int newRoadType = getRoadTypeByBinary ( newBinary );
+		
+		if( newRoadType != -1 ) {
+			neighbourLeft->setDecoration( decorationGroup, newRoadType );
+		}
+	}
+	
+	if( row < height - 1 ) {
+		neighbourDown = theMap->at( row + 1, col );
+		
+		char newBinary = smallCompute( theMap, neighbourDown, decorationGroup );
+		int newRoadType = getRoadTypeByBinary ( newBinary );
+		
+		if( newRoadType != -1 ) {
+			neighbourDown->setDecoration ( decorationGroup, newRoadType );
+		}
+	}
+	
+	if ( col < width - 1 ) {
+		neighbourRight = theMap->at( row, col + 1  );
+		
+		char newBinary = smallCompute ( theMap, neighbourRight, decorationGroup );
+		int newRoadType = getRoadTypeByBinary ( newBinary );
+		
+		if( newRoadType != -1 ) {
+			neighbourRight->setDecoration ( decorationGroup, newRoadType );
+		}
+	}
+	
+}
+
 
 
 
