@@ -5,7 +5,7 @@
 ** genericCell.h
 **  generic class for managing (not graphical) cells
 **
-** Version : $Id: genericCell.h,v 1.8 2004/07/31 19:29:46 audoux Exp $
+** Version : $Id: genericCell.h,v 1.10 2004/12/18 11:39:24 audoux Exp $
 **
 ** Author(s) : Pascal Audoux - Cyrille Verrier
 **
@@ -98,10 +98,13 @@ public:
 	}
 
 	/** \return Returns the type of decoration of this cell */
-	int getDecoration() { return _decoration; }
+	uint getDecorationGroup() { return _decorationGroup; }
+	
+	/** \return Returns the item of decoration of this cell */
+	uint getDecorationItem() { return _decorationItem; }
 
 	/** Sets the type of decoration for this cell */
-	virtual void setDecoration( int decoration );
+	virtual void setDecoration( uint group, uint item );
 
 	/** Return row of the cell */
 	int getRow() const { return _row; }
@@ -154,7 +157,7 @@ protected:
 	int _row , _col;
 	int _transition;
 	int _transitionCellType;
-	int _decoration;
+	uint _decorationGroup, _decorationItem;
 	GenericLord * _lord;
 	GenericBuilding * _building;
 	GenericBase * _base;
@@ -287,6 +290,7 @@ int computeTransition( GenericMap * theMap, GenericCell * cell );
 
 int computeTransitionCellType( GenericMap * theMap, GenericCell * cell );
 
-
+/** Compute and change road type for Cell and its neibours */
+void computeAndChangeRoadType( GenericMap* theMap, GenericCell* cell, uint decorationGroup ); 
 
 #endif // GENERICCELL_H
