@@ -5,7 +5,7 @@
 ** genericDecoration.cpp
 ** manage decoration
 **
-** Version : $Id: genericDecoration.cpp,v 1.7 2004/08/07 12:02:48 audoux Exp $
+** Version : $Id: genericDecoration.cpp,v 1.8 2004/12/18 11:37:03 audoux Exp $
 **
 ** Author(s) : Pascal Audoux
 **
@@ -36,96 +36,23 @@ extern QString DATA_PATH;
 
 GenericDecoration::GenericDecoration()
 {
-	_name = "";
-	_info = "";
-	//_technicEffect = 0;
-	//_moveEffect = 0;
-	//_moveFactor = 0;
-	//_width = 1;
-	//_height = 1;
-	//_mainRow = 0;
-	//_mainCol = 0;
-	//_dispo = new int * [1];
-	//_dispo[0] = new int[1];
-	//_dispo[0][0] = 1;
-	_effectTypeList.setAutoDelete( true );
-	_effectParamList.setAutoDelete( true );
+	_group = 0;
 }
 
 GenericDecoration::~GenericDecoration()
 {
 	clear();
-	_effectTypeList.clear();
-	_effectParamList.clear();
 }
 
 void GenericDecoration::clear()
 {
 	GenericMapDisposition::clear();
-	
-	//_height = 0;
-	//_width = 0;
-	//_mainRow = 0;
-	//	_mainCol = 0;
 }
-/*
-void GenericDecoration::setDispoSize( uint height, uint width )
-{
-	if( ( height > 0 ) && ( width > 0 ) ) {
-		uint i;
-		clear();
-		_width = width;
-		_height = height;
-		_dispo = new int * [height];
-		for( i = 0; i < height; i++ ) {
-			_dispo[i] = new int[width];
-		}
-		for( i = 0; i < height; i++ ) {
-			for( uint j = 0; j < width; j++ ) {
-				_dispo[i][j] = 0;
-			}
-		}
-	}
-}
-
-int GenericDecoration::getDispo( uint row, uint col )
-{
-	int ret = 0;
-
-	if( ( row < _height ) && ( col < _width ) ) {
-		ret = _dispo[row][col];
-	}
-
-	return ret;
-}
-
-void GenericDecoration::setDispo( uint row, uint col, int type )
-{
-	if( ( row < _height ) && ( col < _width ) ) {
-		_dispo[row][col] = type;
-		if( type == 1 ) {
-			_mainRow = row;
-			_mainCol = col;
-		}
-	}
-}*/
 
 void GenericDecoration::save( QTextStream * ts, int indent )
 {
-	uint i;
-
 	indentation( ts, indent );
 	*ts << "<decoration>" << endl;
-	indentation( ts, indent );
-	*ts << "\t<name>" << _name << "</name>" << endl;
-	indentation( ts, indent );
-	*ts << "\t<info>" << _info << "</info>" << endl;
-	
-	for( i = 0; i < _effectTypeList.count(); ++i ) {
-		indentation( ts, indent );
-		*ts << "\t<effect type=\"" << (uint)(* ( _effectTypeList.at( i ) ) ) << "\">";
-		*ts << ( * ( _effectParamList.at( i ) ) ) << "</effect>" << endl;
-	}
 	
 	GenericMapDisposition::save( ts, indent + 1 );
 		
@@ -133,12 +60,56 @@ void GenericDecoration::save( QTextStream * ts, int indent )
 	*ts << "</decoration>" << endl;
 }
 
-uint GenericDecoration::getEffectNumber()
+
+//
+// ----- DecorationGroup -----
+//
+DecorationGroup::DecorationGroup()
+{
+	_name = "";
+	_info = "";
+	_effectTypeList.setAutoDelete( true );
+	_effectParamList.setAutoDelete( true );
+}
+
+DecorationGroup::~DecorationGroup()
+{
+	_effectTypeList.clear();
+	_effectParamList.clear();
+}
+
+void DecorationGroup::save( QTextStream * ts, int indent )
+{
+	uint nb = count();
+	
+	indentation( ts, indent );
+	*ts << "<group>" << endl;
+	
+	indentation( ts, indent+1 );
+	*ts << "\t<name>" << _name << "</name>" << endl;
+	indentation( ts, indent+1 );
+	*ts << "\t<info>" << _info << "</info>" << endl;
+	
+	for( uint i = 0; i < _effectTypeList.count(); ++i ) {
+		indentation( ts, indent+1 );
+		*ts << "\t<effect type=\"" << (uint)(* ( _effectTypeList.at( i ) ) ) << "\">";
+		*ts << ( * ( _effectParamList.at( i ) ) ) << "</effect>" << endl;
+	}
+	
+	for( uint i = 0; i < nb; i++ ) {
+		at( i )->save( ts, indent + 1 );
+	}
+	
+	indentation( ts, indent );
+	*ts << "</group>" << endl;
+}
+
+uint DecorationGroup::getEffectNumber()
 {
 	return _effectTypeList.count();
 }
 
-GenericDecoration::EffectType GenericDecoration::getEffectType( uint num )
+DecorationGroup::EffectType DecorationGroup::getEffectType( uint num )
 {
 	EffectType ret = NONE;
 
@@ -149,7 +120,7 @@ GenericDecoration::EffectType GenericDecoration::getEffectType( uint num )
 	return ret;
 }
 
-uint GenericDecoration::getEffectParam( uint num )
+uint DecorationGroup::getEffectParam( uint num )
 {
 	uint ret = 0;
 
@@ -160,19 +131,19 @@ uint GenericDecoration::getEffectParam( uint num )
 	return ret;
 }
 
-void GenericDecoration::addEffect( GenericDecoration::EffectType type, uint param )
+void DecorationGroup::addEffect( DecorationGroup::EffectType type, uint param )
 {
 	_effectTypeList.append( new EffectType( type ) );
 	_effectParamList.append( new uint( param ) );
 }
 
-void GenericDecoration::clearEffects()
+void DecorationGroup::clearEffects()
 {
 	_effectTypeList.clear();
 	_effectParamList.clear();
 }
 
-QString GenericDecoration::getEffectTypeString( EffectType type )
+QString DecorationGroup::getEffectTypeString( EffectType type )
 {
 	QString ret = "Unknown";
 
@@ -244,7 +215,6 @@ bool DecorationList::save()
 	ts << "<decorations>" << endl;
 
 	for( uint i = 0; i < count(); i++ ) {
-		//GenericDecoration * decor = at( i );
 		at( i )->save( &ts, 1 );
 	}
 	
@@ -270,7 +240,7 @@ bool DecorationHandler::startDocument()
 	_errorProt = "";
 	_list->clear();	
 	_state = StateInit;
-	
+	_list->append( new DecorationGroup() );
 	return true;
 }
 	
@@ -278,7 +248,18 @@ bool DecorationHandler::startElement( const QString &, const QString &, const QS
 {
 	if( qName == "decorations" && _state == StateInit ) {
 		_state = StateDocument;
-	} else if ( qName == "decoration" && _state == StateDocument ) {
+	} else if ( qName == "group" && _state == StateDocument ) {
+		_state = StateGroup;
+		_group = new DecorationGroup();
+	} else if ( qName == "name" && _state == StateGroup ) {
+		_state = StateName;
+	} else if ( qName == "info" && _state == StateGroup ) {
+		_state = StateInfo;
+	} else if ( qName == "effect" && _state == StateGroup ) {
+		_state = StateEffect;
+		_type = (DecorationGroup::EffectType) atts.value( "type" ).toInt();
+		_param = 0;
+	} else if ( qName == "decoration" && _state == StateGroup ) {
 		_state = StateDecoration;
 		_decor = new GenericDecoration();
 	} else if ( qName == "disposition" && _state == StateDecoration ) {
@@ -288,14 +269,6 @@ bool DecorationHandler::startElement( const QString &, const QString &, const QS
 		if( ( _height != 0 ) && ( _width != 0 ) ) {
 			_decor->init( _height, _width );
 		}
-	} else if ( qName == "name" && _state == StateDecoration ) {
-		_state = StateName;
-	} else if ( qName == "info" && _state == StateDecoration ) {
-		_state = StateInfo;
-	} else if ( qName == "effect" && _state == StateDecoration ) {
-		_state = StateEffect;
-		_type = (GenericDecoration::EffectType) atts.value( "type" ).toInt();
-		_param = 0;
 	} else {
 		return false;
 	}
@@ -305,23 +278,28 @@ bool DecorationHandler::startElement( const QString &, const QString &, const QS
 bool DecorationHandler::endElement( const QString &, const QString &, const QString & )
 {
 	switch ( _state ) {
-	case StateDecoration:
+	case StateGroup:
+		_list->append( _group );
 		_state = StateDocument;
-		_list->append( _decor );
+		break;
+	case StateName:
+		_state = StateGroup;
+		break;
+	case StateInfo:
+		_state = StateGroup;
+		break;
+	case StateEffect:
+		_state = StateGroup;
+		_group->addEffect( _type, _param );
+		break;
+	case StateDecoration:
+		_state = StateGroup;
+		_group->append( _decor );
+		_decor->setGroup( _group );
 		break;
 	case StateDisposition:
 		_state = StateDecoration;
 		break;
-	case StateName:
-		_state = StateDecoration;
-		break;
-	case StateInfo:
-		_state = StateDecoration;
-		break;
-	case StateEffect:
-		_state = StateDecoration;
-		_decor->addEffect( _type, _param );
-		break;
 	default:
 		// do nothing
 		break;
@@ -350,23 +328,14 @@ bool DecorationHandler::characters( const QString& ch )
 		}
 		} break;
 	case StateName:
-		_decor->setName( ch_simplified );
+		_group->setName( ch_simplified );
 		break;
 	case StateInfo:
-		_decor->setInfo( ch_simplified );
+		_group->setInfo( ch_simplified );
 		break;
 	case StateEffect:
 		_param = ch_simplified.toInt();
 		break;
-	/*case StateMoveEffect:
-		_decor->setMoveEffect( ch_simplified.toInt() );
-		break;
-	case StateMoveFactor:
-		_decor->setMoveFactor( ch_simplified.toInt() );
-		break;
-	case StateTechnicEffect:
-		_decor->setTechnicEffect( ch_simplified.toInt() );
-		break;*/
 	default:
 	    return false;
     }
