@@ -5,7 +5,7 @@
 ** genericDecoration.h
 ** manage decoration
 **
-** Version : $Id: genericDecoration.h,v 1.5 2004/07/31 17:11:43 audoux Exp $
+** Version : $Id: genericDecoration.h,v 1.6 2004/12/18 11:37:03 audoux Exp $
 **
 ** Author(s) : Pascal Audoux
 **
@@ -37,6 +37,8 @@
 // application specific include files
 #include "libCommon/genericMapDisposition.h"
 
+class DecorationGroup;
+
 /*              ------------------------------
  *                         GenericDecoration
  *              ------------------------------ */
@@ -45,6 +47,28 @@
 class GenericDecoration : public GenericMapDisposition
 {
 
+public:
+	/** Constructor */
+	GenericDecoration();
+
+	/** Destructor */
+	virtual ~GenericDecoration();
+
+	/** Saves the data of a decoration */
+	void save( QTextStream * ts, int indent );
+	
+	void setGroup( DecorationGroup * group ) { _group = group; }
+	
+	DecorationGroup * getGroup() { return _group; }
+
+private:
+	void clear();
+	
+	DecorationGroup * _group;
+};
+
+class DecorationGroup : public QPtrList<GenericDecoration>
+{
 public:
 	enum EffectType {
 		NONE = 0,
@@ -54,23 +78,24 @@ public:
 		NO_TECHNICAL,
 		MAX_TECHNICAL
 	};
+	
 	/** Constructor */
-	GenericDecoration();
-
+	DecorationGroup();
+	
 	/** Destructor */
-	virtual ~GenericDecoration();
-
+	virtual ~DecorationGroup();
+	
 	/** \return Returns the name of this type of decoration */
-	QString getName() { return _name; }
+	const QString & getName() { return _name; }
 
 	/** Sets a name to the decoration */
-	void setName( QString name ) { _name = name; }
+	void setName( const QString & name ) { _name = name; }
 
 	/** \return Returns some information about this decoration */
-	QString getInfo() { return _info; }
+	const QString & getInfo() { return _info; }
 
 	/** Sets some info about this decoration */
-	void setInfo( QString info ) { _info = info; }
+	void setInfo( const QString & info ) { _info = info; }
 
 	static QString getEffectTypeString( EffectType type );
 
@@ -81,48 +106,20 @@ public:
 	uint getEffectParam( uint num );
 
 	void addEffect( EffectType, uint param );
-
+	
 	void clearEffects();
-
-	/** \return Returns the width of the decoration */
-	//uint getDispoWidth() { return _width; }
-
-	/** \return Returns the width of the decoration */
-	//uint getDispoHeight() { return _height; }
-
-	/** Sets the size of decoration */
-	//void setDispoSize( uint height, uint width );
-
-	/** \return Returns the disposition of the cell (row, col) */
-	//int getDispo( uint row, uint col );
-
-	/** Sets the disposition of the cell (row, col). 0->nothing, 1->main row and 2-> occupied */
-	//void setDispo( uint row, uint col, int type );
-
-	/** \return Returns the row of the main cell of this decoration */
-	//int getMainRow() { return _mainRow; }
-
-	/** \return Returns the col of the main cell of this decoration */
-	//int getMainCol() { return _mainCol; }
-
+	
 	/** Saves the data of a decoration */
 	void save( QTextStream * ts, int indent );
-
-private:
-	void clear();
-
+	
+protected:
 	QString _name, _info;
 	QPtrList<EffectType> _effectTypeList;
 	QPtrList<uint> _effectParamList;
-	//int _technicEffect, _moveEffect;
-	//int _moveFactor;
-	//uint _width, _height;
-	//int _mainCol, _mainRow;
-	//int ** _dispo;
 };
 
-/** List for managing the different types of decorations */
-class DecorationList : public QPtrList<GenericDecoration>
+/** List for managing the different decoration group */
+class DecorationList : public QPtrList<DecorationGroup>
 {
 public:
 	/** Constructor */
@@ -162,9 +159,10 @@ public:
 
 private:
 	DecorationList * _list;
+	DecorationGroup * _group;
 	GenericDecoration * _decor;
 	int _height, _width;
-	GenericDecoration::EffectType _type;
+	DecorationGroup::EffectType _type;
 	uint _param;
 
 	QString _errorProt;
@@ -172,17 +170,13 @@ private:
 	enum State {
 		StateInit,
 		StateDocument,
+		StateGroup,
 		StateDecoration,
 		StateDisposition,
 		StateName,
 		StateInfo,
 		StateEffect,
 		StateEffectParam
-		//StateMove,
-		//StateMoveEffect,
-		//StateMoveFactor,
-		//StateTechnic,
-		//StateTechnicEffect,
 	};
 	State _state;
 };
