@@ -5,7 +5,7 @@
 ** genericInsideBuilding.cpp
 ** describes building inside bases
 **
-** Version : $Id: genericInsideBuilding.cpp,v 1.4 2004/07/28 21:07:03 lusum Exp $
+** Version : $Id: genericInsideBuilding.cpp,v 1.5 2004/12/23 22:50:05 audoux Exp $
 **
 ** Author(s) : Pascal Audoux
 **
@@ -84,6 +84,13 @@ InsideBuildingModel::InsideBuildingModel()
 	}
 }
 
+InsideBuildingModel::~InsideBuildingModel()
+{
+	if( _action ) {
+		delete _action;
+	}
+}
+
 void InsideBuildingModel::addRequirement( int req )
 {
 	int * item = new int( req );
