@@ -5,7 +5,7 @@
 ** insideBuilding.h
 ** describes building inside bases
 **
-** Version : $Id: genericInsideBuilding.h,v 1.3 2004/07/31 19:29:46 audoux Exp $
+** Version : $Id: genericInsideBuilding.h,v 1.4 2004/12/23 22:50:05 audoux Exp $
 **
 ** Author(s) : Pascal Audoux
 **
@@ -39,7 +39,7 @@
 class InsideAction;
  
 /**              ------------------------------
- *                    GenericInsideBuilding
+ *                    InsideBuildingModel
  **              ------------------------------ */
 
 class InsideBuildingModel
@@ -47,6 +47,8 @@ class InsideBuildingModel
 public:
 	/** Constructor */
 	InsideBuildingModel();
+	
+	virtual ~InsideBuildingModel();
 
 	uint getRace() { return _race; }
 
@@ -96,7 +98,10 @@ private:
 	uint _mcost[ MAX_RESS ];
 };
 
-/** comment for the class */
+/**              ------------------------------
+ *                    GenericInsideBuilding
+ **              ------------------------------ */
+
 class GenericInsideBuilding
 {
  
