@@ -5,7 +5,7 @@
 ** genericLord.cpp
 ** manages a lord and its units
 **
-** Version : $Id: genericLord.cpp,v 1.15 2004/07/28 21:09:04 lusum Exp $
+** Version : $Id: genericLord.cpp,v 1.17 2004/12/23 22:52:18 audoux Exp $
 **
 ** Author(s) : Pascal Audoux
 **
@@ -159,7 +159,7 @@ GenericLord::GenericLord()
 	}
 	
 	for(int i = PR_ENEMY;i<=PR_LAST;i++){ 
-		_priorities[i]=i;
+		_priorities[i]=(i*10);
 	}	
 
 	_artefactManager = new ArtefactManager( this );
@@ -170,6 +170,7 @@ GenericLord::GenericLord()
 
 GenericLord::~GenericLord()
 {
+	clearUnits();
 	delete _artefactManager;
 }
 
