@@ -5,7 +5,7 @@
 ** genericLord.h
 ** manages a lord and its units
 **
-** Version : $Id: genericLord.h,v 1.11 2004/08/08 12:08:07 audoux Exp $
+** Version : $Id: genericLord.h,v 1.13 2004/12/05 15:09:43 lusum Exp $
 **
 ** Author(s) : Pascal Audoux
 **
@@ -50,14 +50,16 @@ class GenericLordModel;
 class LordCategoryModel;
 
 enum {
-	PR_ENEMY = 0,
+	PR_ENEMY = 1,
 	PR_BASE,
+	PR_BASEOWNER,
 	PR_BUILD,
 	PR_ART,
 	PR_BONUS,
 	PR_CHEST,
 	PR_CREAT,
-	PR_LAST
+	PR_EXPLORE,
+	PR_LAST 
 };
 
 
@@ -70,7 +72,6 @@ LordCharac detectCharac( const QString & type );
 
 QString getCharacName( LordCharac charac );
 
-/** comment for the class */
 class GenericLord
 {
 
@@ -143,7 +144,7 @@ public:
 	/** Return the unit 'num' */
 	GenericFightUnit * getUnit( int num ) { return _units[num]; }
 	
-	void setPrio( int num , int value) { _priorities[num] = num; }
+	void setPrio( int num , int value) { _priorities[num] = value; }
 	
 	/** Return the unit 'num' */
 	int getPrio( int num ) { return _priorities[num]; }
