@@ -5,7 +5,7 @@
 ** genericMap.cpp
 ** gereric class for managing (not graphical) map
 **
-** Version : $Id: genericMap.cpp,v 1.7 2004/07/27 21:04:34 audoux Exp $
+** Version : $Id: genericMap.cpp,v 1.9 2004/12/19 15:10:10 lusum Exp $
 **
 ** Author(s) : Pascal Audoux - Cyrille Verrier
 **
@@ -94,7 +94,8 @@ void GenericMap::changeCell( int i,
 		      int typ,
 		      int transition,
 		      int typtra,
-		      int decoration )
+		      uint decorationGroup,
+		      uint decorationItem )
 {
 	//logDD("chg cell %d %d %d %d %d %d", i, j,
 	//      typ, transition, typtra, decoration );
@@ -103,7 +104,7 @@ void GenericMap::changeCell( int i,
 		_theCells[i][j]->setType( typ );
 		_theCells[i][j]->setTransition( transition );
 		_theCells[i][j]->setTransitionCellType( typtra );
-		_theCells[i][j]->setDecoration( decoration );
+		_theCells[i][j]->setDecoration( decorationGroup, decorationItem );
 	} else {
 		logEE( "Cell type should be unknown" );
 	}
@@ -142,6 +143,7 @@ bool GenericMap::load( QTextStream * ts, int width, int heigth )
 		_theCells[i] = new GenericCell *[_width];
 	}
 	int val;
+	uint item;
 
 	// Loading base cell
 	for( i = 0; i < _height; i++ ) {
@@ -201,7 +203,10 @@ bool GenericMap::load( QTextStream * ts, int width, int heigth )
 		for( j = 0; j < _width; j++ ) {
 			if( ! ts->atEnd() ) {
 				*ts >> val;
-				_theCells[i][j]->setDecoration( val );
+				if( val ) {
+					*ts >> item;
+					_theCells[i][j]->setDecoration( val, item );
+				}
 			} else {
 				logEE("Stream too short");
 				return false;
@@ -270,7 +275,10 @@ void GenericMap::save( QTextStream * ts )
 	for( i = 0; i < _height; i++ ) {
 		*ts << "\t\t";
 		for( j = 0; j < _width; j++ ) {
-			*ts << (int)_theCells[i][j]->getDecoration() << " ";
+			*ts << (int)_theCells[i][j]->getDecorationGroup() << " ";
+			if( (int)_theCells[i][j]->getDecorationGroup() ) {
+				*ts << (int)_theCells[i][j]->getDecorationItem() << " ";
+			}
 		}
 		*ts << endl;
 	}
@@ -282,8 +290,9 @@ void GenericMap::save( QTextStream * ts )
 
 void GenericMap::computeStoppable()
 {
-	for( uint i = 0; i < _width; i++ ) {
-		for( uint j = 0; j < _height; j++ ) {
+	for( uint i = 0; i < _height; i++ ) {
+		for( uint j = 0; j < _width; j++ ) {
+			_theCells[i][j]->setStoppable( true );
 			if( _theCells[i][j]->getBase() ) {
 				computeStoppable( _theCells[i][j]->getBase() );
 			}
@@ -412,29 +421,29 @@ void GenericMap::cleanData()
 				_theCells[i][j]->setLord( 0 );
 			}
 			if( _theCells[i][j]->getBuilding() ) {
-				_theCells[i][j]->setBuilding(0);
+				_theCells[i][j]->setBuilding( 0 );
 			}
 			if( _theCells[i][j]->getBase() )	{
-				_theCells[i][j]->setBase(0);
+				_theCells[i][j]->setBase( 0 );
 			}
 			if( _theCells[i][j]->getCreature() ) {
-				_theCells[i][j]->setCreature(0);
+				_theCells[i][j]->setCreature( 0 );
 			}
 			if( _theCells[i][j]->getTransition() ) {
-				_theCells[i][j]->setTransition(0);
+				_theCells[i][j]->setTransition( 0 );
 				_theCells[i][j]->setTransitionCellType( 0 );
 			}
 			if( _theCells[i][j]->getType() ) {
-				_theCells[i][j]->setType(0);
+				_theCells[i][j]->setType( 0 );
 			}
 			if( _theCells[i][j]->getCoeff() ) {
-				_theCells[i][j]->setCoeff(0);
+				_theCells[i][j]->setCoeff( 0 );
 			}
-			if( _theCells[i][j]->getDecoration() ) {
-				_theCells[i][j]->setDecoration(0);
+			if( _theCells[i][j]->getDecorationGroup() ) {
+				_theCells[i][j]->setDecoration( 0, 0 );
 			}
 			if( _theCells[i][j]->getEvent() ) {
-				_theCells[i][j]->setEvent(0);
+				_theCells[i][j]->setEvent( 0 );
 			}
 		}
 	}
