@@ -5,7 +5,7 @@
 ** genericMap.h
 **  generic class for managing (not graphical) map
 **
-** Version : $Id: genericMap.h,v 1.4 2004/07/27 21:04:34 audoux Exp $
+** Version : $Id: genericMap.h,v 1.5 2004/12/18 11:43:59 audoux Exp $
 **
 ** Author(s) : Pascal Audoux - Cyrille Verrier
 **
@@ -81,7 +81,7 @@ public:
 	virtual bool load( const QString filename );
 
 	virtual void changeCell( int i, int j, int typ,
-		      int transition, int typtra, int decoration );
+		      int transition, int typtra, uint decorationGroup, uint decorationItem );
 	
 	/** Save a map */
 	void save( QTextStream * );
