@@ -5,7 +5,7 @@
 ** genericMapCreature.h
 ** Manages creatures on map
 **
-** Version : $Id: genericMapCreature.h,v 1.10 2004/07/31 19:29:46 audoux Exp $
+** Version : $Id: genericMapCreature.h,v 1.12 2004/12/04 13:34:47 audoux Exp $
 **
 ** Author(s) : Pascal Audoux
 **
@@ -54,6 +54,14 @@ public:
     		Aggressive,
 		Hostile
 	};
+	
+	/** Creature growth mode */
+	enum GrowthMode
+	{
+		Stable,
+		FixedPercentage,
+		VariablePercentage
+	};
 
 	/** Constructor */
 	GenericMapCreature();
@@ -81,13 +89,15 @@ public:
 		_behaviour = behaviour;
 	}
 
-       CreatureBehaviour getBehaviour () {
-           return _behaviour;
-       }
+	CreatureBehaviour getBehaviour () {
+		return _behaviour;
+	}
 
 	QString getBehaviourString();
 
 	static QString getBehaviourString( CreatureBehaviour behaviour );
+	
+	static QString getGrowthString( GrowthMode growth );
 
 	bool isFleeing() {
 		return _flee;
@@ -133,6 +143,16 @@ public:
 	bool isLookingRight() { return _lookingRight; }
 
 	virtual void setLookingRight( bool state ) { _lookingRight = state; }
+	
+	void setGrowthMode( GrowthMode growth ) { _growth = growth; }
+	
+	GrowthMode getGrowthMode() { return _growth; }
+	
+	void setGrowthParam( uint param, uint value );
+	
+	uint getGrowthParam( uint param );
+	
+	void grow();
 
 protected:
 	QPtrVector<unsigned int> _stacks;
@@ -140,6 +160,8 @@ protected:
 	GenericCell * _cell;
 	unsigned int _categoryNumber;
 	CreatureBehaviour _behaviour;
+	GrowthMode _growth;
+	uint _growthParam0, _growthParam1;
 	bool _flee;
 	bool _lookingRight;
 	bool _estimated;
