@@ -5,7 +5,7 @@
 ** genericPlayer.cpp
 ** manage a player
 **
-** Version : $Id: genericPlayer.cpp,v 1.18 2004/10/12 21:38:08 audoux Exp $
+** Version : $Id: genericPlayer.cpp,v 1.21 2004/12/24 18:28:18 lusum Exp $
 **
 ** Author(s) : Pascal Audoux
 **
@@ -37,6 +37,7 @@
 #include "libCommon/genericMap.h"
 #include "libCommon/log.h"
 #include "libCommon/pathFinder.h"
+#include "libCommon/priceMarket.h"
 
 
 extern DataTheme DataTheme;
@@ -73,6 +74,8 @@ GenericPlayer::GenericPlayer( GenericMap * theMap )
 	_theBase.setAutoDelete( false );
 	_map = theMap;
 	_vision = 0;
+	_price = new PriceMarket();
+	_isTeamSet = false;
 	setName( QString( "New player" ) );
 }
 
@@ -107,6 +110,9 @@ GenericPlayer::~GenericPlayer()
 		}
 		delete [] _vision;
 	}
+ if(_price){
+	 delete _price;
+ }
 }
 
 void GenericPlayer::save( QTextStream * ts, int indent )
