@@ -5,7 +5,7 @@
 ** genericPlayer.h
 ** class that manage a player
 **
-** Version : $Id: genericPlayer.h,v 1.10 2004/08/23 18:52:43 lusum Exp $
+** Version : $Id: genericPlayer.h,v 1.11 2004/12/05 15:08:48 lusum Exp $
 **
 ** Author(s) : Pascal Audoux
 **
@@ -43,6 +43,7 @@ class QTextStream;
 
 class Creature;
 class GenericMap;
+class PriceMarket;
 class InsideBuildingModel;
 
 /*              ------------------------------
@@ -238,6 +239,10 @@ public:
 	bool canSee( uint row, uint col );
 
 	bool canSee( GenericCell * cell );
+	
+	PriceMarket * getPriceMarket() { return _price;}
+	
+	void setPriceMarket(PriceMarket * price) { _price = price;}
 
 protected:
 	uint _ress[ MAX_RESS ];
@@ -255,6 +260,7 @@ protected:
 	GenericLord * _selectedLord;
 	GenericBase * _selectedBase;
 	GenericMap * _map;
+	PriceMarket  * _price;
 
 	int ** _vision;
 };
