@@ -5,7 +5,7 @@
 ** priceMarket.cpp
 ** compute prices on markets (for trading resources)
 **
-** Version : $Id: priceMarket.cpp,v 1.3 2003/09/27 10:29:01 audoux Exp $
+** Version : $Id: priceMarket.cpp,v 1.4 2004/12/07 19:03:51 lusum Exp $
 **
 ** Author(s) : Pascal Audoux
 **
@@ -38,7 +38,11 @@ PriceMarket::PriceMarket()
 	uint nbRes = DataTheme.resources.count();
 	_resources = new int[ nbRes ];
 	for( uint i = 0; i < nbRes; i++ ) {
-		_resources[i] = 1;
+		if( i != 0){
+			_resources[i] = 100;
+		} else {
+			_resources[i] = 1;
+		}
 	}
 }
 
