@@ -5,7 +5,7 @@
 ** fight.cpp
 ** Manages the whole fight
 **
-** Version : $Id: fight.cpp,v 1.20 2004/08/08 14:32:32 audoux Exp $
+** Version : $Id: fight.cpp,v 1.22 2004/12/08 11:19:58 lusum Exp $
 **
 ** Author(s) : Cyrille Verrier, Pascal Audoux
 **
@@ -27,14 +27,15 @@
 #include "fight.h"
 
 #include <assert.h>
-// include files for QT
 
+// include files for QT
 #include <qlayout.h>
 #include <qlabel.h>
 #include <qcursor.h>
 #include <qmessagebox.h>
 #include <qpushbutton.h>
 #include <qmultilinedit.h>
+#include <qtooltip.h>
 // application specific include
 #include "conf.h"
 #include "libCommon/attalSocket.h"
@@ -65,7 +66,7 @@ Fight::Fight( QWidget * parent , const char * name )
 
 	_socket = 0;
 	_game = 0;
- _popup = 0;
+	_popup = 0;
 	_isAttack = true;
 	_isActive = false;
 	_isCreature = false;
@@ -326,6 +327,9 @@ void Fight::slot_defend()
 
 void Fight::handleSocket()
 {
+	_game->handleSocket();
+	_socket->reReadData();
+
 	switch( _socket->getCla1() ) {
 	case SO_MSG:
 		socketMsg();
@@ -760,26 +764,38 @@ FightControl::FightControl( QWidget * parent, const char * name )
 	QPushButton * butControl = new QPushButton( this );
 	butControl->setFixedSize( 50, 50 );
 	butControl->setPixmap( IMAGE_PATH + "misc/btn_control.png" );
+	QToolTip::add( butControl, tr( "Options" ) );
+	
 	QPushButton * butSurrender = new QPushButton( this );
 	butSurrender->setFixedSize( 50, 50 );
 	butSurrender->setPixmap( IMAGE_PATH + "misc/btn_surrender.png" );
+	QToolTip::add( butSurrender, tr( "Surrender" ) );
+	
 	QPushButton * butFlee = new QPushButton( this );
 	butFlee->setFixedSize( 50, 50 );
 	butFlee->setPixmap( IMAGE_PATH + "misc/btn_flee.png" );
+	QToolTip::add( butFlee, tr( "Flee" ) );
+	
 	QPushButton * butAuto = new QPushButton( this );
 	butAuto->setFixedSize( 50, 50 );
 	butAuto->setPixmap( IMAGE_PATH + "misc/btn_auto.png" );
+	QToolTip::add( butAuto, tr( "Auto-fight" ) );
+	
 	QPushButton * butSpell = new QPushButton( this );
 	butSpell->setFixedSize( 50, 50 );
 	butSpell->setPixmap( IMAGE_PATH + "misc/btn_spell.png" );
+	QToolTip::add( butSpell, tr( "Spells" ) );
+	
 	QPushButton * butWait = new QPushButton( this );
 	butWait->setFixedSize( 50, 50 );
 	butWait->setPixmap( IMAGE_PATH + "misc/btn_wait.png" );
+	QToolTip::add( butWait, tr( "Wait" ) );
+	
 	QPushButton * butDefend = new QPushButton( this );
 	butDefend->setFixedSize( 50, 50 );
 	butDefend->setPixmap( IMAGE_PATH + "misc/btn_defend.png" );
-	/*QMultiLineEdit * edit = new QMultiLineEdit( this );
-	edit->setReadOnly( true );*/
+	QToolTip::add( butDefend, tr( "Defend" ) );
+	
 	_chat = new ChatWidget( this );
 	_chat->setFixedHeight( 50 );
 
