@@ -5,7 +5,7 @@
 ** attalServer.cpp
 ** the server : manage connections
 **
-** Version : $Id: attalServer.cpp,v 1.20 2004/10/08 23:04:08 audoux Exp $
+** Version : $Id: attalServer.cpp,v 1.31 2004/12/27 23:02:51 audoux Exp $
 **
 ** Author(s) : Pascal Audoux
 **
@@ -222,6 +222,10 @@ void AttalServer::sendGameInfoPlayer()
 	}
 }
 
+void AttalServer::sendConnectionName(const QString & name, int num)
+{
+	_theSockets.at( num )->sendConnectionName( name );
+}
 
 void AttalServer::endGame()
 {
@@ -358,6 +362,11 @@ void AttalServer::sendPlayerResource( char ressource, int nb )
 	_currentSocket->sendPlayerResource( ressource, nb );
 }
 
+void AttalServer::sendPlayerPrice( char ressource, int price )
+{
+	_currentSocket->sendPlayerPrice( ressource, price );
+}
+
 void AttalServer::sendPlayerResources( GenericPlayer * player )
 {
 	AttalPlayerSocket * current = findSocket( player );
@@ -386,14 +395,18 @@ void AttalServer::sendCell( GenericCell * cell )
 	_currentSocket->sendCell( cell );
 }
 
-void AttalServer::sendAskNone( const QString & msg )
+void AttalServer::sendAskNone( const QString & msg, bool toAll )
 {
  	QListIterator<AttalPlayerSocket> ite( _theSockets );
 
-	if( !ite.isEmpty() ) {
-		for( ite.atFirst(); ite.current(); ++ite ) {
-			ite.current()->sendAskNone( msg );
+	if( toAll ) {
+		if( !ite.isEmpty() ) {
+			for( ite.atFirst(); ite.current(); ++ite ) {
+				ite.current()->sendAskNone( msg );
+			}
 		}
+	} else {
+		_currentSocket->sendAskNone( msg );
 	}
 }
 
@@ -402,9 +415,23 @@ void AttalServer::sendAskChest()
 	_currentSocket->sendAskChest();
 }
 
+void AttalServer::sendAskCreatureJoin( GenericMapCreature * creature )
+{
+	_currentSocket->sendAskCreatureJoin( creature );
+}
+	
+void AttalServer::sendAskCreatureMercenary( GenericMapCreature * creature )
+{
+	_currentSocket->sendAskCreatureMercenary( creature );
+}
+
+void AttalServer::sendAskCreatureFlee( GenericMapCreature * creature )
+{
+	_currentSocket->sendAskCreatureFlee( creature );
+}
+
 void AttalServer::updateUnits( GenericLord * lord )
 {
-
 	if( lord ) {
 		if( _currentSocket->getPlayer() == lord->getOwner() ) {
 			_currentSocket->sendLordUnits( lord );
@@ -415,6 +442,18 @@ void AttalServer::updateUnits( GenericLord * lord )
 	}
 }
 
+void AttalServer::updateUnit( GenericLord * lord , int num)
+{
+	if( lord ) {
+		if( _currentSocket->getPlayer() == lord->getOwner() ) {
+			_currentSocket->sendLordUnit( lord , num );
+		} else {
+			/// XXX: would be better to send category of units and not real values
+			_currentSocket->sendLordUnit( lord , num);
+		}
+	}
+}
+
 void AttalServer::newLord( GenericLord * lord )
 {
 	if( lord ) {
@@ -556,9 +595,12 @@ void AttalServer::newBase( GenericBase * base )
 	for( uint i = 0; i < base->getBuildingCount(); i++ ) {
 		_currentSocket->sendBaseBuilding( base, base->getBuilding( i ), true );
 	}
+	for(int i = 0; i < MAX_UNIT; i++ ) {
+		_currentSocket->sendBaseUnit( base, base->getUnit(i) );
+	}
+	_currentSocket->sendBaseName( base );
 }
 
-
 void AttalServer::updateBaseBuilding( GenericBase * base, GenericInsideBuilding * building , GenericPlayer * player )
 {
 	AttalPlayerSocket * socket = findSocket( player );
@@ -607,22 +649,27 @@ void AttalServer::sendExchangeUnit( GenericLord * lord1, uchar unit1, GenericLor
 
 	if( !ite.isEmpty() ) {
 		for( ite.atFirst(); ite.current(); ++ite ) {
-			if( ite.current() != _currentSocket ) {
+			//if( ite.current() != _currentSocket ) {
 				ite.current()->sendExchangeUnit( lord1, unit1, lord2, unit2 );
-			}
+			//}
 		}
 	}
 }
 
+void AttalServer::sendExchangeArtefact( GenericLord * /* lord1 */, int /* item */, GenericLord * /* lord2 */ )
+{
+	/// XXX: _currentSocket->sendExchangeArtefact( lord1, item, lord2 ); unused ??
+}
+
 void AttalServer::sendExchangeBaseUnitCl( GenericBase * base, uchar unit1, GenericLord * lord, uchar unit2 )
 {
 	QListIterator<AttalPlayerSocket> ite( _theSockets );
 
 	if( !ite.isEmpty() ) {
 		for( ite.atFirst(); ite.current(); ++ite ) {
-			if( ite.current() != _currentSocket ) {
+			//if( ite.current() != _currentSocket ) {
 				ite.current()->sendExchangeBaseUnitCl( base, unit1, lord, unit2 );
-			}
+			//}
 		}
 	}
 }
@@ -656,13 +703,11 @@ void AttalServer::newBuilding( GenericBuilding * build )
 
 void AttalServer::ownBuilding( GenericBuilding * build, GenericPlayer * player )
 {
-	QListIterator<AttalPlayerSocket> ite( _theSockets );
+ 	AttalPlayerSocket * socket = findSocket( player );
 
-	if( !ite.isEmpty() ) {
-		for( ite.atFirst(); ite.current(); ++ite ) {
-			ite.current()->sendBuildingOwner( build, player );
-		}
-	}
+	/// XXX: owner could be computed in AttalSocket
+	GenericPlayer * owner = build->getOwner();
+ 	socket->sendBuildingOwner( build, owner );
 }
 
 void AttalServer::ownArtefact( GenericLordArtefact * artefact, GenericPlayer * player )
@@ -676,6 +721,19 @@ void AttalServer::newCreature( GenericMapCreature * creature )
 	_currentSocket->sendNewCreature( creature );
 }
 
+void AttalServer::updateCreature( GenericMapCreature * creature )
+{
+	QListIterator<AttalPlayerSocket> ite( _theSockets );
+
+	if( !ite.isEmpty() ) {
+		for( ite.atFirst(); ite.current(); ++ite ) {
+			if( ite.current()->canSee( creature->getCell() ) ) {
+				ite.current()->sendUpdateCreature( creature );
+			}
+		}
+	}
+}
+
 void AttalServer::delCreature( GenericCell * cell )
 {
 	QListIterator<AttalPlayerSocket> ite( _theSockets );
@@ -698,8 +756,9 @@ void AttalServer::newEvent( GenericEvent * event )
                 }
         }
 */
-	if( _currentSocket->canSee( event->getCell() ) ) 
+	if( _currentSocket->canSee( event->getCell() ) ) {
 		_currentSocket->sendNewEvent( event );
+	}
 }
 
 void AttalServer::delEvent( GenericEvent * event )
