@@ -5,7 +5,7 @@
 ** attalServer.h
 ** the server : manage connections
 **
-** Version : $Id: attalServer.h,v 1.13 2004/10/08 23:02:58 audoux Exp $
+** Version : $Id: attalServer.h,v 1.19 2004/12/05 15:08:48 lusum Exp $
 **
 ** Author(s) : Pascal Audoux
 **
@@ -130,6 +130,9 @@ public:
 
 	/** Send ressources to the player */
 	void sendPlayerResource( char ressource, int nb );
+	
+	/** Send prices to the player */
+	void sendPlayerPrice( char ressource, int price );
 
 	/** Send ressources to the player */
 	void sendPlayerResources( GenericPlayer * player );
@@ -150,7 +153,7 @@ public:
 	void sendCell( GenericCell * cell );
 
 	/** Send a game message to the player */
-	void sendAskNone( const QString & msg );
+	void sendAskNone( const QString & msg, bool toAll = false );
 
 	void sendAskChest();
 
@@ -158,6 +161,12 @@ public:
 	void sendAskLevel( GenericPlayer * dest, char lord, char level, char primSkill, char skill1, char skill2 ) {
 		findSocket( dest )->sendAskLevel( lord, level, primSkill, skill1, skill2 );
 	}
+	
+	void sendAskCreatureJoin( GenericMapCreature * creature );
+	
+	void sendAskCreatureMercenary( GenericMapCreature * creature );
+		
+	void sendAskCreatureFlee( GenericMapCreature * creature );
 
 	/** Send new lord */
 	void newLord( GenericLord * lord );
@@ -168,6 +177,8 @@ public:
 
 	void updateUnits( GenericLord * lord );
 
+	void updateUnit( GenericLord * lord , int num);
+
 	/* update  base units (flag==0)
 	 * lord units (flag==1)
 	 * or both (flag==2)
@@ -197,6 +208,8 @@ public:
 	void sendLordExchange( GenericLord * lord1, GenericLord * lord2 );
 
 	void sendExchangeUnit( GenericLord * lord1, uchar unit1, GenericLord * lord2, uchar unit2 );
+	
+	void sendExchangeArtefact( GenericLord * lord1, int item, GenericLord * lord2 );
 
 	void sendExchangeBaseUnitCl( GenericBase * base, uchar unit1, GenericLord * lord, uchar unit2 );
 
@@ -214,6 +227,8 @@ public:
 
 	void sendLordRemove( GenericLord * lord );
 
+	void sendConnectionName(const QString & name, int num);
+
 	void sendCreatureRemove( GenericCell * cell );
 
 	void setGarrison( GenericLord * lord, bool state );
@@ -226,6 +241,8 @@ public:
 	void ownArtefact( GenericLordArtefact * artefact, GenericPlayer * player );
 
 	void newCreature( GenericMapCreature * creature );
+	
+	void updateCreature( GenericMapCreature * creature );
 
 	void delCreature( GenericCell * cell );
 
