@@ -5,9 +5,9 @@
 ** fightAnalyst.cpp
 ** analyst for the fight phase
 **
-** Version : $Id: fightAnalyst.cpp,v 1.12 2004/08/01 11:24:40 audoux Exp $
+** Version : $Id: fightAnalyst.cpp,v 1.14 2004/12/27 23:04:13 audoux Exp $
 **
-** Author(s) : Pascal Audoux
+** Author(s) : Pascal Audoux - Sardi Carlo
 **
 ** Date : 05/01/2002
 **
@@ -319,12 +319,20 @@ void FightAnalyst::handleMove()
 		if ( !_unitsAtt[ num ]->getFightMap () )
 		{
 			_unitsAtt[ num ]->setFightMap ( _map );
+		}else {
+			if(_map !=_unitsAtt[ num ]->getFightMap ()){
+				logDD("error, attack num %d", num);
+			}
 		}
 		_unitsAtt[ num ]->goTo( _map->at( row, col ) );
 	} else {
 		if ( !_unitsDef[ num ]->getFightMap () )
 		{
 			_unitsDef[ num ]->setFightMap ( _map );
+		}else {
+			if(_map !=_unitsDef[ num ]->getFightMap ()){
+				logDD("error, defense");
+			}
 		}
 		_unitsDef[ num ]->goTo( _map->at( row, col ) );
 	}
@@ -348,17 +356,15 @@ void FightAnalyst::handleOpponent()
 
 void FightAnalyst::handleDamage()
 {
-	uchar claAtt = _socket->readChar ();
-	uchar numAtt = _socket->readChar();
+	/* XXX: unused ?? uchar claAtt = */ _socket->readChar();
+	/* XXX: unused ?? uchar numAtt = */ _socket->readChar();
 
-	CLASS_ATTACK_TYPE type = (CLASS_ATTACK_TYPE) _socket->readChar ();
+	/* XXX: unused ?? CLASS_ATTACK_TYPE type = (CLASS_ATTACK_TYPE) */ _socket->readChar ();
 
 	uchar claDef = _socket->readChar();
 	uchar numDef = _socket->readChar();
 	int damages = _socket->readInt();
 
-
-
 	if( (CLASS_FIGHTER)claDef == FIGHTER_ATTACK ) {
 		_unitsAtt[ numDef ]->hit( damages );
 	} else {
@@ -541,6 +547,7 @@ GenericFightUnit * FightAnalyst::getUnit( int num, CLASS_FIGHTER fighter )
 
 void FightAnalyst::updateUnits( void )
 {
+	//logDD( "analyst: FIGHT END" );
 	GenericLord *oldLord;
 	GenericFightUnit * oldUnit, * newUnit;
 	uint  i;
@@ -559,6 +566,7 @@ void FightAnalyst::updateUnits( void )
 				oldUnit->setNumber( newUnit->getNumber()  );
 				oldUnit->setMove( newUnit->getMove() );
 				oldUnit->setHealth( newUnit->getHealth() );
+				oldUnit->setFightMap( 0 );
 			} else if (oldUnit) {
 				oldLord->setUnit(i,0);
 			}
@@ -579,6 +587,7 @@ void FightAnalyst::updateUnits( void )
 				oldUnit->setNumber( newUnit->getNumber()  );
 				oldUnit->setMove( newUnit->getMove() );
 				oldUnit->setHealth( newUnit->getHealth() );
+				oldUnit->setFightMap( 0 );
 			} else if (oldUnit) {
 				oldLord->setUnit(i,0);
 			}
