@@ -5,7 +5,7 @@
 ** gameData.h
 ** Manage data of a whole game
 **
-** Version : $Id: gameData.h,v 1.6 2004/10/08 23:02:04 audoux Exp $
+** Version : $Id: gameData.h,v 1.7 2004/11/07 20:30:15 audoux Exp $
 **
 ** Author(s) : Pascal Audoux
 **
@@ -81,7 +81,7 @@ public:
 	QString getScenarioDescription() { return _scenarioDescription; }
 	
 	/** Set the theme used by the scenario */
-	void setScenarioTheme( QString theme ) { _scenarioTheme = theme; }
+	void setScenarioTheme( const QString & theme ) { _scenarioTheme = theme; }
 
 	/** Return the theme used by the scenario */
 	QString getScenarioTheme() { return _scenarioTheme; }
