@@ -5,9 +5,9 @@
 ** parser.cpp
 ** Parser for scenarii and saved games.
 **
-** Version : $Id: parser.cpp,v 1.20 2004/07/14 19:10:01 lusum Exp $
+** Version : $Id: parser.cpp,v 1.27 2004/12/13 15:18:12 lusum Exp $
 **
-** Author(s) : Pascal Audoux
+** Author(s) : Pascal Audoux - Sardi Carlo
 **
 ** Date : 04/02/2001
 **
@@ -89,20 +89,14 @@ bool ScenarioParser::startElement( const QString& namespaceURI, const QString& l
 		_state = StateHeight;
 	} else if( qName == "base" && _state == StateDocument ) {
 		_state = StateBase;
+		_baseState = BaseStateInit;
 		_row = 0;
 		_col = 0;
 		_baseType = 0;
+		_baseName = "";
 		_base = _data->getNewBase();
-	} else if( qName == "type" && _state == StateBase ) {
-		_state = StateBaseType;
-	} else if( qName == "col" && _state == StateBase ) {
-		_state = StateBaseCol;
-	} else if( qName == "row" && _state == StateBase ) {
-		_state = StateBaseRow;		
-	} else if( qName == "building" && _state == StateBase ) {
-		_state = StateBaseBuilding;
-	} else if( qName == "forbidden" && _state == StateBase ) {
-		_state = StateBaseForbidden;
+	} else if( _state == StateBase ) {
+		ret = startElementBase( namespaceURI, localName, qName, atts );
 	} else if( qName == "building" && _state == StateDocument ) {
 		_state = StateBuilding;
 		_building = _data->getNewBuilding();
@@ -115,7 +109,7 @@ bool ScenarioParser::startElement( const QString& namespaceURI, const QString& l
 		_state = StateBuildingRow;
 	} else if( qName == "creature" && _state == StateDocument ) {
 		_state = StateCreature;
-		_creature = _data->getNewMapCreature();//new GenericMapCreature();
+		_creature = _data->getNewMapCreature();
 		_row = 0;
 		_col = 0;
 		_race = 0;
@@ -137,6 +131,12 @@ bool ScenarioParser::startElement( const QString& namespaceURI, const QString& l
 		_number = atts.value( "num" ).toInt();
 	} else if( qName == "behaviour" && _state == StateCreature ) {
 		_state = StateCreatureBehaviour;
+	} else if( qName == "growth" && _state == StateCreature ) {
+		_state = StateCreatureGrowth;
+		_creature->setGrowthMode( (GenericMapCreature::GrowthMode)atts.value( "type" ).toInt() );
+		_nbParam = 0;
+	} else if( qName == "param" && _state == StateCreatureGrowth ) {
+		_state = StateCreatureGrowthParam;
 	} else if( qName == "flee" && _state == StateCreature ) {
 		_state = StateCreatureFlee;
 	} else if( qName == "lookingRight" && _state == StateCreature ) {
@@ -155,6 +155,9 @@ bool ScenarioParser::startElement( const QString& namespaceURI, const QString& l
 	} else if( qName == "player" && _state == StateDocument ) {
 		_state = StatePlayer;
 		_data->addPlayer();
+		if(_data->getPlayer( _player )){
+				_data->getPlayer( _player )->setNum( _player );
+		}
 	} else if( qName == "name" && _state == StatePlayer ) {
 		_state = StatePlayerName;
 	} else if( qName == "ruledbyai" && _state == StatePlayer ) {
@@ -232,32 +235,8 @@ bool ScenarioParser::endElement( const QString& namespaceURI, const QString& loc
 		_state = StateMap;
 		break;
 	case StateBase:
-		_state = StateDocument;
-		_base->setRace( _baseType );
-		_base->setPosition( _data->getCell( _row, _col ) );
-		_base->setId( _data->getBaseNumber()-1 );
-		break;
-	case StateBaseType:
-		_state = StateBase;
-		break;
-	case StateBaseCol:
-		_state = StateBase;
-		break;
-	case StateBaseRow:
-		_state = StateBase;
-		break;
-	case StateBaseBuilding:
-		{
-			GenericInsideBuilding * building = new GenericInsideBuilding();
-			building->setRace( _baseType );
-			building->setLevel( _id );
-			_base->addBuilding( building );
-			_state = StateBase;
-		}
-		break;
-	case StateBaseForbidden:
-		_state = StateBase;
-		break;
+		ret = endElementBase( namespaceURI, localName, qName );
+	break;
 	case StateBuilding:
 		_building->setPosition( _data->getCell( _row, _col ) );
 		_state = StateDocument;
@@ -295,6 +274,12 @@ bool ScenarioParser::endElement( const QString& namespaceURI, const QString& loc
 	case StateCreatureBehaviour:
 		_state = StateCreature;
 		break;
+	case StateCreatureGrowth:
+		_state = StateCreature;
+		break;
+	case StateCreatureGrowthParam:
+		_state = StateCreatureGrowth;
+		break;
 	case StateCreatureFlee:
 		_state = StateCreature;
 		break;
@@ -366,6 +351,7 @@ bool ScenarioParser::characters( const QString& ch )
 		_height = ch_simplified.toInt();
 		break;
 	case StateBase:
+		ret = charactersBase( ch_simplified );
 		break;
 	case StateBuilding:
 		break;
@@ -393,27 +379,19 @@ bool ScenarioParser::characters( const QString& ch )
 	case StateCreatureBehaviour:
 		_behaviour = ch_simplified.toInt();
 		break;
+	case StateCreatureGrowth:
+		_creature->setGrowthMode( (GenericMapCreature::GrowthMode)ch_simplified.toInt() );
+		break;
+	case StateCreatureGrowthParam:
+		_creature->setGrowthParam( _nbParam, ch_simplified.toInt() );
+		_nbParam++;
+		break;
 	case StateCreatureFlee:
 		_flee = (bool) ch_simplified.toInt();
 		break;
 	case StateCreatureLooking:
 		_looking = (bool) ch_simplified.toInt();
 		break;
-	case StateBaseType:
-		_baseType = ch_simplified.toInt();
-		break;
-	case StateBaseCol:
-		_col = ch_simplified.toInt();
-		break;
-	case StateBaseRow:
-		_row = ch_simplified.toInt();
-		break;
-	case StateBaseBuilding:
-		_id = ch_simplified.toInt();
-		break;
-	case StateBaseForbidden:
-		_base->addForbiddenBuilding( ch_simplified.toInt() );
-		break;
 	case StatePlayerName:
 		break;
 	case StatePlayerRuled:
@@ -596,6 +574,153 @@ bool ScenarioParser::charactersLord( const QString& ch )
 	return ret;
 }
 
+// Parsing of Bases
+
+bool ScenarioParser::startElementBase( const QString &, const QString &, const QString & qName, const QXmlAttributes & atts )
+{
+	if( qName == "type" && _baseState == BaseStateInit ) {
+		_baseState = BaseStateType;
+	} else if( qName == "name" && _baseState == BaseStateInit ) {
+		_baseState = BaseStateName;
+	} else if( qName == "col" && _baseState == BaseStateInit ) {
+		_baseState = BaseStateCol;
+	} else if( qName == "row" && _baseState == BaseStateInit ) {
+		_baseState = BaseStateRow;		
+	} else if( qName == "building" && _baseState == BaseStateInit ) {
+		_baseState = BaseStateBuilding;
+	} else if( qName == "forbidden" && _baseState == BaseStateInit ) {
+		_baseState = BaseStateForbidden;
+	} else if( qName == "unit" && _baseState == BaseStateInit ) {
+		_baseState = BaseStateUnit;
+		_pos = atts.value( "pos" ).toInt();
+		_unit = new GenericFightUnit();
+		_race = 0;
+		_level = 0;
+	} else if( qName == "race" && _baseState == BaseStateUnit ) {
+		_baseState = BaseStateUnitRace;
+	} else if( qName == "level" && _baseState == BaseStateUnit ) {
+		_baseState = BaseStateUnitLevel;
+	} else if( qName == "number" && _baseState == BaseStateUnit ) {
+		_baseState = BaseStateUnitNumber;
+	} else if( qName == "move" && _baseState == BaseStateUnit ) {
+		_baseState = BaseStateUnitMove;
+	} else if( qName == "health" && _baseState == BaseStateUnit ) {
+		_baseState = BaseStateUnitHealth;
+	} else {
+		logEE( "Not found %s", qName.latin1() );
+		return false;
+	}
+	return true;
+}
+
+bool ScenarioParser::endElementBase( const QString &, const QString &, const QString & )
+{
+	switch ( _baseState ) {	
+		case BaseStateInit:
+		_state = StateDocument;
+		_base->setRace( _baseType );
+		_base->setName( _baseName );
+		_base->setPosition( _data->getCell( _row, _col ) );
+		_base->setId( _data->getBaseNumber()-1 );
+		break;
+		case BaseStateType:
+		_baseState = BaseStateInit;
+		break;
+	case BaseStateName:
+		_baseState = BaseStateInit;
+		break;
+	case BaseStateCol:
+		_baseState = BaseStateInit;
+		break;
+	case BaseStateRow:
+		_baseState = BaseStateInit;
+		break;
+	case BaseStateBuilding:
+		{
+			GenericInsideBuilding * building = new GenericInsideBuilding();
+			building->setRace( _baseType );
+			building->setLevel( _id );
+			_base->addBuilding( building );
+			_baseState = BaseStateInit;
+		}
+		break;
+	case BaseStateForbidden:
+		_baseState = BaseStateInit;
+		break;
+	case BaseStateUnit:
+		_unit->setCreature( _race, _level );
+		_base->setUnit( _pos, _unit );
+		_baseState = BaseStateInit;
+		break;
+	case BaseStateUnitRace:
+		//_unit->setCreature( _type );
+		_baseState = BaseStateUnit;
+		break;
+	case BaseStateUnitLevel:
+		_baseState = BaseStateUnit;
+		break;
+	case BaseStateUnitNumber:
+		_unit->setNumber( _number );
+		_baseState = BaseStateUnit;
+		break;
+	case BaseStateUnitMove:
+		_unit->setMove( _move );
+		_baseState = BaseStateUnit;
+		break;
+	case BaseStateUnitHealth:
+		_unit->setHealth( _health );
+		_baseState = BaseStateUnit;
+		break;
+	default:
+		break;
+	}
+	return true;
+}
+
+bool ScenarioParser::charactersBase( const QString& ch )
+{
+	bool ret = true;
+
+	switch( _baseState ) {
+	case BaseStateType:
+		_baseType = ch.toInt();
+		break;
+	case BaseStateName:
+		_baseName = ch;
+		break;
+	case BaseStateCol:
+		_col = ch.toInt();
+		break;
+	case BaseStateRow:
+		_row = ch.toInt();
+		break;
+	case BaseStateBuilding:
+		_id = ch.toInt();
+		break;
+	case BaseStateForbidden:
+		_base->addForbiddenBuilding( ch.toInt() );
+		break;
+	case BaseStateUnitRace:
+		_race = ch.toInt();
+		break;
+	case BaseStateUnitLevel:
+		_level = ch.toInt();
+		break;
+	case BaseStateUnitNumber:
+		_number = ch.toInt();
+		break;
+	case BaseStateUnitMove:
+		_move = ch.toInt();
+		break;
+	case BaseStateUnitHealth:
+		_health = ch.toInt();
+		break;
+	default:
+		ret = false;
+	}
+	return ret;
+}
+
 // Parsing of Events
 
 bool ScenarioParser::startElementEvent( const QString &, const QString &, const QString& qName, const QXmlAttributes& atts )
@@ -747,6 +872,8 @@ void ScenarioParser::manageCondition( const QString & type )
 		_currentCondition = new QuestConditionLord();
 	} else if( type == "date" ) {
 		_currentCondition = new QuestConditionDate();
+	} else if( type == "player" ) {
+		_currentCondition = new QuestConditionPlayer();
 	}
 
 	if( _conditionStack.isEmpty() ) {
@@ -890,13 +1017,36 @@ void ScenarioParser::manageConditionParam( const QString & param )
 		}
 		break;
 	case QuestCondition::PLAYER:
+		if( _params.count() == 0 ) {
+			_params.append( param.toUInt() );
+		} else {
+			switch( (QuestConditionPlayer::ConditionCategory) _params[ 0 ] ) {
+			case QuestConditionPlayer::NB_LORD:
+				if( _params.count() == 1 ) {
+					_params.append( param.toUInt() );
+				} else {
+					( ( QuestConditionPlayer * ) _currentCondition )->setNbBaseCondition( (QuestCondition::CheckType)_params[ 1 ], param.toUInt() );
+				}
+				break;
+			case QuestConditionPlayer::NB_BASE:
+				if( _params.count() == 1 ) {
+					_params.append( param.toUInt() );
+				} else {
+					( ( QuestConditionPlayer * ) _currentCondition )->setNbBaseCondition( (QuestCondition::CheckType)_params[ 1 ], param.toUInt() );
+				}
+				break;
+			case QuestConditionPlayer::BASENAME:
+				( ( QuestConditionPlayer * ) _currentCondition )->setBasenameCondition( param );
+				break;
+			}
+		}
 		break;
 	}
 }
 
 bool ScenarioParser::fatalError( const QXmlParseException& exception )
 {
-     logEE( "state %d, lordState %d, questState %d, eventState %d", _state, _lordState, _questState, _eventState );
+     logEE( "state %d, lordState %d, baseState %d, questState %d, eventState %d", _state, _lordState, _baseState, _questState, _eventState );
 
     _errorProt += QString( "fatal parsing error: %1 in line %2, column %3\n" )
 	.arg( exception.message() )
