@@ -5,9 +5,9 @@
 ** parser.h
 ** Parser for scenarii and saved games.
 **
-** Version : $Id: parser.h,v 1.12 2004/07/14 19:10:01 lusum Exp $
+** Version : $Id: parser.h,v 1.15 2004/12/04 14:26:57 lusum Exp $
 **
-** Author(s) : Pascal Audoux
+** Author(s) : Pascal Audoux - Sardi Carlo
 **
 ** Date : 04/02/2001
 **
@@ -71,6 +71,8 @@ public:
 	bool startElement( const QString& namespaceURI, const QString& localName, const QString& qName, const QXmlAttributes& atts );
 	
 	bool startElementLord( const QString& namespaceURI, const QString& localName, const QString& qName, const QXmlAttributes& atts );
+	
+	bool startElementBase( const QString& namespaceURI, const QString& localName, const QString& qName, const QXmlAttributes& atts );
 
 	bool startElementQuest( const QString& namespaceURI, const QString& localName, const QString& qName, const QXmlAttributes& atts );
 
@@ -80,6 +82,8 @@ public:
 	bool endElement( const QString& namespaceURI, const QString& localName, const QString& qName );
 
 	bool endElementLord( const QString& namespaceURI, const QString& localName, const QString& qName );
+	
+	bool endElementBase( const QString& namespaceURI, const QString& localName, const QString& qName );
 
 	bool endElementQuest( const QString& namespaceURI, const QString& localName, const QString& qName );
 
@@ -89,6 +93,8 @@ public:
 	bool characters( const QString& ch );
 	
 	bool charactersLord( const QString& ch );
+	
+	bool charactersBase( const QString& ch );
 
 	bool charactersQuest( const QString& ch );
 
@@ -127,9 +133,10 @@ private:
 	bool _flee, _looking;
 	int _race, _level, _res;
 	int _machine;
-	QString _type;
+	QString _type, _baseName;
 	int _player;
 	bool _posOk;
+	uint _nbParam;
 
 	enum State {
 		StateInit,
@@ -141,11 +148,6 @@ private:
 		StateWidth,
 		StateHeight,
 		StateBase,
-		StateBaseType,
-		StateBaseCol,
-		StateBaseRow,
-		StateBaseBuilding,
-		StateBaseForbidden,
 		StateCreature,
 		StateCreatureCol,
 		StateCreatureRow,
@@ -153,6 +155,8 @@ private:
 		StateCreatureLevel,
 		StateCreatureStack,
 		StateCreatureBehaviour,
+		StateCreatureGrowth,
+		StateCreatureGrowthParam,
 		StateCreatureFlee,
 		StateCreatureLooking,
 		StateBuilding,
@@ -186,6 +190,22 @@ private:
 		LordStateMachine
 	};
 
+	enum BaseState {
+		BaseStateInit,
+		BaseStateType,
+		BaseStateName,
+		BaseStateBuilding,
+		BaseStateForbidden,
+		BaseStateCol,
+		BaseStateRow,
+		BaseStateUnit,
+		BaseStateUnitRace,
+		BaseStateUnitLevel,
+		BaseStateUnitNumber,
+		BaseStateUnitMove,
+		BaseStateUnitHealth,
+	};
+
 	enum QuestState {
 		QuestInit,
 		QuestQuest,
@@ -218,6 +238,7 @@ private:
 
 	State _state;
 	LordState _lordState;
+	BaseState _baseState;
 	QuestState _questState, _oldQuestState;
 	EventState _eventState;
 
