@@ -5,7 +5,7 @@
 ** questManager.h
 ** Manages the quests of a scenario
 **
-** Version : $Id: questManager.h,v 1.2 2004/02/08 00:08:15 audoux Exp $
+** Version : $Id: questManager.h,v 1.4 2004/06/22 20:19:36 audoux Exp $
 **
 ** Author(s) : Pascal Audoux
 **
@@ -31,26 +31,44 @@
 
 // generic include files
 // include files for QT
-#include <qlist.h>
+#include <qptrlist.h>
 // application specific include files
 #include "libCommon/quest.h"
 
 
+class QTextStream;
+
 /*              ------------------------------
  *                         QuestManager
  *              ------------------------------ */
 
 
-
-/** comment for the class */
-class QuestManager : public QList<Quest>
+class QuestManager
 {
-
 public:
 	/** Constructor */
 	QuestManager();
 
+	/** Destructor */
+	virtual ~QuestManager();
+
 	void clear();
+
+	void save( QTextStream * ts, uint indent );
+
+	Quest * getMainQuest();
+
+	void setMainQuest( Quest * quest ) { _mainQuest = quest; }
+
+	uint getSecondaryQuestNumber();
+
+	Quest * getSecondaryQuest( uint num );
+
+	void appendSecondaryQuest( Quest * quest );
+
+protected:
+	Quest * _mainQuest;
+	QPtrList<Quest> _quests;
 };
 
 #endif // QUESTMANAGER_H
