@@ -5,7 +5,7 @@
 ** itemSelection.cpp
 ** Allow selection of specific item panels
 **
-** Version : $Id: itemSelection.cpp,v 1.20 2004/04/28 16:57:42 audoux Exp $
+** Version : $Id: itemSelection.cpp,v 1.24 2004/12/19 15:10:11 lusum Exp $
 **
 ** Author(s) : Pascal Audoux
 **
@@ -28,9 +28,15 @@
 
 // generic include files
 // include files for QT
+#include <qcombobox.h>
+#include <qlayout.h>
 #include <qpushbutton.h>
 #include <qsignalmapper.h>
+#include <qwidgetstack.h>
 // application specific include files
+#include "libCommon/dataTheme.h"
+#include "libCommon/genericDecoration.h"
+
 #include "libClient/bonus.h"
 #include "libClient/building.h"
 #include "libClient/cell.h"
@@ -43,8 +49,6 @@
 #include "libClient/map.h"
 #include "libClient/mapCreature.h"
 
-#include "libCommon/dataTheme.h"
-
 #include "libServer/gameData.h"
 
 #include "scenarioEditor/screen.h"
@@ -115,7 +119,7 @@ void ItemSelection::addNewLine()
 
 int ItemSelection::button()
 {
-// XXX: replace selectedId with Id (selected)
+	/// XXX: replace selectedId with Id (selected)
 	return _bg->id ( _bg->selected() );
 }
 
@@ -147,22 +151,83 @@ void TransitionSelection::handleLeftClick( Cell * cell )
 }
 
 
+//
+// ----- DecorationGroupSelection -----
+//
+
+DecorationGroupSelection::DecorationGroupSelection( QWidget * parent, const char * name )
+	:ItemSelection( parent, name )
+{
+	DecorationSelection * item;
+	uint nbGroups = DataTheme.decorations.count();
+	
+	_groups = new QComboBox( this );	
+	_stack = new QWidgetStack( this );
+		
+	for( uint i = 1; i < nbGroups; i++ ) {
+		_groups->insertItem( DataTheme.decorations.at( i )->getName() );
+		item = new DecorationSelection( i, this );
+		_stack->addWidget( item, i-1 );
+	}
+	FIXEDSIZE( _groups );
+	
+	QVBoxLayout * layout = new QVBoxLayout( this );
+	layout->setSpacing( 5 );
+	layout->setMargin( 5 );
+	layout->addWidget( _groups );
+	layout->addWidget( _stack, 1 );
+	layout->activate();
+	
+	connect( _groups, SIGNAL( activated( int ) ), SLOT( slot_selectGroup( int ) ) );
+	
+	slot_selectGroup( 0 );
+}
+
+void DecorationGroupSelection::handleLeftClick( Cell * cell )
+{
+	( (DecorationSelection*)_stack->visibleWidget() )->handleLeftClick( cell );
+}
+
+void DecorationGroupSelection::slot_selectGroup( int group )
+{
+	_stack->raiseWidget( group );
+}
+
 //
 // ----- DecorationSelection -----
 //
 
-DecorationSelection::DecorationSelection( QWidget * parent, const char * name )
+DecorationSelection::DecorationSelection( uint group, QWidget * parent, const char * name )
 	:ItemSelection( parent, name )
 {
-	for( uint i = 0; i < ImageTheme.decoration->count(); i++ ) {
-		addButton( ImageTheme.decoration->image( i ), i );
+	DecorationGroup * deco = DataTheme.decorations.at( group );
+	uint nbItems = deco->count();
+	
+	_group = group;
+	
+	for( uint i = 0; i < nbItems; i++ ) {
+		addButton( ImageTheme.decoration[ group-1 ]->image( i ), i );
+	}
+	
+	_isRoad = false;
+	if( deco->getEffectNumber() > 0 ) {
+		DecorationGroup::EffectType effect = deco->getEffectType( 0 );
+		if( ( effect  == DecorationGroup::DECREASE_MOVECOST ) || ( effect == DecorationGroup::INCREASE_MOVECOST ) ) {
+			_isRoad = true;
+			addNewLine();
+			addButton( tr( "Auto-path" ), nbItems );
+		}
 	}
 }
 
 void DecorationSelection::handleLeftClick( Cell * cell )
 {
 	if( button() != -1 ) {
-		cell->setDecoration( button() + 1 );
+		if( _isRoad && ( button() == ( _bg->count() - 1 ) ) ) {
+			computeAndChangeRoadType( (GenericMap *)theMap, (GenericCell *)cell, _group ); 
+		} else {
+			cell->setDecoration( _group, button() );
+		}
 	}
 }
 
@@ -182,7 +247,7 @@ BuildingSelection::BuildingSelection( QWidget * parent, const char * name )
 void BuildingSelection::handleLeftClick( Cell * cell )
 {
 	if( button() != -1 ) {
-		if( ( ! cell->getBuilding() )  && ( ! cell->getBase() ) ) {
+		if( ( ! cell->getBuilding() )  && ( ! cell->getBase() ) && cell->getCoeff() >= 0  && cell->isStoppable() && cell->isFree()) {
 			Building * building = (Building *)_data->getNewBuilding();//new Building( theMap );
 			building->setType( button() );
 			building->setPosition( (GenericCell *)cell );
@@ -206,7 +271,7 @@ BaseSelection::BaseSelection( QWidget * parent, const char * name )
 void BaseSelection::handleLeftClick( Cell * cell )
 {
 	if( button() != -1 ) {
-		if( ( ! cell->getBuilding() ) && ( ! cell->getBase() ) ) {
+		if( ( ! cell->getBuilding() ) && ( ! cell->getBase() ) && cell->getCoeff() >= 0  && cell->isStoppable() && cell->isFree()) {
 			Base * base = (Base *)_data->getNewBase();
 			base->setRace( button() );
 			base->setPosition( (GenericCell *)cell );
@@ -227,7 +292,7 @@ LordSelection::LordSelection( QWidget * parent, const char * name )
 void LordSelection::handleLeftClick( Cell * cell )
 {
 	if( button() != -1 ) {
-		if( ! cell->getLord() ) {
+		if( ! cell->getLord() && cell->getCoeff() >= 0  && cell->isStoppable() && cell->isFree()) {
 			_num++;
 			Lord * lord = (Lord*)_data->getLord( _num );
 			lord->setVisible( true );
@@ -366,6 +431,7 @@ ToolSelection::ToolSelection( Screen * screen, QWidget * parent, const char * na
 	_screen = screen;
 	addButton("Eraser",0);
 	addButton("Auto-transition",1);
+	addButton("Auto-roads",2);
 }
 
 void ToolSelection::handleLeftClick( Cell * cell )
@@ -375,8 +441,12 @@ void ToolSelection::handleLeftClick( Cell * cell )
 		_screen->handleDelete();
 		break;
 	case 1:
-		cell->setTransition( computeTransition( (GenericMap*)theMap, (GenericCell *)cell ) );
-		cell->setTransitionCellType( computeTransitionCellType( (GenericMap*)theMap, (GenericCell *)cell 		) );
+		cell->setTransition( computeTransition( (GenericMap *)theMap, (GenericCell *)cell ) );
+		cell->setTransitionCellType( computeTransitionCellType( (GenericMap *)theMap, (GenericCell *)cell ) );
+		break;
+	case 2: 
+		computeAndChangeRoadType( (GenericMap *)theMap, (GenericCell *)cell, 1 ); /// XXX: to change '1' -> road type
 		break;
 	}
 }
+
