@@ -5,9 +5,9 @@
 ** propertiesItem.cpp
 ** Defines properties box for bases on map
 **
-** Version : $Id: propertiesBase.cpp,v 1.6 2004/07/31 19:29:47 audoux Exp $
+** Version : $Id: propertiesBase.cpp,v 1.8 2004/12/08 11:17:30 lusum Exp $
 **
-** Author(s) : Pascal Audoux
+** Author(s) : Pascal Audoux - Sardi Carlo
 **
 ** Date : 29/12/2001
 **
@@ -38,6 +38,7 @@
 #include "libCommon/genericLord.h"
 #include "libCommon/genericPlayer.h"
 #include "libCommon/dataTheme.h"
+#include "libClient/askWidget.h"
 #include "libClient/gui.h"
 
 extern DataTheme DataTheme;
@@ -47,10 +48,40 @@ extern DataTheme DataTheme;
 // ----- PropertiesBase -----
 //
 
-PropertiesBase::PropertiesBase( QPtrList<GenericPlayer> * players, QWidget * parent, const char * name )
-	: QDialog( parent, name, true )
+PropertiesBase::PropertiesBase( QPtrList<GenericPlayer> * players, QWidget  * parent, const char * name )
+	:QTabDialog( parent, name, true )
+{
+	setCaption( tr( "Base properties" ) );
+	_players = players;
+	_base = 0;
+
+	_general = new GeneralPropertiesBase( players, this );
+	_units = new PropertiesBaseUnits( this );
+
+	addTab( _general, tr( "General" ) );
+	addTab( _units, tr( "Units" ) );
+	setOkButton();
+	setCancelButton();
+}
+
+void PropertiesBase::accept()
+{
+	_general->accept();
+	_units->accept();
+	QTabDialog::accept();
+}
+
+void PropertiesBase::init( GenericBase * base )
+{
+	_base = base;
+	_general->init( base );
+	_units->init( base );
+}
+
+
+GeneralPropertiesBase::GeneralPropertiesBase( QPtrList<GenericPlayer> * players, QWidget * parent, const char * name )
+	: QWidget( parent, name )
 {
-        setCaption( tr( "Base properties" ) );
 	_base = 0;
 
 	QLabel * ownerLabel = new QLabel( this );
@@ -63,14 +94,12 @@ PropertiesBase::PropertiesBase( QPtrList<GenericPlayer> * players, QWidget * par
 	_listBuilding->addColumn( tr( "Buildings" ) );
 	_listBuilding->setSorting( -1 );
 
-	QPushButton * pb = new QPushButton( this );
-	pb->setText( tr( "Ok" ) );
-	FIXEDSIZE( pb );
-
 	QHBoxLayout * layH1 = new QHBoxLayout();
 	layH1->setSpacing( 5 );
 	layH1->addWidget( ownerLabel );
 	layH1->addWidget( _ownerList, 1 );
+	
+	_name = new AskString( tr( "Name: " ), this );
 
 	QHBoxLayout * layH2 = new QHBoxLayout();
 	layH2->setSpacing( 5 );
@@ -79,21 +108,20 @@ PropertiesBase::PropertiesBase( QPtrList<GenericPlayer> * players, QWidget * par
 	QHBoxLayout * layH = new QHBoxLayout();
 	layH->setMargin( 5 );
 	layH->addStretch( 1 );
-	layH->addWidget( pb );
 
 	QVBoxLayout * layout = new QVBoxLayout( this );
 	layout->setMargin( 5 );
 	layout->setSpacing( 5 );
 	layout->addLayout( layH1 );
+	layout->addWidget( _name );
 	layout->addLayout( layH2, 1 );
 	layout->addLayout( layH );
 	layout->activate();
 
-	connect( pb, SIGNAL( clicked() ), SLOT( slot_accept() ) );
 	connect( _ownerList, SIGNAL( activated( int ) ), SLOT( slot_owner( int ) ) );
 }
 
-void PropertiesBase::refresh( QPtrList<GenericPlayer> * players )
+void GeneralPropertiesBase::refresh( QPtrList<GenericPlayer> * players )
 {
 	_players = players;
 	_ownerList->clear();
@@ -108,7 +136,7 @@ void PropertiesBase::refresh( QPtrList<GenericPlayer> * players )
 }
 
 
-void PropertiesBase::slot_accept()
+void GeneralPropertiesBase::accept()
 {
 	QListViewItemIterator ite( _listBuilding );
 	int i =0;
@@ -127,10 +155,10 @@ void PropertiesBase::slot_accept()
 		}
 		i++;
 	}
-	accept();
+	_base->setName( _name->getValue() );
 }
 
-void PropertiesBase::slot_owner( int num )
+void GeneralPropertiesBase::slot_owner( int num )
 {
 	if( _base->getOwner() ) {
 		_base->getOwner()->removeBase( _base );
@@ -143,7 +171,7 @@ void PropertiesBase::slot_owner( int num )
 	}
 }
 
-void PropertiesBase::init( GenericBase * base )
+void GeneralPropertiesBase::init( GenericBase * base )
 {
 	_base = base;
 	_listBuilding->clear();
@@ -167,8 +195,70 @@ void PropertiesBase::init( GenericBase * base )
 	} else {
 		_ownerList->setCurrentItem( 0 );
 	}
+	
+	_name->setValue( _base->getName() );
+}
+
+//
+// ----- PropertiesBaseUnits -----
+//
+
+PropertiesBaseUnits::PropertiesBaseUnits( QWidget * parent, const char * name )
+: QWidget( parent, name )
+{
+	_base = 0;
+
+	QHBoxLayout * layH1 = new QHBoxLayout();
+	QHBoxLayout * layH2 = new QHBoxLayout();
+
+	for( int i = 0; i < MAX_UNIT; i++ ) {
+		_troop[i] = new EditTroop( i, this );
+		if( i <= (MAX_UNIT / 2 ) ) {
+			layH1->addWidget( _troop[i] );
+		} else {
+			layH2->addWidget( _troop[i] );
+		}
+	}
+	layH1->addStretch( 1 );
+	layH2->addStretch( 1 );
+
+	QVBoxLayout * layout = new QVBoxLayout( this );
+	layout->setSpacing( 5 );
+	layout->addLayout( layH1 );
+	layout->addLayout( layH2 );
+	layout->addStretch( 1 );
+	layout->activate();
+}
+
+void PropertiesBaseUnits::init( GenericBase * base )
+{
+	_base = base;
+
+	for( int i = 0; i < MAX_UNIT; i++ ) {
+		_troop[i]->init (_base->getUnit (i));
+	}
+}
+
+void PropertiesBaseUnits::accept()
+{
+	for( int i = 0; i < MAX_UNIT; i++ ) {
+		_troop[i]->save( i, _base );
+	}
+}
+
+bool PropertiesBaseUnits::hasNoneUnits ()
+{
+	bool hasUnits = false;
+
+	for( int i = 0; i < MAX_UNIT; i++ ) {
+		if (_troop[i]->hasUnits ())
+		{
+			hasUnits = true;
+		}
+	}
+
+	return (!hasUnits);
 }
 
 
 
-
