@@ -5,9 +5,9 @@
 ** propertiesBase.h
 ** Defines properties box for bases on map
 **
-** Version : $Id: propertiesBase.h,v 1.2 2004/07/31 19:29:47 audoux Exp $
+** Version : $Id: propertiesBase.h,v 1.4 2004/12/08 11:17:30 lusum Exp $
 **
-** Author(s) : Pascal Audoux
+** Author(s) : Pascal Audoux - Sardi Carlo
 **
 ** Date : 29/12/2001
 **
@@ -28,6 +28,7 @@
 #ifndef PROPERTIESBASE_H
 #define PROPERTIESBASE_H
  
+#include "propertiesLord.h"
  
 // generic include files
 // include files for QT
@@ -38,17 +39,19 @@
 
 class QComboBox;
 class QListView;
+
+class AskString;
 class GenericLord;
 class GenericBase;
 class GenericPlayer;
+class GeneralPropertiesBase;
+class PropertiesBaseUnits;
 
 /*              ------------------------------
  *                         PropertiesBase
  *              ------------------------------ */
 
-
-/** Dialog for editing the properties of the base */
-class PropertiesBase : public QDialog
+class PropertiesBase : public QTabDialog
 {
 	Q_OBJECT
 public:
@@ -57,10 +60,34 @@ public:
 
 	void init( GenericBase * base );
 
+public slots:
+	virtual void accept();
+
+private:
+	QPtrList<GenericPlayer> * _players;
+	GenericBase * _base;
+
+	GeneralPropertiesBase * _general;
+	PropertiesBaseUnits * _units;
+};
+
+
+
+/** Dialog for editing the properties of the base */
+class GeneralPropertiesBase : public QWidget
+{
+	Q_OBJECT
+public:
+	/** Constructor */
+	GeneralPropertiesBase( QPtrList<GenericPlayer> * players, QWidget * parent = 0, const char * name = 0 );
+
+	void init( GenericBase * base );
+
 	void refresh( QPtrList<GenericPlayer> * players );
+	
+	void accept();
 
 public slots:
-	void slot_accept();
 
 	void slot_owner( int );
 
@@ -69,6 +96,25 @@ private:
 	GenericBase * _base;
 	QListView * _listBuilding;
 	QComboBox * _ownerList;
+	AskString * _name;
 };
 
+class PropertiesBaseUnits : public QWidget
+{
+public:
+	PropertiesBaseUnits( QWidget * parent = 0, const char * name = 0 );
+
+	void init( GenericBase * base );
+
+	void accept();
+
+	bool hasNoneUnits ();
+
+protected:
+	GenericBase * _base;
+	EditTroop * _troop[MAX_UNIT];
+};
+
+
+
 #endif // PROPERTIESBASE_H
