@@ -53,11 +53,14 @@ private:
     QLabel * _creaturePix;
     QPtrVector<AskInt> _creatureStacks;
     AskCombo * _creatureBehaviour;
+    AskCombo * _creatureGrowth;
+    AskInt * _growthParam0, * _growthParam1;
     AskBool * _creatureFlee;
     AskBool * _lookingRight;
 
 private slots:
-    void slotAccept ();
+	void slot_accept ();
+	void slot_growthMode( int mode );
 };
 
 #endif // PROPERTIESCREATURE_H   
