@@ -5,7 +5,7 @@
 ** propertiesLord.cpp
 ** this is a template for all .cpp files
 **
-** Version : $Id: propertiesLord.cpp,v 1.12 2004/08/01 21:08:37 audoux Exp $
+** Version : $Id: propertiesLord.cpp,v 1.16 2004/12/11 13:39:40 lusum Exp $
 **
 ** Author(s) : Pascal Audoux
 **
@@ -485,6 +485,7 @@ EditTroop::EditTroop( int num, QWidget * parent, const char * name )
 	layout->addWidget( _name );
 
 	_number = new AskInt( tr( "Number : " ), this );
+	_number->setMaxValue( 65535 );
 	layout->addWidget( _number );
 
 	layout->addStretch( 1 );
@@ -568,6 +569,25 @@ void EditTroop::save( int i, GenericLord * lord )
 	}
 }
 
+void EditTroop::save( int i, GenericBase * base )
+{
+	GenericFightUnit * unit = base->getUnit( i );
+
+	if( _number->getValue() > 0 ) {
+		if( ! unit ) {
+			unit = new GenericFightUnit();
+		}
+		unit->setCreature( _race->currentItem(), _name->currentItem() );
+		unit->setNumber( _number->getValue() );
+		base->setUnit( i, unit );
+	} else {
+		if( unit ) {
+			delete unit;
+		}
+		base->setUnit( i, 0 );
+	}
+}
+
 
 //
 // ----- PropertiesLordArtefacts -----
@@ -578,45 +598,44 @@ PropertiesLordArtefacts::PropertiesLordArtefacts( QWidget * parent, const char *
 {
 	_lord = 0;
 
-     // main layout
-     QHBoxLayout* mainLayout = new QHBoxLayout (this);
+	// main layout
+	QHBoxLayout * mainLayout = new QHBoxLayout( this );
 
-     QPushButton* addButton = new QPushButton (this);
-     QPushButton* removeButton = new QPushButton (this);
+	QPushButton * addButton = new QPushButton( this );
+	QPushButton * removeButton = new QPushButton( this );
 
-     addButton->setText ("->");
-     removeButton->setText ("<-");
+	addButton->setText( "->" );
+	removeButton->setText( "<-" );
 
-     _artefactsList = new QTable (DataTheme.artefacts.count (), 1, this);
-     _artefactsList->setLeftMargin (1);
-     _artefactsList->setTopMargin (40);
-     _artefactsList->setColumnStretchable (0, true);
-     _artefactsList->setReadOnly (true);
-     _artefactsList->setShowGrid (false);
-     _artefactsList->setSelectionMode (QTable::SingleRow);
-     _artefactsList->horizontalHeader()->setLabel (0, tr( "Common artefacts list" ) );
+	_artefactsList = new QTable( DataTheme.artefacts.count(), 1, this );
+	_artefactsList->setLeftMargin( 1 );
+	_artefactsList->setTopMargin( 40 );
+	_artefactsList->setColumnStretchable( 0, true );
+	_artefactsList->setReadOnly( true );
+	_artefactsList->setShowGrid( false );
+	_artefactsList->setSelectionMode( QTable::SingleRow );
+	_artefactsList->horizontalHeader()->setLabel( 0, tr( "Common artefacts list" ) );
 
-     _lordsArtefactsList = new QTable (DataTheme.artefacts.count (), 1, this);
-     _lordsArtefactsList->setLeftMargin (1);
-     _lordsArtefactsList->setTopMargin (40);
-     _lordsArtefactsList->setColumnStretchable (0, true);
-     _lordsArtefactsList->setReadOnly (true);
-     _lordsArtefactsList->setShowGrid (false);
-     _lordsArtefactsList->setSelectionMode (QTable::SingleRow);
-     _lordsArtefactsList->horizontalHeader()->setLabel (0, tr( "Lord's artefacts list" ));
+	_lordsArtefactsList = new QTable( DataTheme.artefacts.count(), 1, this );
+	_lordsArtefactsList->setLeftMargin( 1 );
+	_lordsArtefactsList->setTopMargin( 40 );
+	_lordsArtefactsList->setColumnStretchable( 0, true );
+	_lordsArtefactsList->setReadOnly( true );
+	_lordsArtefactsList->setShowGrid( false );
+	_lordsArtefactsList->setSelectionMode( QTable::SingleRow );
+	_lordsArtefactsList->horizontalHeader()->setLabel( 0, tr( "Lord's artefacts list" ) );
 
-     QGridLayout* gridLayout = new QGridLayout (5 , 1, 20);
-     gridLayout->addWidget (addButton,1,0, Qt::AlignCenter);
-     gridLayout->addWidget (removeButton,3,0, Qt::AlignCenter);
+	QGridLayout* gridLayout = new QGridLayout( 5 , 1, 20 );
+	gridLayout->addWidget( addButton, 1, 0, Qt::AlignCenter );
+	gridLayout->addWidget( removeButton, 3, 0, Qt::AlignCenter );
 
-     mainLayout->setMargin (20);
-     mainLayout->addWidget (_artefactsList, 3);
-     mainLayout->addLayout (gridLayout , 2);
-     mainLayout->addWidget (_lordsArtefactsList, 3);
+	mainLayout->setMargin( 20 );
+	mainLayout->addWidget( _artefactsList, 3 );
+	mainLayout->addLayout( gridLayout, 2 );
+	mainLayout->addWidget( _lordsArtefactsList, 3 );
 
-     connect (addButton, SIGNAL (clicked ()), this, SLOT (addButtonPushed ()));
-
-     connect (removeButton, SIGNAL (clicked ()), this, SLOT (removeButtonPushed ()));
+	connect( addButton, SIGNAL( clicked() ), this, SLOT( slot_addButtonPushed() ) );
+	connect( removeButton, SIGNAL( clicked() ), this, SLOT( slot_removeButtonPushed() ) );
 }
 
 void PropertiesLordArtefacts::init( GenericLord * lord )
@@ -667,30 +686,34 @@ void PropertiesLordArtefacts::fillArtefactsList ()
 	refreshArtefactsList ();
 }
 
-void PropertiesLordArtefacts::addButtonPushed ()
+void PropertiesLordArtefacts::slot_addButtonPushed()
 {
-   if (_artefactsList->numSelections () <= 0) return;
+	if( _artefactsList->numSelections() <= 0 ) {
+		return;
+	}
 
-   QTableSelection sel = _artefactsList->selection (0);
+	QTableSelection sel = _artefactsList->selection( 0 );
 
-   int row = sel.topRow ();
+	int row = sel.topRow();
 
-   _artefacts[row] = true;
+	_artefacts[ row ] = true;
 
-   refreshArtefactsList ();
+	refreshArtefactsList();
 }
 
-void PropertiesLordArtefacts::removeButtonPushed ()
+void PropertiesLordArtefacts::slot_removeButtonPushed()
 {
-   if (_lordsArtefactsList->numSelections () <= 0) return;
+	if( _lordsArtefactsList->numSelections() <= 0 ) {
+		return;
+	}
 
-   QTableSelection sel = _lordsArtefactsList->selection (0);
+	QTableSelection sel = _lordsArtefactsList->selection( 0 );
+	
+	int row = sel.topRow();
 
-   int row = sel.topRow ();
+	_artefacts[ row ] = false;
 
-   _artefacts[row] = false;
-
-   refreshArtefactsList ();
+	refreshArtefactsList();
 }
 
 void PropertiesLordArtefacts::refreshArtefactsList ()
