@@ -5,7 +5,7 @@
 ** propertiesLord.h
 ** Properties for lords
 **
-** Version : $Id: propertiesLord.h,v 1.5 2004/07/31 19:29:47 audoux Exp $
+** Version : $Id: propertiesLord.h,v 1.8 2004/12/08 11:17:30 lusum Exp $
 **
 ** Author(s) : Pascal Audoux & Nick Semenov
 **
@@ -155,6 +155,8 @@ public:
 
 	/** Saves the data */
 	void save( int i, GenericLord * lord );
+	
+	void save( int i, GenericBase * base );
 
 	bool hasUnits ();
 
@@ -187,7 +189,7 @@ protected:
 
 class PropertiesLordArtefacts : public QWidget
 {
-      Q_OBJECT
+	Q_OBJECT
 public:
 	PropertiesLordArtefacts( QWidget * parent = 0, const char * name = 0 );
 
@@ -198,28 +200,26 @@ public:
 protected:
 	GenericLord * _lord;
 
-       QTable* _artefactsList;
-       
-       QTable* _lordsArtefactsList;
+	QTable * _artefactsList;
+	
+	QTable * _lordsArtefactsList;
 
-       /* true if artefact belongs to lord, false elsethere*/
-       bool _artefacts[100];
+	/* true if artefact belongs to lord, false elsethere XXX: to change in dynamic... */
+	bool _artefacts[100];
 
-       void fillArtefactsList ();
+	void fillArtefactsList();
 
-       void refreshArtefactsList ();
+	void refreshArtefactsList();
 
 private slots:
+	void slot_addButtonPushed();
 
-       void addButtonPushed ();
-
-       void removeButtonPushed ();       
-
+	void slot_removeButtonPushed();       
 };
 
 class PropertiesLordWarMachines : public QWidget
 {
-      Q_OBJECT
+	Q_OBJECT
 public:
 	PropertiesLordWarMachines( QWidget * parent = 0, const char * name = 0 );
 
