@@ -5,7 +5,7 @@
 ** screen.cpp
 ** main widget of the editor
 **
-** Version : $Id: screen.cpp,v 1.22 2004/06/15 21:33:55 lusum Exp $
+** Version : $Id: screen.cpp,v 1.27 2004/12/19 15:10:11 lusum Exp $
 **
 ** Author(s) : Pascal Audoux
 **
@@ -183,8 +183,8 @@ void Screen::handleDelete()
 		Event * event = (Event *)( _currentCell->getEvent() );
 		_events.remove(event);
 		_currentCell->setEvent( 0 );
-	} else if( _currentCell->getDecoration() ) {
-		_currentCell->setDecoration( 0 );
+	} else if( _currentCell->getDecorationGroup() ) {
+		_currentCell->setDecoration( 0, 0 );
 	} else if( _currentCell->getTransition() ) {
 		_currentCell->setTransition( 0 );
 		_currentCell->setTransitionCellType( 0 );
@@ -253,9 +253,11 @@ void Screen::handlePropertiesLord()
 
 void Screen::handlePropertiesBase()
 {
-	PropertiesBase propBase( & _players );
-	propBase.init( _currentCell->getBase() );
-	propBase.exec();
+	PropertiesBase * propBase = new PropertiesBase( & _players );
+	propBase->init( _currentCell->getBase() );
+	propBase->exec();
+	
+	delete propBase;
 }
 
 void Screen::handlePropertiesBuilding()
@@ -302,7 +304,7 @@ void Screen::slot_mouseMoved( Cell * c )
 			setCursor( waitCursor );
 		} else if( c->getCreature() ) {
 			setCursor( waitCursor );
-		} else if( c->getDecoration() ) {
+		} else if( c->getDecorationGroup() ) {
 			setCursor( pointingHandCursor );
 	//	} else if( c->getTransition() ) {
 	//		setCursor( upArrowCursor );
@@ -327,7 +329,10 @@ void Screen::displayInfo()
 	info.setTheme( getScenarioTheme() );
 	info.setDescription( getScenarioDescription() );
 	if( info.exec() ) {
-		// XXX:get back the infos...
+		setNbPlayer( info.getNbPlayer() );
+		setScenarioName( info.getName() );
+		setScenarioTheme( info.getTheme() );
+		setScenarioDescription( info.getDescription() );
 	}
 }
 
@@ -347,6 +352,7 @@ bool Screen::load( const QString filename )
 		logEE( "Parse Error (%s) : %s", filename.latin1(), handler.errorProtocol().latin1() );
 		return false;
 	}
+	_map->computeStoppable();
 	if(!_miniMap->isHidden()){
 		_miniMap->redrawMap( _map );
 	}
@@ -385,6 +391,7 @@ void Screen::newScenario()
 		for( uint i = 0; i < info.getNbPlayer(); i++ ) {
 			GenericPlayer * player = new GenericPlayer( theMap );
 			player->setNum( i );
+			player->setName( QString("Player %1").arg(i) );
 			_players.append( player );
 		}
 	}
@@ -426,8 +433,8 @@ void Screen::clearMap()
 					_creatures.remove(theMap->at( i, j )->getCreature());
 					theMap->at( i, j )->setCreature( 0 );
 				}
-				if( theMap->at( i, j )->getDecoration() ) {
-					theMap->at( i, j )->setDecoration( 0 );
+				if( theMap->at( i, j )->getDecorationGroup() ) {
+					theMap->at( i, j )->setDecoration( 0, 0 );
 				}
 				if( theMap->at( i, j )->getTransition() ) {
 					theMap->at( i, j )->setTransitionCellType( 0 );
@@ -440,6 +447,7 @@ void Screen::clearMap()
 		if(!_miniMap->isHidden()){
 			_miniMap->redrawMap( _map );
 		}
+		_map->computeStoppable();
 	}
 }
 
@@ -476,3 +484,4 @@ void Screen::manageQuests()
 	quests->exec();
 	delete quests;
 }
+
