@@ -5,9 +5,9 @@
 ** engine.cpp
 ** the game engine !
 **
-** Version : $Id: engine.cpp,v 1.51 2004/10/12 21:40:37 audoux Exp $
+** Version : $Id: engine.cpp,v 1.69 2004/12/24 18:28:19 lusum Exp $
 **
-** Author(s) : Pascal Audoux
+** Author(s) : Pascal Audoux - Sardi Carlo
 **
 ** Date : 03/10/2000
 **
@@ -136,9 +136,15 @@ void Engine::stateNotPlaying( int num )
 			for( uint i = 0; i < len; i++) {
 				res.append( _server->readChar() );
 			}
-			/// XXX: be sure that name is unique...
+			for( uint j = 0; j < _players.count(); j++ ) {
+				if( _players.at( j )->getName() == res ) {
+					res+=QString("_%1").arg(j);
+				}
+			}
+
 			_players.at( num )->setName( res );
 			_server->sendConnectionId( num );
+			_server->sendConnectionName( res , num);
 			emit sig_newPlayer( _server->findSocket( _players.at( num ) ) );}
 			break;
 		case C_CONN_PLAYER:
@@ -252,16 +258,180 @@ void Engine::handleAnswer()
 			_currentPlayer->increaseResource( 0, 1000 );
 			_server->sendPlayerResource( 0, _currentPlayer->getResource( 0 ) );
 		} else	{
-			GenericLord * lord = _question->getLord();
-			if( lord ) {
-				manageIncreaseExperience( lord, 2500 );
-			} else {
-				logEE( "Lord in _question should not be NULL" );
+			switch( _question->getType() ) {
+			case C_QR_CHEST: {
+				GenericLord * lord = _question->getLord();
+				if( lord ) {
+					manageIncreaseExperience( lord, 2500 );
+				} else {
+					logEE( "Lord in _question should not be NULL" );
+				}
+				} break;
+			default:
+				logEE( "should not happen" );
 			}
 		}
 		_state = IN_GAME;
 		}
 		break;
+	case ANSWER_YESNO:
+		switch( _question->getType() ) {
+		case C_QR_CREATURE_JOIN:
+			handleAnswerCreatureJoin();
+			break;
+		case C_QR_CREATURE_MERCENARY:
+			handleAnswerCreatureMercenary();
+			break;
+		case C_QR_CREATURE_FLEE:
+			handleAnswerCreatureFlee();
+			break;
+		default:
+			logEE( "Should not happen" );
+		}
+	}
+}
+
+void Engine::handleAnswerCreatureJoin()
+{
+	bool accept = (bool) _server->readChar();
+	GenericMapCreature * creature = _question->getCreature();
+	GenericLord * lord = _question->getLord();
+	
+	uchar race = creature->getRace();
+	uchar level = creature->getLevel();
+	
+	if( accept ) {
+		_state = IN_GAME;
+		GenericFightUnit * unit = 0;
+		int place = -1;
+				
+		for( uint i = 0; i < MAX_UNIT; i++ ) {
+			unit = lord->getUnit( i );
+			
+			if( unit ) {
+				if( ( unit->getRace() == race ) && ( unit->getLevel() == level ) ) {
+					place = i;
+					break;
+				}
+			} else {
+				place = i;
+				break;
+			}
+		}
+		
+		if( place >= 0 ) {
+			unit = lord->getUnit( place );
+			
+			if( ! unit ) {
+				unit = new GenericFightUnit();
+				unit->setCreature( race, level );
+			}
+			unit->addNumber( creature->getCreatureNumber() );
+			lord->setUnit( place, unit );
+			_server->updateUnit( lord, place );
+		} else {
+			_server->sendAskNone( tr( "You have no place for recruiting new creatures" ) );
+		}
+		GenericCell * cell = creature->getCell();
+		_server->sendCreatureRemove( cell );
+			
+		cell->setCreature( 0 );
+		_creatures.remove(creature);
+	} else {
+		if( creature->isFleeing() ) {
+			_question->setType( C_QR_CREATURE_FLEE );
+			_server->sendAskCreatureFlee( creature );
+		} else {
+			_state = IN_GAME;
+			startFight( lord->getId(), _question->getCreature() );
+			_isCreature = true;
+		}
+	}
+}
+
+void Engine::handleAnswerCreatureMercenary()
+{
+	bool accept = (bool) _server->readChar();
+	GenericMapCreature * creature = _question->getCreature();
+	GenericLord * lord = _question->getLord();
+	
+	uchar race = creature->getRace();
+	uchar level = creature->getLevel();
+	
+	if( accept ) {
+		_state = IN_GAME;
+		GenericFightUnit * unit = 0;
+		int place = -1;
+				
+		for( uint i = 0; i < MAX_UNIT; i++ ) {
+			unit = lord->getUnit( i );
+			
+			if( unit ) {
+				if( ( unit->getRace() == race ) && ( unit->getLevel() == level ) ) {
+					place = i;
+					break;
+				}
+			} else {
+				place = i;
+				break;
+			}
+		}
+		
+		if( place >= 0 ) {
+			if( _currentPlayer->canBuy( creature->getCreature(), creature->getCreatureNumber() ) ) {
+				_currentPlayer->buy( creature->getCreature(), creature->getCreatureNumber() );
+				_server->sendPlayerResources( _currentPlayer );
+				
+				unit = lord->getUnit( place );
+				
+				if( ! unit ) {
+					unit = new GenericFightUnit();
+					unit->setCreature( race, level );
+				}
+				unit->addNumber( creature->getCreatureNumber() );
+				lord->setUnit( place, unit );
+				_server->updateUnit( lord, place );
+			} else {
+				_server->sendAskNone( tr( "You have not enough resources for recruiting this creatures" ) );
+			}
+		} else {
+			_server->sendAskNone( tr( "You have no place for recruiting new creatures" ) );
+		}
+		GenericCell * cell = creature->getCell();
+		_server->sendCreatureRemove( cell );
+			
+		cell->setCreature( 0 );
+		_creatures.remove(creature);
+	} else {
+		GenericMapCreature * creature = _question->getCreature();
+		
+		if( creature->isFleeing() ) {
+			_question->setType( C_QR_CREATURE_FLEE );
+			_server->sendAskCreatureFlee( creature );
+		} else {
+			_state = IN_GAME;
+			startFight( _question->getLord()->getId(), _question->getCreature() );
+			_isCreature = true;
+		}
+	}
+}
+
+void Engine::handleAnswerCreatureFlee()
+{
+	bool accept = (bool) _server->readChar();
+	
+	if( accept ) {
+		_state = IN_GAME;
+		GenericMapCreature * creature = _question->getCreature();
+		GenericCell * cell = creature->getCell();
+		_server->sendCreatureRemove( cell );
+			
+		cell->setCreature( 0 );
+		_creatures.remove(creature);
+	} else {
+		_state = IN_GAME;
+		startFight( _question->getLord()->getId(), _question->getCreature() );
+		_isCreature = true;
 	}
 }
 
@@ -476,6 +646,7 @@ void Engine::movingOnChest( GenericLord * movingLord, GenericCell * destCell )
 	GenericEvent * event = destCell->getEvent();
 
 	_question->setLord( movingLord );
+	_question->setType( C_QR_CHEST );
 	_server->sendAskChest();
 	_state = IN_QUESTION;
 	destCell->setEvent( 0 );
@@ -507,6 +678,13 @@ void Engine::movingOnBuilding( GenericLord * movingLord, GenericCell * destCell,
 				}
 			}
 			_currentPlayer->addBuilding( building );
+			building->setOwner( _currentPlayer );
+			for( i = 0; i < _players.count(); i++ ) {
+				tempPlayer = _players.at( i );
+				if( tempPlayer->canSee( destCell ) ) {
+					_server->ownBuilding( building, tempPlayer );
+				}
+			}
 		}
 		destCell->setLord( movingLord );
 		int row = movingLord->getCell()->getRow();
@@ -534,7 +712,14 @@ void Engine::movingOnBase( GenericLord * movingLord, GenericCell * destCell, int
 		for( index = 0; index < _players.count(); index++ ) {
 			tempPlayer = _players.at( index );
 			if( tempPlayer->canSee( destCell ) ) {
+				updatePlayerPrices(tempPlayer);
 				_server->ownBase( base, tempPlayer );
+				uint nbRes = DataTheme.resources.count();
+				int price;
+				for( uint i = 0; i < nbRes; i++ ) {
+					price = tempPlayer->getPriceMarket()->getResourcePrice( i );
+					_server->sendPlayerPrice( i, price );
+				}
 			}
 		}
 	}
@@ -548,20 +733,47 @@ void Engine::movingOnBase( GenericLord * movingLord, GenericCell * destCell, int
 
 void Engine::movingOnCreature( GenericLord * movingLord, GenericCell * destCell )
 {
-	uchar lord = movingLord->getId();
+	//uchar lord = movingLord->getId();
 	int cost = movingLord->computeCostMvt( destCell );
-
+	
 	movingLord->decreaseBaseCharac( MOVE, cost );
 
 	GenericMapCreature * creature = destCell->getCreature();
 	uint lordForce = movingLord->computeForceIndicator();
 	uint creatureForce = creature->computeForceIndicator();
+	
 	if( creatureForce > 0 ) {
 		double ratio = double( lordForce ) / double( creatureForce );
-		/* XXX: to use... CreatureAction action =*/ computeCreatureAction( creature, ratio );
-		/// XXX: handle friendly map creatures...
-		startFight( lord, creature );
-		_isCreature = true;
+		
+		CreatureAction action = computeCreatureAction( creature, ratio );
+		
+		switch( action ) {
+		case CreatureJoin:
+			_question->setType( C_QR_CREATURE_JOIN );
+			_question->setLord( movingLord );
+			_question->setCreature( creature );
+			_state = IN_QUESTION;
+			_server->sendAskCreatureJoin( creature );
+			break;
+		case CreatureMercenary:
+			_question->setType( C_QR_CREATURE_MERCENARY );
+			_question->setLord( movingLord );
+			_question->setCreature( creature );
+			_state = IN_QUESTION;
+			_server->sendAskCreatureMercenary( creature );
+			break;
+		case CreatureFlee:
+			_question->setType( C_QR_CREATURE_FLEE );
+			_question->setLord( movingLord );
+			_question->setCreature( creature );
+			_state = IN_QUESTION;
+			_server->sendAskCreatureFlee( creature );
+			break;
+		case CreatureFight:
+			startFight( movingLord->getId(), creature );
+			_isCreature = true;
+			break;
+		}	
 	}
 }
 
@@ -608,6 +820,9 @@ void Engine::handleInGameExchange()
 	case C_EXCH_UNIT:
 		exchangeUnits();
 		break;
+	case C_EXCH_ARTEFACT:
+		exchangeArtefact();
+		break;
 	case C_EXCH_BASEUNIT:
 		exchangeBaseUnits();
 		break;
@@ -624,6 +839,7 @@ void Engine::exchangeUnits()
 	uchar idUnit2 = _server->readChar();
 	GenericLord * lord1 = 0;
 	GenericLord * lord2 = 0;
+	
 	if( idLord1 ) {
 		lord1 = _currentPlayer->getLordById( idLord1 );
 	}
@@ -656,13 +872,43 @@ void Engine::exchangeUnits()
 	}
 }
 
+void Engine::exchangeArtefact()
+{
+	uchar idLord1 = _server->readChar();
+	int item = _server->readInt();
+	uchar idLord2 = _server->readChar();
+	
+	GenericLord * lord1 = 0;
+	GenericLord * lord2 = 0;
+	
+	if( idLord1 ) {
+		lord1 = _currentPlayer->getLordById( idLord1 );
+	}
+	if( idLord2 ) {
+		lord2 = _currentPlayer->getLordById( idLord2 );
+	}
+	
+	if( lord1 && lord2 ) {
+		ArtefactManager * manag1 = lord1->getArtefactManager();
+		ArtefactManager * manag2 = lord2->getArtefactManager();
+		
+		GenericLordArtefact * artefact = manag1->getArtefact( item );
+		
+		manag1->removeArtefact( item );
+		manag2->addArtefact( artefact );
+		
+		_server->sendExchangeArtefact( lord1, item, lord2 );
+	}
+}
+
 void Engine::exchangeBaseUnits()
 {
 	uchar idBase = _server->readChar();
 	uchar idUnit1 = _server->readChar();
 	uchar idLord = _server->readChar();
 	uchar idUnit2 = _server->readChar();
-	
+
+	bool noex = false;	
 	GenericBase * base = _currentPlayer->getBaseById( idBase );
 	GenericLord * lord = 0; 
 	if(idLord && idLord<255){
@@ -684,13 +930,17 @@ void Engine::exchangeBaseUnits()
 					lord->setUnit( idUnit2, uni1 );
 					base->setUnit( idUnit1, uni2 );
 				} else {
-					uni1->addNumber( uni2->getNumber() );
-					lord->setUnit( idUnit2, 0 );
-					delete uni2;
+					uni2->addNumber( uni1->getNumber() );
+					base->setUnit( idUnit1, 0 );
+					delete uni1;
 				}
 			} else if (!uni1) {
-				lord->setUnit( idUnit2, 0 );
-				base->setUnit( idUnit1, uni2 );
+				if(lord->countUnits() > 1){
+					lord->setUnit( idUnit2, 0 );
+					base->setUnit( idUnit1, uni2 );
+				} else {
+					noex = true;
+				}
 			} else if (!uni2) {
 				lord->setUnit( idUnit2, uni1 );
 				base->setUnit( idUnit1, 0 );
@@ -713,7 +963,8 @@ void Engine::exchangeBaseUnits()
 				base->setUnit( idUnit1, 0 );
 			}
 		}	
-		_server->sendExchangeBaseUnitCl(base,idUnit1,lord,idUnit2);
+		if(noex == false) 
+			_server->sendExchangeBaseUnitCl(base,idUnit1,lord,idUnit2);
 	}
 }
 
@@ -750,41 +1001,43 @@ void Engine::handleInGameModifBase()
 	
 
 		GenericBase * base = _currentPlayer->getBaseById( id );
-		GenericBaseModel * baseModel = DataTheme.bases.at( base->getRace() );
-		InsideBuildingModel * buildingModel = baseModel->getBuildingModel( building );
+		if(base) {
+			GenericBaseModel * baseModel = DataTheme.bases.at( base->getRace() );
+			InsideBuildingModel * buildingModel = baseModel->getBuildingModel( building );
+			GenericInsideBuilding * tmpbuil = base->getBuildingByType( building );
 
-		if(isBuy==true){
-			if( base->canBuild() && _currentPlayer->canBuy( buildingModel ) ) {
-				for( uint i = 0; i < DataTheme.resources.count(); i++ ) {
-					if( buildingModel->getCost( i ) != 0 ) {
-						_currentPlayer->decreaseResource( i, buildingModel->getCost( i ) );
-						_server->sendPlayerResource( i, _currentPlayer->getResource( i ) );
+			if(isBuy==true && !tmpbuil){
+				if( base->canBuild() && _currentPlayer->canBuy( buildingModel ) ) {
+					for( uint i = 0; i < DataTheme.resources.count(); i++ ) {
+						if( buildingModel->getCost( i ) != 0 ) {
+							_currentPlayer->decreaseResource( i, buildingModel->getCost( i ) );
+							_server->sendPlayerResource( i, _currentPlayer->getResource( i ) );
+						}
+					}
+					base->addBuilding( building );
+					base->canBuild( false );
+					for( index = 0; index < _players.count(); index++ ) {
+						tempPlayer = _players.at( index );
+						if( tempPlayer->canSee( base->getCell() ) ) {
+							_server->updateBaseBuilding( base, base->getBuildingByType( building ), tempPlayer );
+						}
 					}
 				}
-				base->addBuilding( building );
-				base->canBuild( false );
-				for( index = 0; index < _players.count(); index++ ) {
-					tempPlayer = _players.at( index );
-					if( tempPlayer->canSee( base->getCell() ) ) {
-						_server->updateBaseBuilding( base, base->getBuildingByType( building ), tempPlayer );
+			} else if(isBuy == false && tmpbuil) {
+				if( base->canSell() && (DataTheme.bases.at( tmpbuil->getRace() )->getBuildingModel(tmpbuil->getLevel() )->getAction()->getType() !=INSIDE_VILLAGE)){
+					for( uint i = 0; i < DataTheme.resources.count(); i++ ) {
+						if( buildingModel->getCost( i ) != 0 ) {
+							_currentPlayer->increaseResource( i, buildingModel->getCost( i )/2 );
+							_server->sendPlayerResource( i, _currentPlayer->getResource( i ) );
+						}
 					}
-				}
-			}
-		} else {
-			if( base->canSell()) {
-				for( uint i = 0; i < DataTheme.resources.count(); i++ ) {
-					if( buildingModel->getCost( i ) != 0 ) {
-						_currentPlayer->increaseResource( i, buildingModel->getCost( i )/2 );
-						_server->sendPlayerResource( i, _currentPlayer->getResource( i ) );
-					}
-				}
-				GenericInsideBuilding * tmpbuil = base->getBuildingByType( building );
-				base->removeBuilding( tmpbuil );
-				base->canSell( false );
-				for( index = 0; index < _players.count(); index++ ) {
-					tempPlayer = _players.at( index );
-					if( tempPlayer->canSee( base->getCell() ) ) {
-						_server->updateBaseBuilding( base , tmpbuil , tempPlayer);
+					base->removeBuilding( tmpbuil );
+					base->canSell( false );
+					for( index = 0; index < _players.count(); index++ ) {
+						tempPlayer = _players.at( index );
+						if( tempPlayer->canSee( base->getCell() ) ) {
+							_server->updateBaseBuilding( base , tmpbuil , tempPlayer);
+						}
 					}
 				}
 			}
@@ -800,7 +1053,7 @@ void Engine::handleInGameModifBase()
 			uchar level = _server->readChar();
 			int number = _server->readInt();
 			Creature * creature = DataTheme.creatures.at( race, level );
-			if( base->getCreatureProduction( creature ) >= number ) {
+			if( base->getCreatureProduction( creature ) >= number  && number != 0) {
 				if( _currentPlayer->canBuy( creature, number ) ) {
 					_currentPlayer->buy( creature, number );
 					base->addGarrison( creature, number );
@@ -816,48 +1069,28 @@ void Engine::handleInGameModifBase()
 		int firstRes = _server->readInt();
 		int secondRes = _server->readInt();
 		int value = _server->readInt();
-		int cupr,tmpr;
-		uint nbRes = DataTheme.resources.count();
-				
-		 PriceMarket * realPrice = new PriceMarket();
-	
-		 if(firstRes != secondRes){
-			 cupr = 10000;	
+		int cupr;
+		
+		if(firstRes != secondRes){
+			PriceMarket * realPrice = _currentPlayer->getPriceMarket();
+			if(realPrice->getResourcePrice( firstRes ) >= realPrice->getResourcePrice( secondRes )){
 
-			 for( uint i = 0; i < nbRes; i++ ) {
-				 uint nbases = _currentPlayer->numBase();
-				 for( uint j = 0 ; j < nbases ; j++){
-					 PriceMarket * price = DataTheme.bases.at( _currentPlayer->getBase( j )->getRace())->getPriceMarket();
-					 tmpr= price->getResourcePrice( i ) ;
-					 if( tmpr < cupr ) {
-						 cupr = tmpr;
-					 }
-				 }
-				 if(cupr==10000){
-					 cupr=1;
-				 }
-				 realPrice->setResourcePrice(i,cupr);
-				 cupr = 10000;
-			 }
+				cupr= realPrice->getResourceInResource( firstRes,secondRes );
 
-			 if(realPrice->getResourcePrice( firstRes ) >= realPrice->getResourcePrice( secondRes )){
+				//logDD("firstRes %d, secondRes %d, value %d, cupr %d",firstRes,secondRes,value, cupr);
+				_currentPlayer->increaseResource( secondRes, value*cupr);
+				_currentPlayer->decreaseResource( firstRes, value);
+			} else {
+				cupr= realPrice->getResourceInResource( secondRes,firstRes );
 
-				 cupr= realPrice->getResourceInResource( firstRes,secondRes );
+				//logDD("firstRes %d, secondRes %d, value %d, cupr",firstRes,secondRes,value, cupr);
+				_currentPlayer->increaseResource( secondRes, value);
+				_currentPlayer->decreaseResource( firstRes, value*cupr);
 
-				 //logDD("firstRes %d, secondRes %d, value %d, cupr %d",firstRes,secondRes,value, cupr);
-				 _currentPlayer->increaseResource( secondRes, value*cupr);
-				 _currentPlayer->decreaseResource( firstRes, value);
-			 } else {
-				 cupr= realPrice->getResourceInResource( secondRes,firstRes );
-
-				 //logDD("firstRes %d, secondRes %d, value %d, cupr",firstRes,secondRes,value, cupr);
-				 _currentPlayer->increaseResource( secondRes, value);
-				 _currentPlayer->decreaseResource( firstRes, value*cupr);
-
-			 }
-			 _server->sendPlayerResource( firstRes, _currentPlayer->getResource(firstRes));
-			 _server->sendPlayerResource( secondRes, _currentPlayer->getResource(secondRes));
-		 }
+			}
+			_server->sendPlayerResource( firstRes, _currentPlayer->getResource(firstRes));
+			_server->sendPlayerResource( secondRes, _currentPlayer->getResource(secondRes));
+		}
 		} break;
 	default:
 		logDD( "Not yet implemented" );
@@ -868,39 +1101,11 @@ void Engine::handleInGameModifBase()
 void Engine::handleInGameModifLord()
 {
 	switch( _server->getCla3() ) {
-	case C_LORD_GARRISON: {
-			uchar idLord = _server->readChar();
-			bool garrison = ( _server->readChar() == (uchar)1 );
-			GenericLord * lord = _currentPlayer->getLordById( idLord );
-			/// XXX: test if it is possible...
-			if( lord && lord->getCell()->getBase() != 0 ) {
-				lord->setVisible( !garrison );
-				GenericBase * base = lord->getCell()->getBase();
-				if( ( lord == base->getGarrisonLord() ) ||
-				( lord == base->getVisitorLord() ) ) {
-					if( ( garrison && ( lord == base->getVisitorLord() ) )
-					|| ( ( lord == base->getGarrisonLord() ) && !garrison ) ) {
-						base->exchangeLords();
-						_server->setGarrison( lord, garrison );
-					}
-				} else if( ( base->getGarrisonLord() == 0 ) ||
-				( base->getVisitorLord() == 0 ) ) {
-					if( garrison ) {
-						if( base->getGarrisonLord() ) {
-							base->exchangeLords();
-						}
-						base->setGarrisonLord( lord );
-						_server->setGarrison( lord, true );
-					} else {
-						if( base->getVisitorLord() ) {
-							base->exchangeLords();
-						}
-						base->setVisitorLord( lord );
-						_server->setGarrison( lord, false );
-					}
-				}
-			}
-		}
+	case C_LORD_GARRISON: 
+		handleInGameModifLordGarrison();
+		break;
+	case C_LORD_UNIT: 
+		handleInGameModifLordUnit();
 		break;
 	default:
 		logDD( "Not yet implemented (modif lord)" );
@@ -908,6 +1113,87 @@ void Engine::handleInGameModifLord()
 	}
 }
 
+void Engine::handleInGameModifLordGarrison()
+{
+	uchar idLord = _server->readChar();
+	bool garrison = ( _server->readChar() == (uchar)1 );
+	GenericLord * lord = _currentPlayer->getLordById( idLord );
+	
+	/// XXX: test if it is possible...
+	if( lord && lord->getCell()->getBase() != 0 ) {
+		lord->setVisible( !garrison );
+		GenericBase * base = lord->getCell()->getBase();
+		if( ( lord == base->getGarrisonLord() ) ||
+		( lord == base->getVisitorLord() ) ) {
+			if( ( garrison && ( lord == base->getVisitorLord() ) )
+			|| ( ( lord == base->getGarrisonLord() ) && !garrison ) ) {
+				base->exchangeLords();
+				_server->setGarrison( lord, garrison );
+			}
+		} else if( ( base->getGarrisonLord() == 0 ) || ( base->getVisitorLord() == 0 ) ) {
+			if( garrison ) {
+				if( base->getGarrisonLord() ) {
+					base->exchangeLords();
+				}
+				base->setGarrisonLord( lord );
+				_server->setGarrison( lord, true );
+			} else {
+				if( base->getVisitorLord() ) {
+					base->exchangeLords();
+				}
+				base->setVisitorLord( lord );
+				_server->setGarrison( lord, false );
+			}
+		}
+	}
+}
+
+void Engine::handleInGameModifLordUnit()
+{
+	uchar id = _server->readChar();
+	uchar num = _server->readChar();
+	uchar race = _server->readChar();
+	uchar level = _server->readChar();
+	uint nb = _server->readInt();
+	uchar move = _server->readChar();
+	int health = _server->readInt();
+	
+	GenericLord * lord = 0; 
+	GenericFightUnit * unit = 0;
+		
+	if( id && id < 255 ) {
+		lord = _currentPlayer->getLordById( id );
+	}
+
+	unit =lord->getUnit( num );
+	if( ! unit ) {
+		unit = new GenericFightUnit();
+		unit->setCreature( race, level );
+		unit->setMove( move );
+		unit->setHealth( health );
+	}
+	if( unit->getNumber() < nb ) {
+		/* no cheat possible */
+		return;
+	}
+
+	if( nb == 0 ){
+		if( lord->countUnits() > 1 ) {
+			unit->setNumber( nb );
+		}
+	} else {
+		unit->setNumber( nb );
+	}
+
+	lord->setUnit( num, unit );
+	_server->updateUnit( lord, num );
+	if( unit->getNumber() == 0 ){
+		delete unit;
+		unit = 0;
+		lord->setUnit( num, unit );
+	}	
+}
+
 bool Engine::handleBuildingEnter( GenericBuilding * building, GenericLord * lord )
 {
 	bool enter = false;
@@ -1156,8 +1442,15 @@ void Engine::startGame()
 				}
 			}
 		}
+		updatePlayerPrices(_currentPlayer);
+		uint nbRes = DataTheme.resources.count();
+		int price;
+		for( uint i = 0; i < nbRes; i++ ) {
+			price = _currentPlayer->getPriceMarket()->getResourcePrice( i );
+			_server->sendPlayerPrice( i, price );
+		}
 	}
-	_server->sendAskNone( getScenarioDescription() );
+	_server->sendAskNone( getScenarioDescription(), true );
 	
 	newDay();
 	_currentPlayer = _players.at( 0 );
@@ -1318,7 +1611,8 @@ void Engine::newDay()
 	_calendar->newDay();
 	if( _calendar->getDay() == 1 ) {
 		// new week
-		for( uint i = 0; i < _bases.count(); ++i ) {
+		uint nbItems = _bases.count();
+		for( uint i = 0; i < nbItems; ++i ) {
 			_bases.at( i )->initCreatureProduction();
 			_bases.at( i )->getPopGrowth();
 			for( index = 0; index < _players.count(); index++ ) {
@@ -1328,6 +1622,11 @@ void Engine::newDay()
 				}
 			}
 		}
+		nbItems = _creatures.count();
+		for( uint i = 0; i < nbItems; ++i ) {
+			_creatures.at( i )->grow();
+			_server->updateCreature( _creatures.at( i ) ); /// XXX:  we could update only if 'category' has changed...
+		}
 	}
 }
 
@@ -1432,6 +1731,7 @@ void Engine::handleCreatTurn( GenericPlayer * player, GenericLord * lord )
 
 void Engine::handleBuildingAction( Action * action, GenericPlayer * player )
 {
+	int ress;
 	for( int i = 0; i < action->getElementaryNumber(); i++ ) {
 		ElementaryAction * elementary = action->getElementaryAction( i );
 		switch( elementary->getType() ) {
@@ -1440,7 +1740,8 @@ void Engine::handleBuildingAction( Action * action, GenericPlayer * player )
 				_server->sendPlayerResource( elementary->getArg(), player->getResource( elementary->getArg() ) );
 				break;
 			case ElementaryAction::RANDRESSOURCE:
-				player->setResource( elementary->getArg(), player->getResource( elementary->getArg() ) + elementary->getCoeff()*(int) ((2.0*rand())/(RAND_MAX+1.0)) );
+				ress = getRandResource(elementary->getCoeff());
+				player->setResource( elementary->getArg(), player->getResource( elementary->getArg() ) + ress );
 				_server->sendPlayerResource( elementary->getArg(), player->getResource( elementary->getArg() ) );
 				break;
 			default:
@@ -1575,6 +1876,9 @@ void Engine::updateCellVision( GenericCell * cell )
 	}
 	if( cell->getBuilding() ) {
 		_server->newBuilding( cell->getBuilding() );
+		if(cell->getBuilding()->getOwner()){
+			_server->ownBuilding( cell->getBuilding(), _currentPlayer );
+		}
 	}
 	if( cell->getEvent() ) {
 		_server->newEvent( cell->getEvent() );/*
@@ -1680,3 +1984,41 @@ void Engine::checkMainQuest()
 	}
 }
 
+int Engine::getRandResource( int coeff)
+{
+	int ress,tmprand;
+	
+	tmprand =(int) ((200.0*rand())/(RAND_MAX+1.0));
+	ress = (coeff*(100 + (100 - tmprand)))/100;
+	//logDD("resource %d , coeff %d , rand %d", ress,coeff,tmprand);
+	return ress;
+}
+
+void Engine::updatePlayerPrices( GenericPlayer * player)
+{
+
+	uint nbases;
+	int cupr,tmpr;
+	uint nbRes = DataTheme.resources.count();
+
+	PriceMarket * realPrice = player->getPriceMarket();
+
+	cupr = 10000;	
+
+	for( uint i = 0; i < nbRes; i++ ) {
+		nbases = player->numBase();
+		for( uint j = 0 ; j < nbases ; j++){
+			PriceMarket * price = DataTheme.bases.at( player->getBase( j )->getRace())->getPriceMarket();
+			tmpr= price->getResourcePrice( i ) ;
+			if( tmpr < cupr ) {
+				cupr = tmpr;
+			}
+		}
+		if(cupr==10000){
+			cupr=1;
+		}
+		realPrice->setResourcePrice(i,cupr);
+		cupr = 10000;
+	}
+
+}
