@@ -5,9 +5,9 @@
 ** engine.h
 ** the game engine !
 **
-** Version : $Id: engine.h,v 1.21 2004/09/26 12:27:16 lusum Exp $
+** Version : $Id: engine.h,v 1.26 2004/12/07 19:03:53 lusum Exp $
 **
-** Author(s) : Pascal Audoux
+** Author(s) : Pascal Audoux - Sardi Carlo
 **
 ** Date : 03/10/2000
 **
@@ -138,10 +138,16 @@ private:
 	void handleInGameModif();
 	void handleInGameModifBase();
 	void handleInGameModifLord();
+	void handleInGameModifLordGarrison();
+	void handleInGameModifLordUnit();
 	void handleInGameTurn();
 
 	void newDay();
 
+	void handleAnswerCreatureJoin();
+	void handleAnswerCreatureMercenary();
+	void handleAnswerCreatureFlee();
+	
 	// enter into building (if return == true)
 	bool handleBuildingEnter( GenericBuilding * building, GenericLord * lord );
 	void handleBuildingAction( Action * action, GenericLord * lord );
@@ -166,9 +172,13 @@ private:
 
 	uint getAlivePlayersNumber();
 	void exchangeUnits();
+	void exchangeArtefact();
 	void exchangeBaseUnits();
 	bool enoughPlayers();
 
+	int getRandResource( int coeff);
+	void updatePlayerPrices( GenericPlayer * player);
+
 	void updateMapVision( QPtrList<GenericCell> & removed, QPtrList<GenericCell> & added );
 	void updateCellVision( GenericCell * cell );
 
