@@ -5,7 +5,7 @@
 ** questionManager.cpp
 ** Manages questions for the engine
 **
-** Version : $Id: questionManager.cpp,v 1.2 2004/10/09 13:20:24 audoux Exp $
+** Version : $Id: questionManager.cpp,v 1.3 2004/11/28 12:11:36 audoux Exp $
 **
 ** Author(s) : Pascal Audoux
 **
@@ -34,6 +34,7 @@
 QuestionManager::QuestionManager()
 {
 	_lord = 0;
+	_creature = 0;
 	_type = C_QR_MSG_END;
 }
 
@@ -47,6 +48,15 @@ CLASS_ANSWER QuestionManager::getAnswerType()
 	case C_QR_QUEST:
 		ret = ANSWER_YESNO;
 		break;
+	case C_QR_CREATURE_FLEE:
+		ret = ANSWER_YESNO;
+		break;
+	case C_QR_CREATURE_MERCENARY:
+		ret = ANSWER_YESNO;
+		break;
+	case C_QR_CREATURE_JOIN:
+		ret = ANSWER_YESNO;
+		break;
 	}
 
 	return ret;
