@@ -5,7 +5,7 @@
 ** serverInterface.cpp
 ** interface for the server
 **
-** Version : $Id: serverInterface.cpp,v 1.16 2004/10/10 11:46:37 audoux Exp $
+** Version : $Id: serverInterface.cpp,v 1.17 2004/11/03 21:03:37 audoux Exp $
 **
 ** Author(s) : Pascal Audoux - Carlo
 **
@@ -27,6 +27,8 @@
 
 #include "serverInterface.h"
 
+// generic include files
+#include <unistd.h>
 #include <stdlib.h>
 #include <time.h>
 // include files for QT
