@@ -5,9 +5,9 @@
 ** sectionBase.cpp
 ** section specifying bases
 **
-** Version : $Id: sectionBase.cpp,v 1.12 2004/07/28 20:25:58 audoux Exp $
+** Version : $Id: sectionBase.cpp,v 1.14 2004/12/11 13:40:24 lusum Exp $
 **
-** Author(s) : Pascal Audoux
+** Author(s) : Pascal Audoux - Sardi Carlo
 **
 ** Date : 02/06/2001
 **
@@ -234,7 +234,15 @@ SectionInsideBuilding::SectionInsideBuilding( QWidget * parent, const char * nam
 	_y->setMaxValue( 1000 );
 	_cost = new AskCost( tr( "Cost: " ), this );
 	_maintCost = new AskCost( tr( "Maintenance cost: " ), this );
-	_action = new AskInt(tr( "Action: "), this );
+	_comboInAct = new QComboBox( this );
+	_comboInAct->insertItem(tr("Not yet used"));
+	_comboInAct->insertItem(tr("Main Building"));
+	_comboInAct->insertItem(tr("Castle"));
+	_comboInAct->insertItem(tr("Prod Creature"));
+	_comboInAct->insertItem(tr("Market"));
+	FIXEDSIZE( _comboInAct );
+
+	//_action = new AskInt(tr( "Action: "), this );
 	_params = new AskIntList( this );
 	_params->setLabel( tr( "Params: " ) );
 
@@ -249,7 +257,7 @@ SectionInsideBuilding::SectionInsideBuilding( QWidget * parent, const char * nam
 	layout->addWidget( _y );
 	layout->addWidget( _cost );
 	layout->addWidget( _maintCost );
-	layout->addWidget( _action );
+	layout->addWidget( _comboInAct );
 	layout->addWidget( _params );
 
 
@@ -350,14 +358,14 @@ void SectionInsideBuilding::save()
 			build->setCost( i, _cost->getValue( i ) );
 			build->setMantCost( i, _maintCost->getValue( i ) );
 		}
-		if(_action->getValue()!=0){
-			InsideAction * action = new InsideAction();
-			action->setType(_action->getValue());
-			for( uint i = 0; i < _params->count(); i++ ) {
-				action->addParam(_params->getValue(i) );
-			}
-			build->setAction( action );
+		//if(((uint) _comboInAct->currentItem())!=0){
+		InsideAction * action = new InsideAction();
+		action->setType((uint) _comboInAct->currentItem());
+		for( uint i = 0; i < _params->count(); i++ ) {
+			action->addParam(_params->getValue(i) );
 		}
+		build->setAction( action );
+		//}
 	}
 }
 
@@ -377,12 +385,12 @@ void SectionInsideBuilding::init()
 		_params->clear();
 		InsideAction * action = build->getAction();
 		if(action){
-			_action->setValue(action->getType());
+			_comboInAct->setCurrentItem((uint) action->getType());
 			for( uint i = 0; i < action->getParamNumber(); i++ ) {
 				_params->addValue( action->getParam(i) );
 			}
 		} else {
-			_action->setValue( 0 );
+			_comboInAct->setCurrentItem( 0 );
 		}
 		uint nbRes = DataTheme.resources.count();
 		for( uint i = 0; i < nbRes; i++ ) {
@@ -404,7 +412,7 @@ void SectionInsideBuilding::clear()
 		_cost->setValue( i,  0  );
 		_maintCost->setValue( i,  0  );
 	}
-	_action->setValue( 0 );
+	_comboInAct->setCurrentItem( 0 );
 	_params->clear();
 }
 
