@@ -5,7 +5,7 @@
 ** sectionBase.h
 ** section specifying bases
 **
-** Version : $Id: sectionBase.h,v 1.8 2004/07/28 20:25:58 audoux Exp $
+** Version : $Id: sectionBase.h,v 1.9 2004/10/31 21:59:51 lusum Exp $
 **
 ** Author(s) : Pascal Audoux
 **
@@ -32,10 +32,12 @@
 // generic include files
 // include files for QT
 #include <qwidget.h>
+#include <qcombobox.h>
 // application specific include files
 #include "themeEditor/sectionWidget.h"
 #include "themeEditor/askCost.h"
 
+class QComboBox;
 class MapDispositionEditor;
 class SectionInsideBuilding;
 
@@ -132,9 +134,10 @@ protected:
 	uint _idBase, _idBuild;
 	SelectionWidget * _select;
 	AskString * _name, * _description;
-	AskInt * _x, * _y, * _action;
+	AskInt * _x, * _y ;
 	AskCost * _maintCost,* _cost;
 	AskIntList * _params;
+	QComboBox * _comboInAct;
 };
 
 #endif // SECTIONBASE_H
