@@ -5,7 +5,7 @@
 ** sectionCreature.cpp
 ** section for specifying creatures
 **
-** Version : $Id: sectionCreature.cpp,v 1.9 2004/07/31 19:29:47 audoux Exp $
+** Version : $Id: sectionCreature.cpp,v 1.10 2004/11/01 14:38:24 lusum Exp $
 **
 ** Author(s) : Pascal Audoux
 **
@@ -298,6 +298,14 @@ EditCreature::EditCreature( QWidget * parent, const char * name )
 
 	_maintCost = new AskCost( tr( "Maintenance cost: " ), this );
 	layout->addWidget( _maintCost );
+	
+	_XOffset = new AskInt( tr( "X Offset: " ), this );
+	_XOffset->setMinValue( -255 );
+	layout->addWidget( _XOffset );
+	
+	_YOffset = new AskInt( tr( "Y Offset: " ), this );
+	_YOffset->setMinValue( -255 );
+	layout->addWidget( _YOffset );
 
 	_pix = new AskPixmap( true, "", tr( "Picture: " ), this );
 	layout->addWidget( _pix );
@@ -321,6 +329,8 @@ void EditCreature::save( int race, int creature )
 	unit->setMorale( _morale->getValue() );
 	unit->setSize( _size->getValue() );
 	unit->setLuck( _luck->getValue() );
+	unit->setXOffset( _XOffset->getValue() );
+	unit->setYOffset( _YOffset->getValue() );
 	uint nbRes = DataTheme.resources.count();
 	for( uint i = 0; i < nbRes; i++ ) {
 		unit->setCost( i, _cost->getValue( i ) );
@@ -344,6 +354,8 @@ void EditCreature::init( int race, int creature )
 	_morale->setValue( unit->getMorale() );
 	_size->setValue( unit->getSize() );
 	_luck->setValue( unit->getLuck() );
+	_XOffset->setValue(unit->getXOffset());
+	_YOffset->setValue(unit->getYOffset());
 	uint nbRes = DataTheme.resources.count();
 	for( uint i = 0; i < nbRes; i++ ) {
 		_cost->setValue( i, unit->getCost( i ) );
