@@ -5,9 +5,9 @@
 ** sectionSelector.cpp
 ** main widget, allows modif in diff theme sections
 **
-** Version : $Id: sectionSelector.cpp,v 1.4 2004/05/08 22:07:56 audoux Exp $
+** Version : $Id: sectionSelector.cpp,v 1.5 2004/12/11 13:41:30 lusum Exp $
 **
-** Author(s) : Pascal Audoux
+** Author(s) : Pascal Audoux - Sardi Carlo
 **
 ** Date : 02/06/2001
 **
@@ -80,18 +80,18 @@ SectionSelector::SectionSelector( QWidget * parent, const char * name )
 	: QTabWidget( parent, name )
 {
 	AttalScrollView * viewGeneral = new AttalScrollView( this, "scrollview general" );
-	SectionGeneral * general = new SectionGeneral( viewGeneral->viewport(), "general" );
-	viewGeneral->setSection( general );
+	_general = new SectionGeneral( viewGeneral->viewport(), "general" );
+	viewGeneral->setSection( _general );
 	addTab( viewGeneral, tr( "General" ) );
 
 	AttalScrollView * viewArtefact = new AttalScrollView( this, "scrollview artefacts" );
-	SectionArtefact * artefact = new SectionArtefact( viewArtefact->viewport(), "artefact" );
-	viewArtefact->setSection( artefact );
+	_artefact = new SectionArtefact( viewArtefact->viewport(), "artefact" );
+	viewArtefact->setSection( _artefact );
 	addTab( viewArtefact, tr( "Artefacts" ) );
 
 	AttalScrollView * viewTeam = new AttalScrollView( this, "scrollview teams" );
-	SectionTeam * team = new SectionTeam( viewTeam, "team" );
-	viewTeam->setSection( team );
+	_team = new SectionTeam( viewTeam, "team" );
+	viewTeam->setSection( _team );
 	addTab( viewTeam, tr( "Teams" ) );
 
 	AttalScrollView * viewBase = new AttalScrollView( this, "scrollview bases" );
@@ -100,23 +100,23 @@ SectionSelector::SectionSelector( QWidget * parent, const char * name )
 	addTab( viewBase, tr( "Bases" ) );
 
 	AttalScrollView * viewBuilding = new AttalScrollView( this, "scrollview buildings" );
-	SectionBuilding * building = new SectionBuilding( viewBuilding->viewport(), "building" );
-	viewBuilding->setSection( building );
+	_building = new SectionBuilding( viewBuilding->viewport(), "building" );
+	viewBuilding->setSection( _building );
 	addTab( viewBuilding, tr( "Buildings" ) );
 
 	AttalScrollView * viewCreature = new AttalScrollView( this, "scrollview creatures" );
-	SectionCreature * creature = new SectionCreature( viewCreature->viewport(), "creatures" );
-	viewCreature->setSection( creature );
+	_creature = new SectionCreature( viewCreature->viewport(), "creatures" );
+	viewCreature->setSection( _creature );
 	addTab( viewCreature, tr( "Creatures" ) );
 
 	AttalScrollView * viewDecoration = new AttalScrollView( this, "scrollview decorations" );
-	SectionDecoration * decoration = new SectionDecoration( viewDecoration->viewport(), "decoration" );
-	viewDecoration->setSection( decoration );
+	_decoration = new SectionDecoration( viewDecoration->viewport(), "decoration" );
+	viewDecoration->setSection( _decoration );
 	addTab( viewDecoration, tr( "Decorations" ) );
 
 	AttalScrollView * viewGround = new AttalScrollView( this, "scrollview grounds" );
-	SectionGround * ground = new SectionGround( viewGround->viewport(), "ground" );
-	viewGround->setSection( ground );
+	_ground = new SectionGround( viewGround->viewport(), "ground" );
+	viewGround->setSection( _ground );
 	addTab( viewGround, tr( "Grounds" ) );
 
 	AttalScrollView * viewLordCategory = new AttalScrollView( this, "scrollview lord categories" );
@@ -130,26 +130,26 @@ SectionSelector::SectionSelector( QWidget * parent, const char * name )
 	addTab( viewLord, tr( "Lords" ) );
 
 	AttalScrollView * viewExperience = new AttalScrollView( this, "scrollview levels" );
-	SectionExperience * experience = new SectionExperience( viewExperience->viewport(), "experience" );
-	viewExperience->setSection( experience );
+	_experience = new SectionExperience( viewExperience->viewport(), "experience" );
+	viewExperience->setSection( _experience );
 	addTab( viewExperience, tr( "Levels" ) );
 
 	AttalScrollView * viewResource = new AttalScrollView( this, "scrollview resources" );
-	SectionRessource * resource = new SectionRessource( viewResource->viewport(), "resources" );
-	viewResource->setSection( resource );
+	_resource = new SectionRessource( viewResource->viewport(), "resources" );
+	viewResource->setSection( _resource );
 	addTab( viewResource, tr( "Resources" ) );
 
 	AttalScrollView * viewMachine = new AttalScrollView( this, "scrollview machine" );
-	SectionMachine * machine = new SectionMachine( viewMachine->viewport(), "machines" );
-	viewMachine->setSection( machine );
+	_machine = new SectionMachine( viewMachine->viewport(), "machines" );
+	viewMachine->setSection( _machine );
 	addTab( viewMachine, tr( "War Machines" ) );
 
 	connect( this, SIGNAL( currentChanged( QWidget * ) ), SLOT( slot_changed( QWidget * ) ) );
-	connect( creature, SIGNAL( sig_changed() ), SLOT( slot_creaturesChanged() ) );
+	connect( _creature, SIGNAL( sig_changed() ), SLOT( slot_creaturesChanged() ) );
 	connect( _lordCategories, SIGNAL( sig_changed() ), SLOT( slot_lordCategoryChanged() ) );
-	connect( general, SIGNAL( sig_changed() ), SLOT( slot_generalChanged() ) );
+	connect( _general, SIGNAL( sig_changed() ), SLOT( slot_generalChanged() ) );
 
-	_current = general;
+	_current = _general;
 }
 
 void SectionSelector::save()
@@ -157,6 +157,23 @@ void SectionSelector::save()
 	_current->save();
 }
 
+void SectionSelector::saveAll()
+{
+	_lordCategories->save();
+	_general->save();
+	_artefact->save();
+	_team->save();
+	_building->save();
+	_creature->save();
+	_decoration->save();
+	_ground->save();
+	_experience->save();
+	_resource->save();
+	_machine->save();
+	_base->save();
+	_lord->save();
+}
+
 void SectionSelector::slot_changed( QWidget * widget )
 {
 	_current->save();
