@@ -5,9 +5,9 @@
 ** sectionSelector.h
 ** main widget, allows modif in diff theme sections
 **
-** Version : $Id: sectionSelector.h,v 1.2 2004/05/08 22:07:56 audoux Exp $
+** Version : $Id: sectionSelector.h,v 1.3 2004/12/11 13:41:30 lusum Exp $
 **
-** Author(s) : Pascal Audoux
+** Author(s) : Pascal Audoux - Sardi Carlo
 **
 ** Date : 02/06/2001
 **
@@ -38,6 +38,17 @@ class Section;
 class SectionBase;
 class SectionLord;
 class SectionLordCategory;
+class SectionGeneral ;
+class	SectionArtefact ;
+class	SectionTeam ;
+class	SectionBuilding ;
+class	SectionCreature ;
+class	SectionDecoration ;
+class	SectionGround ;
+class	SectionExperience ;
+class	SectionRessource ;
+class	SectionMachine ;
+
 
 /**              ------------------------------
  *                          SectionSelector
@@ -54,6 +65,9 @@ public:
 
 	/** Saves the sections */
 	void save();
+	
+	/** Saves all the sections */
+	void saveAll();
 
 public slots:
 	/** Slot if something changed */
@@ -71,8 +85,18 @@ public slots:
 private:
 	Section * _current;
 	SectionLordCategory * _lordCategories;
-	SectionLord * _lord;
+	SectionGeneral * _general;
+	SectionArtefact * _artefact;
+	SectionTeam * _team;
+	SectionBuilding * _building;
+	SectionCreature * _creature;
+	SectionDecoration * _decoration;
+	SectionGround * _ground;
+	SectionExperience * _experience;
+	SectionRessource * _resource;
+	SectionMachine * _machine;
 	SectionBase * _base;
+	SectionLord * _lord;
 };
 
 #endif // SECTIONSELECTOR_H
