@@ -5,7 +5,7 @@
 ** mapInterface.cpp
 ** Manages the editor
 **
-** Version : $Id: themeInterface.cpp,v 1.6 2004/05/09 11:01:20 audoux Exp $
+** Version : $Id: themeInterface.cpp,v 1.7 2004/12/11 13:41:30 lusum Exp $
 **
 ** Author(s) : Pascal Audoux
 **
@@ -155,7 +155,7 @@ void ThemeInterface::slot_actions( int num )
 		break;
 	}
 	case ACTION_SAVE: {
-		_selector->save();
+		_selector->saveAll();
 		DataTheme.save();
 		break;
 	}
